package com.unis.inspectionresult.client;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.FormfieldsVO;
import com.unis.inspectionresult.common.vo.FormfieldsqueryVO;
import com.unis.inspectionresult.common.vo.InspectionIndicatorsVO;
import com.unis.inspectionresult.common.vo.InspectionIndicatorsqueryVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@FeignClient(name = "inspectionresult-server")
@Component
@Api(value = "表单信息", tags = "表单信息")
public interface FormfieldsFeign {

	/**
	 * 新增表单信息
	 * @param vo
	 * @return
	 */
	@ApiOperation(value = "新增表单信息", notes = "参数：表单信息实体信息")
	@PostMapping("/formfields")
	public ResponseWrapper insertFormfields(@RequestBody FormfieldsVO vo);

	/**
	 * 根据条件分页获取信息列表
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@ApiOperation(value = "根据条件分页获取信息列表")
	@PostMapping("/formfieldsList")
	public ResponseWrapper getInspectionfieldsList(@RequestBody FormfieldsqueryVO queryvo,
			@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
			@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum);
	
	
	
	/**
	 * 根据条件不分页获取信息列表
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@ApiOperation(value = "根据条件不分页获取信息列表")
	@PostMapping("/formfieldsforList")
	public ResponseWrapper getInspectionforfieldsList(@RequestBody FormfieldsqueryVO queryvo);

	/**
	 * 查看表单信息
	 * @param bdId
	 * @return
	 */
	@ApiOperation(value = "查看表单信息")
	@GetMapping("/formfields/{bdId}")
	public ResponseWrapper getFormfields(@PathVariable("bdId") String bdId);

	/**
	 * 编辑表单信息
	 * @param vo
	 * @return
	 */
	@ApiOperation(value = "编辑表单信息")
	@PutMapping("/formfields")
	public ResponseWrapper updateFormfields(@RequestBody FormfieldsVO vo);

}
