package com.unis.inspectionresult.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.DCfxxsjyVO;
import com.unis.inspectionresult.common.vo.TrcjczbVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @Classname TrcjczbFeign
 * @Description 日常检查远程调用
 * @Date 2023/11/22 17:22
 * @Created by rising123sun
 */
@FeignClient(name = "inspectionresult-server")
@Component
@Api(value = "日常检查远程调用", tags = "日常检查远程调用")
public interface TrcjczbFeign {

    // 分页列表查询
    @ApiOperation(value = "分页列表查询", notes = "分页列表查询")
    @PostMapping("/trcjc/queryPageList")
    public ResponseWrapper queryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                         @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                         @RequestBody TrcjczbVO trcjczbVO);

    // 日常检查新增
    @PostMapping("/trcjc/add")
    @ApiOperation(value = "日常检查新增", notes = "日常检查新增")
    public ResponseWrapper add(@RequestBody TrcjczbVO trcjczbVO);

    // 日常检查修改
    @PostMapping("/trcjc/update")
    @ApiOperation(value = "日常检查修改", notes = "日常检查修改")
    public ResponseWrapper update(@RequestBody TrcjczbVO trcjczbVO);

    // 日常检查删除
    @DeleteMapping("/trcjc/delete/{id}")
    @ApiOperation(value = "日常检查删除", notes = "日常检查删除")
    public ResponseWrapper delete(@PathVariable("id") String id);

    /**
     * @param dCfxxsjyVO 库点代码
     * @return 仓房信息列表
     * @author WangZL, wangruimin
     * @Description 根据库点代码获取仓房列表
     * @version V2
     */
    @ApiOperation(value = "仓房信息-根据库点代码获取仓房列表", notes = "参数：库点代码")
    @PostMapping(value = "/trcjc//warehouse/selectByEntity")
    public ResponseWrapper selectByEntity(@RequestBody DCfxxsjyVO dCfxxsjyVO);

    // 企业接受检查统计表分页列表查询
    @ApiOperation(value = "企业接受检查统计表分页列表查询", notes = "企业接受检查统计表分页列表查询")
    @PostMapping("/trcjcshqk/qyjsjcQueryPageList")
    public ResponseWrapper qyjsjcQueryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                               @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                               @RequestBody TrcjczbVO trcjczbVO);

    // 企业接受检查统计表报表导出
    @ApiOperation(value = "企业接受检查统计表报表导出", notes = "企业接受检查统计表报表导出")
    @PostMapping("/trcjcshqk/qyjsjcQueryPageListForDc")
    public ResponseWrapper qyjsjcQueryPageListForDc(@RequestBody TrcjczbVO trcjczbVO);

    @ApiOperation(value = "根据被检企业名称，年份以及仓房编码查询相关检查时间", notes = "根据被检企业名称，年份以及仓房编码查询相关检查时间")
    @PostMapping("/trcjcshqk/queryJcsjByBjdwmcAndYearAndCfbm")
    public ResponseWrapper queryJcsjByBjdwmcAndYearAndCfbm(@RequestBody TrcjczbVO trcjczbVO);

    // 检查单位统计表分页列表查询
    @ApiOperation(value = "检查单位统计表分页列表查询", notes = "检查单位统计表分页列表查询")
    @PostMapping("/trcjcshqk/jcdwjcQueryPageList")
    public ResponseWrapper jcdwjcQueryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                               @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                               @RequestBody TrcjczbVO trcjczbVO);
    // 检查单位统计表报表导出
    @ApiOperation(value = "检查单位统计表报表导出", notes = "检查单位统计表报表导出")
    @PostMapping("/trcjcshqk/jcdwjcQueryPageListForDc")
    public ResponseWrapper jcdwjcQueryPageListForDc(@RequestBody TrcjczbVO trcjczbVO);

    // 详情查询
    @ApiOperation(value = "详情查询", notes = "详情查询")
    @GetMapping("/trcjc/queryDetail/{id}")
    public ResponseWrapper queryDetail(@PathVariable("is") String id);
}
