package com.unis.inspectionresult.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.CheckWorkLogQueryVO;
import com.unis.inspectionresult.common.vo.CheckWorkLogVO;
import com.unis.inspectionresult.server.service.CheckWorkLogService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title CheckWorkLogController
 * @ProjectName 检查工作日志信息 CheckWorkLogController
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "检查工作日志 ", tags = "检查工作日志")
@Slf4j
public class CheckWorkLogController {

	@Autowired
	private CheckWorkLogService checkWorkLogService;

	/**
	 * @author WangZL
	 * @Description 检查工作日志-查询列表
	 * @param 检查开始时间，检查结束时间，被检企业编号
	 * @return 检查工作日志列表
	 */
	@ApiOperation(value = "检查工作日志-查询列表", notes = "参数：检查开始时间，检查结束时间，被检企业编号")
	@PostMapping(value = "/checkWorkLogList")
    public ResponseWrapper getCheckWorkLogList(@RequestBody CheckWorkLogQueryVO checkWorkLogQueryVO){
		try {
			List<CheckWorkLogVO> checkWorkLogList = checkWorkLogService.getCheckWorkLogList(checkWorkLogQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), checkWorkLogList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author WangZL
	 * @Description 检查工作日志-分页查询列表
	 * @param 检查开始时间，检查结束时间，被检企业编号
	 * @return
	 */
	@ApiOperation(value = "检查工作日志-分页查询列表", notes = "参数：检查开始时间，检查结束时间，被检企业编号")
	@PostMapping(value = "/checkWorkLogPage/{pageNum}/{pageSize}")
	public ResponseWrapper getCheckWorkLogPage(@RequestBody CheckWorkLogQueryVO checkWorkLogQueryVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<CheckWorkLogVO> pageInfos = new PageInfo<CheckWorkLogVO>(checkWorkLogService.getCheckWorkLogPage(checkWorkLogQueryVO,pageNum,pageSize));
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 检查工作日志-新增
	 * @param 检查工作日志信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/checkWorkLog")
	@ApiOperation(value = "检查工作日志-新增", notes = "参数：检查工作日志信息对象 model")
    public ResponseWrapper insert(@RequestBody CheckWorkLogVO checkWorkLogVO) {
		try{
			CheckWorkLogVO checkWorkLogVOs = checkWorkLogService.insert(checkWorkLogVO);
			if(checkWorkLogVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增检查工作日志失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), checkWorkLogVOs);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author WangZL
	 * @Description 检查工作日志-更新
	 * @param 检查工作日志信息对象 model
	 * @return 新增状态
	 */
	@PutMapping(value = "/checkWorkLog")
	@ApiOperation(value = "检查工作日志-更新", notes = "参数：检查工作日志信息对象 model")
    public ResponseWrapper update(@RequestBody CheckWorkLogVO checkWorkLogVO) {
		try{
			int x = checkWorkLogService.update(checkWorkLogVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该检查工作日志信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该检查工作日志信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author WangZL
	 * @Description 检查工作日志-删除
	 * @param 检查工作日志ID
	 * @return 状态
	 */
	@DeleteMapping(value="/checkWorkLog/{id}")
	@ApiOperation(value = "检查工作日志-删除", notes = "参数：日志ID")
	public ResponseWrapper delete(@PathVariable("id") Integer id) {
		try{
			int x = checkWorkLogService.delete(id);
			if(x>0) {
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
	            return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
			} else {
				 return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败,请检查工作日志ID是否正确", null);
			}
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author WangZL
	 * @Description 检查工作日志-查询详情
	 * @param 检查工作日志ID
	 * @return 状态
	 */
	@GetMapping(value="/checkWorkLog/{id}")
	@ApiOperation(value = "检查工作日志-查询详情", notes = "参数：日志ID")
	public ResponseWrapper getCheckWorkLogInfoById(@PathVariable("id") Integer id) {
		try{
			CheckWorkLogVO checkWorkLogVO = checkWorkLogService.getCheckWorkLogInfoById(id);
			if(checkWorkLogVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，检查工作日志不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), checkWorkLogVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

}
