package com.unis.inspectionresult.server.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.FormfieldsVO;
import com.unis.inspectionresult.common.vo.FormfieldsqueryVO;
import com.unis.inspectionresult.server.service.FormfieldsService;

import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(value = "表单信息", tags = "表单信息")
public class FormfieldsController {

	@Autowired
	private FormfieldsService formfieldsService;

	/**
	 * 新增表单信息
	 * @param jczbvo
	 * @return
	 */
	@PostMapping("/formfields")
	public ResponseWrapper insertFormfields(@RequestBody FormfieldsVO vo) {
		try {;
			int indicators = formfieldsService.insertFormfields(vo);
			return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", indicators);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "新增失败", null);
		}
	}

	/**
	 * 分页
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@PostMapping("/formfieldsList")
	public ResponseWrapper getInspectionfieldsList(@RequestBody FormfieldsqueryVO queryvo,
			@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
			@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum) {

		try {
			List<FormfieldsVO> formfieldsList = formfieldsService.getFormfieldsList(queryvo, pageSize, pageNum);

			PageInfo<FormfieldsVO> pageInfos = new PageInfo<FormfieldsVO>(formfieldsList);

			return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", pageInfos);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}

	}
	
	/**
	 * 不分页
	 * @param queryvo
	 * 
	 * @return
	 */
	@PostMapping("/formfieldsforList")
	public ResponseWrapper getInspectionforfieldsList(@RequestBody FormfieldsqueryVO queryvo) {

		try {
			List<FormfieldsVO> formfieldsList = formfieldsService.getFormfieldsforList(queryvo);

			PageInfo<FormfieldsVO> pageInfos = new PageInfo<FormfieldsVO>(formfieldsList);

			return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", pageInfos);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}

	}

	/**
	 * 更新表单信息
	 * @param jczbvo
	 * @return
	 */
	@PutMapping("/formfields")
	public ResponseWrapper updateFormfields(@RequestBody FormfieldsVO vo) {

		try {
			int updateInspectionIndicators = formfieldsService.updateFormfields(vo);
			return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", updateInspectionIndicators);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "更新失败", null);
		}
	}
	
	/**
	 * 获取表单信息
	 * @param zbId
	 * @return
	 */
	@GetMapping("/formfields/{bdId}")
	public ResponseWrapper getFormfields(@PathVariable("bdId") String bdId) {

		try {
			FormfieldsVO formfields = formfieldsService.getFormfields(bdId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", formfields);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取失败", null);
		}
	}

}