package com.unis.inspectionresult.server.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.InspectionIndicatorsVO;
import com.unis.inspectionresult.common.vo.InspectionIndicatorsqueryVO;
import com.unis.inspectionresult.server.service.InspectionIndicatorsService;

import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(value = "检查指标", tags = "检查指标")
public class InspectionresultController {

	@Autowired
	private InspectionIndicatorsService inspectionresultService;

	/**
	 * 新增检查指标
	 * @param jczbvo
	 * @return
	 */
	@PostMapping("/inspectionresultService")
	public ResponseWrapper insertInspectionIndicators(@RequestBody InspectionIndicatorsVO jczbvo) {
		try {
			int indicators = inspectionresultService.insertInspectionIndicators(jczbvo);
			return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", indicators);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "新增失败", null);
		}
	}

	/**
	 * 分页
	 * @param queryvo
	 * @param pageSize
	 * @param pageNum
	 * @return
	 */
	@PostMapping("/inspectionresultList")
	public ResponseWrapper getInspectionIndicatorsServiceList(@RequestBody InspectionIndicatorsqueryVO queryvo,
			@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
			@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum) {

		try {
			List<InspectionIndicatorsVO> jczbList = inspectionresultService.getJczbList(queryvo, pageSize, pageNum);

			PageInfo<InspectionIndicatorsVO> pageInfos = new PageInfo<InspectionIndicatorsVO>(jczbList);

			return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", pageInfos);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}

	}

	/**
	 * 更新检查指标
	 * @param jczbvo
	 * @return
	 */
	@PutMapping("/inspectionresult")
	public ResponseWrapper updateInspectionIndicators(@RequestBody InspectionIndicatorsVO jczbvo) {

		try {
			int updateInspectionIndicators = inspectionresultService.updateInspectionIndicators(jczbvo);
			return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", updateInspectionIndicators);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "更新失败", null);
		}
	}
	
	/**
	 * 获取检查指标
	 * @param zbId
	 * @return
	 */
	@GetMapping("/inspectionresult/{zbId}")
	public ResponseWrapper getInspectionIndicators(@PathVariable("zbId") String zbId) {

		try {
			InspectionIndicatorsVO indicatorsVO = inspectionresultService.getJczb(zbId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", indicatorsVO);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取失败", null);
		}
	}

}