package com.unis.inspectionresult.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.RectificationAcceptanceVO;
import com.unis.inspectionresult.server.service.RectificationAcceptanceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title RectificationAcceptanceController
 * @ProjectName 整改验收单信息 RectificationAcceptanceController
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "整改验收单 ", tags = "整改验收单")
@Slf4j
public class RectificationAcceptanceController {

	@Autowired
	private RectificationAcceptanceService rectificationAcceptanceService;

	/**
	 * @author WangZL
	 * @Description 新增整改验收单
	 * @param 整改验收单信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/rectificationAcceptance")
	@ApiOperation(value = "整改验收单-新增", notes = "参数：整改验收单信息对象 model")
    public ResponseWrapper insert(@RequestBody RectificationAcceptanceVO rectificationAcceptanceVO) {
		try{
			RectificationAcceptanceVO rectificationAcceptanceVOs = rectificationAcceptanceService.insert(rectificationAcceptanceVO);
			if(rectificationAcceptanceVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增整改验收单失败，输入正确的结果ID", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rectificationAcceptanceVOs);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

    /**
	 * @author WangZL
	 * @Description 更新整改验收单信息
	 * @param 整改验收单信息对象 model
	 * @return
	 */
	@PutMapping(value = "/rectificationAcceptance")
	@ApiOperation(value = "整改验收单-更新", notes = "参数：整改验收单信息对象 model")
	public ResponseWrapper update(@RequestBody RectificationAcceptanceVO rectificationAcceptanceVO) {
		try{
			int x = rectificationAcceptanceService.update(rectificationAcceptanceVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该整改验收单信息不存在", null);
			} else if (x==-1) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该结果信息和验收单不相符", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该整改验收单信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 根据结果ID获取整改验收单列表
	 * @param 结果ID
	 * @return 状态
	 */
	@GetMapping(value="/rectificationAcceptanceList/{jgId}")
	@ApiOperation(value = "整改验收单-查询列表", notes = "参数：结果ID")
	public ResponseWrapper getRectificationAcceptanceListInfoByJgId(@PathVariable("jgId") String jgId) {
		try{
			List<RectificationAcceptanceVO> rectificationAcceptanceVO = rectificationAcceptanceService.getRectificationAcceptanceListInfoByJgId(jgId);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rectificationAcceptanceVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 根据验收单ID获取整改验收单信息
	 * @param 验收单ID
	 * @return 状态
	 */
	@GetMapping(value="/rectificationAcceptance/{ysdId}")
	@ApiOperation(value = "整改验收单-查询详情", notes = "参数：验收单ID")
	public ResponseWrapper getRectificationAcceptanceInfoByYsdId(@PathVariable("ysdId") String ysdId) {
		try{
			RectificationAcceptanceVO rectificationAcceptanceVO = rectificationAcceptanceService.getRectificationAcceptanceInfoByYsdId(ysdId);
			if(rectificationAcceptanceVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，整改验收单不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rectificationAcceptanceVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}
}
