package com.unis.inspectionresult.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.RectificationFeedbackVO;
import com.unis.inspectionresult.server.service.RectificationFeedbackService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title RectificationFeedbackController
 * @ProjectName 整改反馈单信息 RectificationFeedbackController
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "整改反馈单 ", tags = "整改反馈单")
@Slf4j
public class RectificationFeedbackController {

	@Autowired
	private RectificationFeedbackService rectificationFeedbackService;

	/**
	 * @author WangZL
	 * @Description 新增整改反馈单
	 * @param 整改反馈单信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/rectificationFeedback")
	@ApiOperation(value = "整改反馈单-新增", notes = "参数：整改反馈单信息对象 model")
    public ResponseWrapper insert(@RequestBody RectificationFeedbackVO rectificationFeedbackVO) {
		try{
			RectificationFeedbackVO rectificationFeedbackVOs = rectificationFeedbackService.insert(rectificationFeedbackVO);
			if(rectificationFeedbackVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增整改反馈单失败，输入正确的结果ID", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", rectificationFeedbackVOs);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

    /**
	 * @author WangZL
	 * @Description 更新整改反馈单信息
	 * @param 整改反馈单信息对象 model
	 * @return
	 */
	@PutMapping(value = "/rectificationFeedback")
	@ApiOperation(value = "整改反馈单-更新", notes = "参数：整改反馈单信息对象 model")
	public ResponseWrapper update(@RequestBody RectificationFeedbackVO rectificationFeedbackVO) {
		try{
			int x = rectificationFeedbackService.update(rectificationFeedbackVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该整改反馈单信息不存在", null);
			} else if (x==-1) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该结果信息和反馈单不相符", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该整改反馈单信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 根据结果ID获取整改反馈单信息
	 * @param 结果ID
	 * @return 状态
	 */
	@GetMapping(value="/rectificationFeedbackList/{jgId}")
	@ApiOperation(value = "整改反馈单-查询列表", notes = "参数：结果ID")
	public ResponseWrapper getRectificationFeedbackInfoListByJgId(@PathVariable("jgId") String jgId) {
		try{
			List<RectificationFeedbackVO> rectificationFeedbackVOList = rectificationFeedbackService.getRectificationFeedbackInfoListByJgId(jgId);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rectificationFeedbackVOList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 根据反馈单ID获取整改反馈单信息
	 * @param 反馈单ID
	 * @return 状态
	 */
	@GetMapping(value="/rectificationFeedback/{fkdId}")
	@ApiOperation(value = "整改反馈单-查询详情", notes = "参数：反馈单ID")
	public ResponseWrapper getRectificationFeedbackInfoByFkdId(@PathVariable("fkdId") String fkdId) {
		try{
			RectificationFeedbackVO rectificationFeedbackVO = rectificationFeedbackService.getRectificationFeedbackInfoByFkdId(fkdId);
			if(rectificationFeedbackVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，整改反馈单不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rectificationFeedbackVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

}
