package com.unis.inspectionresult.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.RectificationNoticeVO;
import com.unis.inspectionresult.server.service.RectificationNoticeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * @author WangZL
 * @version 1.0
 * @Title RectificationNoticeController
 * @ProjectName 责令整改通知单信息 RectificationNoticeController
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "责令整改通知单 ", tags = "责令整改通知单")
@Slf4j
public class RectificationNoticeController {

	@Autowired
	private RectificationNoticeService rectificationNoticeService;

	/**
	 * @author WangZL
	 * @Description 新增责令整改通知单
	 * @param 责令整改通知单信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/rectificationNotice")
	@ApiOperation(value = "责令整改通知单-新增", notes = "参数：责令整改通知单信息对象 model")
    public ResponseWrapper insert(@RequestBody RectificationNoticeVO rectificationNoticeVO) {
		try{
			RectificationNoticeVO rectificationNoticeVOs = rectificationNoticeService.insert(rectificationNoticeVO);
			if(rectificationNoticeVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增责令整改通知单失败，输入正确的结果ID", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rectificationNoticeVOs);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

    /**
	 * @author WangZL
	 * @Description 更新责令整改通知单信息
	 * @param 责令整改通知单信息对象 model
	 * @return
	 */
	@PutMapping(value = "/rectificationNotice")
	@ApiOperation(value = "责令整改通知单-更新", notes = "参数：责令整改通知单信息对象 model")
	public ResponseWrapper update(@RequestBody RectificationNoticeVO rectificationNoticeVO) {
		try{
			int x = rectificationNoticeService.update(rectificationNoticeVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该责令整改通知单信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该责令整改通知单信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 根据结果ID获取责令整改通知单信息
	 * @param 结果ID
	 * @return 状态
	 */
	@GetMapping(value="/rectificationNotice/{jgId}")
	@ApiOperation(value = "责令整改通知单-查询详情", notes = "参数：结果ID")
	public ResponseWrapper getRectificationNoticeInfoByJgId(@PathVariable("jgId") String jgId) {
		try{
			RectificationNoticeVO rectificationNoticeVO = rectificationNoticeService.getRectificationNoticeInfoByJgId(jgId);
			if(rectificationNoticeVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，责令整改通知单不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rectificationNoticeVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

}
