package com.unis.inspectionresult.server.controller;

import com.github.pagehelper.PageInfo;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.*;
import com.unis.inspectionresult.server.entity.TrcjczbDO;
import com.unis.inspectionresult.server.service.TrcjcshqkService;
import com.unis.inspectionresult.server.service.TrcjczbService;
import com.unis.inspectionresult.server.service.TrcjczgqkService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @Classname TrcjczbController
 * @Description 日常检查主表控制层
 * @Date 2023/11/20 13:54
 * @Created by rising123sun
 */
@RestController
@Slf4j
@Api(value = "日常检查", tags = "日常检查")
public class TrcjczbController {

    @Resource
    private TrcjczbService trcjczbService;


    // 分页列表查询
    @ApiOperation(value = "分页列表查询", notes = "分页列表查询")
    @PostMapping("/trcjc/queryPageList")
    public ResponseWrapper queryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                         @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                         @RequestBody TrcjczbVO trcjczbVO) {
        try {
            List<TrcjczbVO> list = trcjczbService.queryPageList(pageSize, pageNum, trcjczbVO);
            PageInfo<TrcjczbVO> pageInfo = new PageInfo<>(list);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", pageInfo);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
        }
    }

    // 日常检查新增
    @PostMapping("/trcjc/add")
    @ApiOperation(value = "日常检查新增", notes = "日常检查新增")
    public ResponseWrapper add(@RequestBody TrcjczbVO trcjczbVO) {
        try {
            trcjczbService.add(trcjczbVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", null);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "新增失败", null);
        }
    }

    // 日常检查修改
    @PostMapping("/trcjc/update")
    @ApiOperation(value = "日常检查修改", notes = "日常检查修改")
    public ResponseWrapper update(@RequestBody TrcjczbVO trcjczbVO) {
        try {
            return trcjczbService.update(trcjczbVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "修改失败", null);
        }
    }

    // 日常检查删除
    @DeleteMapping("/trcjc/delete/{id}")
    @ApiOperation(value = "日常检查删除", notes = "日常检查删除")
    public ResponseWrapper delete(@PathVariable String id) {
        try {
            trcjczbService.delete(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "删除失败", null);
        }
    }

    /**
     * @param dCfxxsjyVO 库点代码
     * @return 仓房信息列表
     * @author WangZL, wangruimin
     * @Description 根据库点代码获取仓房列表
     * @version V2
     */
    @ApiOperation(value = "仓房信息-根据库点代码获取仓房列表", notes = "参数：库点代码")
    @PostMapping(value = "/trcjc/warehouse/selectByEntity")
    public ResponseWrapper selectByEntity(@RequestBody DCfxxsjyVO dCfxxsjyVO) {
        try {
            Map<String,List<Dcfxx>> map = trcjczbService.selectCfxxByEntity(dCfxxsjyVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
    }

    // 详情查询
    @ApiOperation(value = "详情查询", notes = "详情查询")
    @GetMapping("/trcjc/queryDetail/{id}")
    public ResponseWrapper queryDetail(@PathVariable String id) {
        try {
            TrcjczbVO trcjczbVO = trcjczbService.queryDetail(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息成功", trcjczbVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息失败", null);
        }
    }

    // 企业接受检查统计表分页列表查询
    @ApiOperation(value = "企业接受检查统计表分页列表查询", notes = "企业接受检查统计表分页列表查询")
    @PostMapping("/trcjcshqk/qyjsjcQueryPageList")
    public ResponseWrapper qyjsjcQueryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                         @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                         @RequestBody TrcjczbVO trcjczbVO) {
        try {
            List<Qyjsjctjb> list = trcjczbService.qyjsjcQueryPageList(pageSize, pageNum, trcjczbVO);
            PageInfo<Qyjsjctjb> pageInfo = new PageInfo<>(list);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", pageInfo);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
        }
    }

    // 企业接受检查统计表报表导出
    @ApiOperation(value = "企业接受检查统计表报表导出", notes = "企业接受检查统计表报表导出")
    @PostMapping("/trcjcshqk/qyjsjcQueryPageListForDc")
    public ResponseWrapper qyjsjcQueryPageListForDc(@RequestBody TrcjczbVO trcjczbVO) {
        try {
            List<Qyjsjctjb> list = trcjczbService.qyjsjcQueryPageListForBbdc(trcjczbVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
        }
    }

    // 检查单位统计表分页列表查询
    @ApiOperation(value = "检查单位统计表分页列表查询", notes = "检查单位统计表分页列表查询")
    @PostMapping("/trcjcshqk/jcdwjcQueryPageList")
    public ResponseWrapper jcdwjcQueryPageList(@RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                               @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                               @RequestBody TrcjczbVO trcjczbVO) {
        try {
            List<Jcdwtjb> list = trcjczbService.jcdwjcQueryPageList(pageSize, pageNum, trcjczbVO);
            PageInfo<Jcdwtjb> pageInfo = new PageInfo<>(list);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", pageInfo);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
        }
    }

    // 检查单位统计表报表导出
    @ApiOperation(value = "检查单位统计表报表导出", notes = "检查单位统计表报表导出")
    @PostMapping("/trcjcshqk/jcdwjcQueryPageListForDc")
    public ResponseWrapper jcdwjcQueryPageListForDc(@RequestBody TrcjczbVO trcjczbVO) {
        try {
            List<Jcdwtjb> list = trcjczbService.jcdwjcQueryPageListForBbdc(trcjczbVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
        }
    }

    // 根据被检企业名称，年份以及仓房编码查询相关检查时间
    @ApiOperation(value = "根据被检企业名称，年份以及仓房编码查询相关检查时间", notes = "根据被检企业名称，年份以及仓房编码查询相关检查时间")
    @PostMapping("/trcjcshqk/queryJcsjByBjdwmcAndYearAndCfbm")
    public ResponseWrapper queryJcsjByBjdwmcAndYearAndCfbm(@RequestBody TrcjczbVO trcjczbVO) {
        try {
            List<TrcjczbDO> list = trcjczbService.queryJcsjByBjdwmcAndYearAndCfbm(trcjczbVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
        }
    }

}
