/*
 * DailyCheckResultController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-26 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.controller.resultback;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.constant.BaseStatusConstant;
import com.unis.inspectionresult.common.groups.InsertGroup;
import com.unis.inspectionresult.common.groups.UpdateGroup;
import com.unis.inspectionresult.common.vo.BaseKcVO;
import com.unis.inspectionresult.common.vo.ResultApplyQuery;
import com.unis.inspectionresult.common.vo.resultback.*;
import com.unis.inspectionresult.server.service.DailyCheckResultService;
import com.unis.inspectiontask.common.vo.PerformanceQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

/**
 * T_JCJG-检查结果
 * @author lipenghe at 2019-08-26 16:21:29
 */
@RestController
@Slf4j
@RequestMapping("/manager/resultback")
@Api(value = "结果反馈", tags = "检查结果")
public class DailyCheckResultController {

    @Autowired
    private DailyCheckResultService dailyCheckResultService;

    @ApiOperation(value = "结果反馈---检查结果---新增", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(@Validated({InsertGroup.class}) @RequestBody DailyCheckResultVO checkResultVO,
                                                 BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        } else {
            return dailyCheckResultService.insertEntitySelectiveResult(checkResultVO);
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---修改", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(@Validated({UpdateGroup.class}) @RequestBody DailyCheckResultVO checkResultVO,
                                                   BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        } else {
            return dailyCheckResultService.updateByEntitySelectiveResult(checkResultVO, null);
        }
    }

    /*@ApiOperation(value = "结果反馈---检查结果---修改,更新单表专属", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/updateSingleByEntitySelective")
    public ResponseWrapper updateSingleByEntitySelective(@Validated({UpdateGroup.class}) @RequestBody DailyCheckResultVO checkResultVO
        ,BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            DailyCheckResultDO entity=JsonUtils.parse(
            JsonUtils.serialize(checkResultVO),DailyCheckResultDO.class);
            return dailyCheckResultService.updateByEntitySelectiveResult(entity,null);
        }
    }*/

    @ApiOperation(value = "结果反馈---检查结果---更新状态", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(@RequestBody DailyCheckResultVO checkResultVO) {
        if(checkResultVO!=null){
            return dailyCheckResultService.updateStatusByEntityResult(checkResultVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---结果反馈撤回", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/updateBackByEntity")
    public ResponseWrapper updateBackByEntity(@RequestBody DailyCheckResultVO checkResultVO) {
        if(checkResultVO!=null){
            return dailyCheckResultService.updateBackByEntity(checkResultVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---制定任务的撤回,非结果反馈撤回", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/deleteBackByEntity")
    public ResponseWrapper deleteBackByEntity(@RequestBody DailyCheckResultVO checkResultVO) {
        if(checkResultVO!=null){
            return dailyCheckResultService.deleteBackByEntity(checkResultVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---删除", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "jgId", value = "主键id#<主键><非空>结果id(任务id+001)", dataType = "String", paramType = "body", required = false)
    })
    @PostMapping("/dailyCheckResult/deleteByEntity")
    public ResponseWrapper deleteByEntity(@RequestBody DailyCheckResultVO checkResultVO){
        if(checkResultVO!=null){
            checkResultVO.setStatus(BaseStatusConstant.STATUS_DELETED);
            return dailyCheckResultService.deleteByEntityResult(checkResultVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---查询列表", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/selectByEntity")
    public ResponseWrapper selectByEntity(
           @RequestBody DailyCheckResultVO checkResultVO) {
        return dailyCheckResultService.selectByEntityResult(checkResultVO);
    }

    @ApiOperation(value = "结果反馈---检查结果---分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResult/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            ,@RequestBody DailyCheckResultVO checkResultVO) {
        return dailyCheckResultService.selectPageByEntityResult(pageNum, pageSize, checkResultVO, "CREATE_DATE DESC");
    }

    @ApiOperation(value = "结果反馈---检查结果---分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResult/dailyCheckResultYlCplPage")
    public ResponseWrapper dailyCheckResultYlCplPage(
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            ,@RequestBody DailyCheckResultVO checkResultVO) {
        return dailyCheckResultService.dailyCheckResultYlCplPage(pageNum,pageSize
                , checkResultVO,"CREATE_DATE DESC");
    }

    @ApiOperation(value = "结果反馈---检查结果---分页查询列表(可视化),pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResult/dailyCheckResultPageForKSH")
    public ResponseWrapper dailyCheckResultPageForKSH(
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            ,@RequestBody DailyCheckSearchVO dailyCheckSearchVO) {
        return dailyCheckResultService.dailyCheckResultPageForKSH(pageNum,pageSize
                , dailyCheckSearchVO);
    }

    @ApiOperation(value = "结果反馈---检查结果---综合查询分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResult/resultList")
    public ResponseWrapper resultList(
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            ,@RequestBody ResultApplyQuery resultApplyQuery) {
        return dailyCheckResultService.resultList(pageNum,pageSize
                , resultApplyQuery,"CREATE_DATE DESC");
    }

    @ApiOperation(value = "结果反馈---检查结果---综合查询分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResult/resultListDis")
    public ResponseWrapper resultListDis(
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            ,@RequestBody ResultApplyQuery resultApplyQuery) {
        return dailyCheckResultService.resultListDis(pageNum,pageSize
                , resultApplyQuery,"CREATE_DATE DESC");
    }


    @ApiOperation(value = "结果反馈---检查组检查结果---分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResult/selectTeamPageByEntity")
    public ResponseWrapper selectTeamPageByEntity(
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            ,@RequestBody DailyCheckResultVO checkResultVO) {
        return dailyCheckResultService.selectTeamPageByEntityResult(pageNum,pageSize
                , checkResultVO,"JG_ID DESC");
    }

    @ApiOperation(value = "结果反馈---检查结果---当前组织的分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
            @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResult/selectOwnerPageByEntity")
    public ResponseWrapper selectOwnerPageByEntity(
            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
            ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
            ,@RequestBody DailyCheckResultVO checkResultVO) {
        //应要求注释掉
        //checkResultVO.setBjdwId(CurrentUtil.getOrgId());
        return dailyCheckResultService.selectPageByEntityResult(pageNum,pageSize
                , checkResultVO,"CREATE_DATE DESC");
    }

    @ApiOperation(value = "结果反馈---检查结果---查询详情", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "jgId", value = "主键id#<主键><非空>结果id(任务id+001)", dataType = "String", paramType = "body", required = false)
    })
    @PostMapping("/dailyCheckResult/selectById")
    public ResponseWrapper selectById(@RequestBody DailyCheckResultVO checkResultVO){
        if(checkResultVO!=null){
            return dailyCheckResultService.selectByIdResult(checkResultVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---查询简单详情", notes = "结果反馈")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "jgId", value = "主键id#<主键><非空>结果id(任务id+001)", dataType = "String", paramType = "body", required = false)
    })
    @PostMapping("/dailyCheckResult/selectSingleByIdResult")
    public ResponseWrapper selectSingleByIdResult(@RequestBody DailyCheckResultVO checkResultVO){
        if(checkResultVO!=null){
            return dailyCheckResultService.selectSingleByIdResult(checkResultVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    /*@ApiOperation(value = "结果反馈---检查结果---初始化数据", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/selectInitData")
    public ResponseWrapper selectInitData(@RequestBody DailyCheckResultVO checkResultVO){
        if(checkResultVO!=null){
            return dailyCheckResultService.selectInitDataResult(checkResultVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }*/

    /**
     * 获取所有列表
     * @param checkResultQueryVO
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "结果列表", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/{pageNum}/{pageSize}")
    public ResponseWrapper getPageList(@RequestBody DailyCheckResultQueryVO checkResultQueryVO,
                                       @PathVariable("pageNum") Integer pageNum,
                                       @PathVariable("pageSize") Integer pageSize){
        try {
            PageInfo<DailyCheckResultQJVO> allList = dailyCheckResultService.getAllList(checkResultQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "获取列表成功", allList);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取列表失败", null);
        }
    }
    /*
     * @Title: getQyZgNotes
     * @Description: 方法描述:(企业整改数据统计 - 整改)
     * @param @param checkResultVO
     * @param @return    设定文件
     * @return ResponseWrapper    返回类型
     * @throws
     */
    @ApiOperation(value = "企业整改数据统计 - 整改", notes = "企业整改:年份")
    @GetMapping("/dailyCheckResult/QyZgNotes/{year}")
    public ResponseWrapper getQyZgNotes(@PathVariable String year) {
        if(year!=null){
            return dailyCheckResultService.selectQyZgLists(year);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---检查结果【条件导出查询】", notes = "结果反馈")
    @PostMapping("/dailyCheckResult/inspectionResultExport")
    public ResponseWrapper inspectionResultExport(
            @RequestBody DailyCheckResultVO checkResultVO) {
        return dailyCheckResultService.inspectionResultExport(
                checkResultVO,"JG_ID DESC");
    }


    @ApiOperation(value = "结果反馈---检查结果---根据rwId,bjdwId查询检查时间", notes = "检查时间")
    @PostMapping("/dailyCheckResult/inspectionTime/{rwId}/{bjdwId}")
    public ResponseWrapper getInspectionTime(@PathVariable(value = "rwId") String rwId,
                                             @PathVariable(value = "bjdwId") String bjdwId){
        try {
        	DailyCheckInspectionTimeAndResultIdVO jcsj = dailyCheckResultService.getInspectionTime(rwId,bjdwId);
            return ResponseWrapper.success(HttpStatus.OK.value(),"查询成功",jcsj);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---根据任务时间查询特定状态结果数据", notes = "根据任务时间查询特定状态结果数据")
    @PostMapping("/dailyCheckResult/inspectionList")
    public ResponseWrapper getinspectionList(@RequestBody PerformanceQueryVO performanceQueryVO){
        try {
            List<DailyCheckResultPerformanceVO> dailyCheckResultVOList = dailyCheckResultService.getinspectionList(performanceQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(),"查询成功",dailyCheckResultVOList);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---根据结果id列表结果数据", notes = "根据结果id列表结果数据")
    @PostMapping("/dailyCheckResult/inspectionListByjgIdList")
    public ResponseWrapper getInspectionListByjgIdList(@RequestBody PerformanceQueryVO performanceQueryVO){
        try {
            List<DailyCheckResultVO> dailyCheckResultVOList = dailyCheckResultService.getInspectionListByjgIdList(performanceQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(),"查询成功",dailyCheckResultVOList);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---根据结果id列表分页查询数据", notes = "根据结果id列表分页查询")
    @PostMapping("/dailyCheckResult/inspectionResultPageByjgIdList")
    public ResponseWrapper getInspectionResultPageByjgIdList(@RequestBody PerformanceQueryVO performanceQueryVO){
        try {
        	PageInfo<DailyCheckResultVO> dailyCheckResultVOList = dailyCheckResultService.getInspectionResultPageByjgIdList(performanceQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(),"查询成功",dailyCheckResultVOList);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
        }
    }

    @ApiOperation(value = "结果反馈---调整流程---新增", notes = "调整流程新增")
    @PostMapping("/dailyCheckResult/additionProcessAdjustment")
    public ResponseWrapper insertProcessAdjustment(@RequestBody DailyCheckProcessAdjustmentAddVO record) {
        return dailyCheckResultService.insertProcessAdjustment(record)
                ? ResponseWrapper.success(HttpStatus.OK.value(), "调整流程新增成功", null)
                : ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "调整流程新增失败", null);
    }

    @ApiOperation(value = "结果反馈---调整流程---修改", notes = "调整流程修改")
    @PostMapping("/dailyCheckResult/modificationProcessAdjustment")
    public ResponseWrapper updateProcessAdjustment(@RequestBody DailyCheckProcessAdjustmentAddVO record) {
        return dailyCheckResultService.updateProcessAdjustment(record)
                ? ResponseWrapper.success(HttpStatus.OK.value(), "调整流程修改成功", null)
                : ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "调整流程修改失败", null);
    }

    @ApiOperation(value = "结果反馈---调整流程---审核", notes = "调整流程审核")
    @PostMapping("/dailyCheckResult/auditProcessAdjustment")
    public ResponseWrapper auditProcessAdjustment(@RequestBody DailyCheckProcessAdjustmentAuditVO record) {
        return dailyCheckResultService.auditProcessAdjustment(record)
                ? ResponseWrapper.success(HttpStatus.OK.value(), "调整流程修改成功", null)
                : ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "调整流程修改失败", null);
    }

    @ApiOperation(value = "结果反馈---调整流程---查看详情", notes = "结果反馈---调整流程---查看详情")
    @GetMapping("/dailyCheckResult/viewProcessAdjustment/{checkResultId}")
    public ResponseWrapper viewProcessAdjustment(@PathVariable(name = "checkResultId") String checkResultId) {
        return dailyCheckResultService.viewProcessAdjustment(checkResultId) != null
                ? ResponseWrapper.success(HttpStatus.OK.value(), "调整流程查看详情成功",
                dailyCheckResultService.viewProcessAdjustment(checkResultId))
                : ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "调整流程查看详情失败", null);
    }

    @ApiOperation(value = "结果反馈---检查结果---根据任务时间查询特定状态结果数据", notes = "根据任务时间查询特定状态结果数据")
    @PostMapping("/dailyCheckResult/developmentSituation")
    public ResponseWrapper developmentSituation(@RequestBody DevelopmentSituationQueryVO developmentSituationQueryVO){
        try {
            DevelopmentSituationVO developmentSituation = dailyCheckResultService.developmentSituation(developmentSituationQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(),"查询成功",developmentSituation);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
        }
    }

    @ApiOperation(value = "结果反馈---检查结果---根据任务时间查询任务列表", notes = "根据任务时间查询任务列表")
    @PostMapping("/dailyCheckResult/developmentSituationByRwIdList")
    public ResponseWrapper developmentSituationByRwIdList(@RequestBody DevelopmentSituationQueryVO developmentSituationQueryVO){
        try {
            List<String> rwIdList = dailyCheckResultService.developmentSituationByRwIdList(developmentSituationQueryVO);
            return ResponseWrapper.success(HttpStatus.OK.value(),"查询成功",rwIdList);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"查询信息失败",null);
        }
    }

	/**
	 *
	 * @Description: 展示检查结果列表通过计划Id
	 * @author: 王帅
	 * @param: @param  planId
	 * @param: @return 参数
	 * @return: List<DailyCheckResultVO> 返回类型
	 */
	@ApiOperation(value = "展示检查结果列表通过计划Id", notes = "展示检查结果列表通过计划Id")
	@ApiImplicitParam(name = "planId", value = "计划主键", paramType = "query", required = true)
	@GetMapping("checkResultListByPlanId")
	public ResponseEntity<List<DailyCheckResultByPlanShowVO>> getCheckResultListByPlanId(
			@RequestParam(name = "planId", required = true) String planId) {
		List<DailyCheckResultByPlanShowVO> showVOList = null;
		try {
			showVOList = dailyCheckResultService.getCheckResultListByPlanId(planId);
		} catch (Exception e) {
			return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
		}

		return ResponseEntity.status(HttpStatus.OK).body(showVOList);
	}


	/**
	 *
	 * @Description: 获取监管区域
	 * @author: 王帅
	 * @param: @param  orgId
	 * @param: @return 参数
	 * @return: List<DailyCheckTerritorialSupervisionVO> 返回类型
	 */
	@ApiOperation(value = "获取监管区域", notes = "获取监管区域")
	@ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query", required = true)
	@GetMapping("territorialSupervisionList")
	public ResponseWrapper getTerritorialSupervisionByOrgId(
			@RequestParam(name = "orgId", required = true) String orgId) {
		return ResponseWrapper.success(dailyCheckResultService.getTerritorialSupervisionByOrgId(orgId));
	}


	 @ApiOperation(value = "结果反馈---检查结果---查询企业近3个月检查记录", notes = "结果反馈")
	    @PostMapping("/dailyCheckResultList/{bjdwId}")
	    public ResponseWrapper dailyCheckResultList(@PathVariable("bjdwId") String bjdwId){
	        return dailyCheckResultService.dailyCheckResultList(bjdwId);
	    }

	 @ApiOperation(value = "结果反馈---企业原粮列表", notes = "结果反馈")
	    @PostMapping("/selectKcxx/{tyshxydm}")
	    public ResponseWrapper selectKcxx(@PathVariable("tyshxydm") String tyshxydm){
	        return ResponseWrapper.success(dailyCheckResultService.selectKcxx(tyshxydm));
	    }

	 @ApiOperation(value = "结果反馈---企业成品粮列表", notes = "结果反馈")
	    @PostMapping("/selectChengPinKc/{tyshxydm}")
	    public ResponseWrapper selectChengPinKc(@PathVariable("tyshxydm") String tyshxydm){
	        return ResponseWrapper.success(dailyCheckResultService.selectChengPinKc(tyshxydm));
	    }

    @ApiOperation(value = "结果反馈---企业成品粮列表", notes = "结果反馈")
    @PostMapping("/selectBatchWd")
    public ResponseWrapper selectBatchWd(@RequestBody List<String> cfbhList){
        return ResponseWrapper.success(dailyCheckResultService.selectBatchWd(cfbhList));
    }
}


