/*
 * DailyCheckResultDetailController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-30 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.controller.resultback;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.groups.InsertGroup;
import com.unis.inspectionresult.common.groups.UpdateGroup;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultDetailVO;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckResultDetailDO;
import com.unis.inspectionresult.server.service.DailyCheckResultDetailService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * T_BDJLZB-表单记录主表
 * @author lipenghe at 2019-08-30 16:13:16
 */
@RestController
@RequestMapping("/manager/resultback")
@Api(value = "结果反馈", tags = "表单记录主表")
public class DailyCheckResultDetailController {

    @Autowired
    private DailyCheckResultDetailService dailyCheckResultDetailService;

    @ApiOperation(value = "结果反馈---表单记录主表---新增", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(@Validated({InsertGroup.class}) @RequestBody DailyCheckResultDetailVO resultDetailVO
        ,BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return dailyCheckResultDetailService.insertEntitySelectiveResult(resultDetailVO);
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---修改", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(@Validated({UpdateGroup.class}) @RequestBody DailyCheckResultDetailVO resultDetailVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return dailyCheckResultDetailService.updateByEntitySelectiveResult(resultDetailVO,null);
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---修改,更新单表专属", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/updateSingleByEntitySelective")
    public ResponseWrapper updateSingleByEntitySelective(@Validated({UpdateGroup.class}) @RequestBody DailyCheckResultDetailVO resultDetailVO
        ,BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            DailyCheckResultDetailDO entity=JsonUtils.parse(
                JsonUtils.serialize(resultDetailVO),DailyCheckResultDetailDO.class);
            return dailyCheckResultDetailService.updateByEntitySelectiveResult(entity,null);
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---更新状态", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(@RequestBody DailyCheckResultDetailVO resultDetailVO) {
        if(resultDetailVO!=null){
            return dailyCheckResultDetailService.updateStatusByEntityResult(resultDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---更新为提交", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/updateSubmit")
    public ResponseWrapper updateSubmit(@RequestBody DailyCheckResultDetailVO resultDetailVO) {
        if(resultDetailVO!=null){
            return dailyCheckResultDetailService.updateByEntitySelectiveResult(resultDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---更新为审核通过", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/updateReview")
    public ResponseWrapper updateReview(@RequestBody DailyCheckResultDetailVO resultDetailVO) {
        if(resultDetailVO!=null){
            return dailyCheckResultDetailService.updateByEntitySelectiveResult(resultDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---更新为驳回", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/updateRefused")
    public ResponseWrapper updateRefused(@RequestBody DailyCheckResultDetailVO resultDetailVO) {
        if(resultDetailVO!=null){
            return dailyCheckResultDetailService.updateByEntitySelectiveResult(resultDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---删除", notes = "结果反馈")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "bdzbid", value = "表单主表id#<主键><非空>", dataType = "String", paramType = "body", required = false)
    })
    @PostMapping("/dailyCheckResultDetail/deleteByEntity")
    public ResponseWrapper deleteByEntity(@RequestBody DailyCheckResultDetailVO resultDetailVO){
        if(resultDetailVO!=null){
            return dailyCheckResultDetailService.deleteByEntityResult(resultDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
        @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/dailyCheckResultDetail/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody DailyCheckResultDetailVO resultDetailVO) {
            return dailyCheckResultDetailService.selectPageByEntityResult(pageNum,pageSize
            , resultDetailVO,"BDZBID DESC");
    }

    @ApiOperation(value = "结果反馈---表单记录主表---查询详情", notes = "结果反馈")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "bdzbid", value = "表单主表id#<主键><非空>", dataType = "String", paramType = "body", required = false)
    })
    @PostMapping("/dailyCheckResultDetail/selectById")
    public ResponseWrapper selectById(@RequestBody DailyCheckResultDetailVO resultDetailVO){
        if(resultDetailVO!=null){
            return dailyCheckResultDetailService.selectByIdResult(resultDetailVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---表单记录主表---初始化数据", notes = "结果反馈")
    @PostMapping("/dailyCheckResultDetail/selectInitData")
    public ResponseWrapper selectInitData(@RequestBody DailyCheckResultDetailVO resultDetailVO){
        if(resultDetailVO!=null){
            return dailyCheckResultDetailService.selectInitDataResult(resultDetailVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
