/*
 * FormDetailController.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-30 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.controller.resultback;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.groups.InsertGroup;
import com.unis.inspectionresult.common.groups.UpdateGroup;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.resultback.FormDetailVO;
import com.unis.inspectionresult.server.entity.resultback.FormDetailDO;
import com.unis.inspectionresult.server.service.FormDetailService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * T_BDJLMX-储备粮公司-表单记录明细表
 * @author lipenghe at 2019-08-30 16:13:16
 */
@RestController
@RequestMapping("/manager/resultback")
@Api(value = "结果反馈", tags = "储备粮公司-表单记录明细表")
public class FormDetailController {

    @Autowired
    private FormDetailService formDetailService;

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---新增", notes = "结果反馈")
    @PostMapping("/formDetail/insertEntitySelective")
    public ResponseWrapper insertEntitySelective(@Validated({InsertGroup.class}) @RequestBody FormDetailVO formDetailVO
        , BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return formDetailService.insertEntitySelectiveResult(formDetailVO);
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---修改", notes = "结果反馈")
    @PostMapping("/formDetail/updateByEntitySelective")
    public ResponseWrapper updateByEntitySelective(@Validated({UpdateGroup.class}) @RequestBody FormDetailVO formDetailVO
        ,BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            return formDetailService.updateByEntitySelectiveResult(formDetailVO,null);
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---修改,更新单表专属", notes = "结果反馈")
    @PostMapping("/formDetail/updateSingleByEntitySelective")
    public ResponseWrapper updateSingleByEntitySelective(@Validated({UpdateGroup.class}) @RequestBody FormDetailVO formDetailVO
        ,BindingResult bindingResult) {
        if(bindingResult.hasErrors()){
            return ResponseWrapper.validateFail(bindingResult.getAllErrors());
        }else{
            FormDetailDO entity=JsonUtils.parse(
            JsonUtils.serialize(formDetailVO),FormDetailDO.class);
            return formDetailService.updateByEntitySelectiveResult(entity,null);
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---更新状态", notes = "结果反馈")
    @PostMapping("/formDetail/updateStatusByEntity")
    public ResponseWrapper updateStatusByEntity(@RequestBody FormDetailVO formDetailVO) {
        if(formDetailVO!=null){
            return formDetailService.updateStatusByEntityResult(formDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---更新为提交", notes = "结果反馈")
    @PostMapping("/formDetail/updateSubmit")
    public ResponseWrapper updateSubmit(@RequestBody FormDetailVO formDetailVO) {
        if(formDetailVO!=null){
            return formDetailService.updateByEntitySelectiveResult(formDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---更新为审核通过", notes = "结果反馈")
    @PostMapping("/formDetail/updateReview")
    public ResponseWrapper updateReview(@RequestBody FormDetailVO formDetailVO) {
        if(formDetailVO!=null){
            return formDetailService.updateByEntitySelectiveResult(formDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---更新为驳回", notes = "结果反馈")
    @PostMapping("/formDetail/updateRefused")
    public ResponseWrapper updateRefused(@RequestBody FormDetailVO formDetailVO) {
        if(formDetailVO!=null){
            return formDetailService.updateByEntitySelectiveResult(formDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---删除", notes = "结果反馈")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "bdmxid", value = "表单明细id#<主键><非空>", dataType = "String", paramType = "body", required = false)
    })
    @PostMapping("/formDetail/deleteByEntity")
    public ResponseWrapper deleteByEntity(@RequestBody FormDetailVO formDetailVO){
        if(formDetailVO!=null){
            return formDetailService.deleteByEntityResult(formDetailVO,null);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---分页查询列表,pageSize,pageNum从url传", notes = "结果反馈")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageSize", value = "分页大小", dataType = "int", paramType = "query"),
        @ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query")
    })
    @PostMapping("/formDetail/selectPageByEntity")
    public ResponseWrapper selectPageByEntity(
        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum
        ,@RequestParam(value = "pageSize", defaultValue = "10") int pageSize
        ,@RequestBody FormDetailVO formDetailVO) {
            return formDetailService.selectPageByEntityResult(pageNum,pageSize
            , formDetailVO,"BDMXID DESC");
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---查询详情", notes = "结果反馈")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "bdmxid", value = "表单明细id#<主键><非空>", dataType = "String", paramType = "body", required = false)
    })
    @PostMapping("/formDetail/selectById")
    public ResponseWrapper selectById(@RequestBody FormDetailVO formDetailVO){
        if(formDetailVO!=null){
            return formDetailService.selectByIdResult(formDetailVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }

    @ApiOperation(value = "结果反馈---储备粮公司-表单记录明细表---初始化数据", notes = "结果反馈")
    @PostMapping("/formDetail/selectInitData")
    public ResponseWrapper selectInitData(@RequestBody FormDetailVO formDetailVO){
        if(formDetailVO!=null){
            return formDetailService.selectInitDataResult(formDetailVO);
        }else{
            return ResponseWrapper.invalid();
        }
    }
}
