package com.unis.inspectionresult.server.domain;


import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.inspectionresult.common.vo.CheckWorkLogQueryVO;
import com.unis.inspectionresult.common.vo.CheckWorkLogVO;
import com.unis.inspectionresult.server.dao.CheckWorkLogDao;
import com.unis.inspectionresult.server.entity.CheckWorkLogDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title CheckWorkLogDomain
 * @ProjectName 持久化
 * @Description
 * @date 2019/07/22 17点26分
 */
@Component
public class CheckWorkLogDomain extends BaseDomain {

	@Autowired
	private CheckWorkLogDao checkWorkLogDao;

	/**
	 * 获取检查工作日志列表
	 * @param checkWorkLogVO
	 * @return
	 */
	public List<CheckWorkLogVO> getCheckWorkLogList(CheckWorkLogQueryVO checkWorkLogVO) {
		checkWorkLogVO.setOrgId(CurrentUtil.getOrgId());
		return checkWorkLogDao.getCheckWorkLogList(checkWorkLogVO);
	}

	/**
	 * 新增检查工作日志信息
	 * @param checkWorkLogVO
	 * @return
	 */
	public CheckWorkLogVO insert(CheckWorkLogVO checkWorkLogVO) {
		//进行传递参数copy
		CheckWorkLogDO checkWorkLogDO = new CheckWorkLogDO();
		//获取最大主键ID
		Integer id = checkWorkLogDao.selectMaxId();
		if (id == null) {
			id = 0;
		}
		checkWorkLogVO.setId(id+1);
		checkWorkLogVO.setStatus(1);
		checkWorkLogVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(checkWorkLogVO, checkWorkLogDO);
		checkWorkLogDO.setOrgId(CurrentUtil.getOrgId());
		checkWorkLogDao.insert(checkWorkLogDO);
		return checkWorkLogVO;
	}

	/**
	 * 根据检查工作日志ID获取检查工作日志信息
	 * @param id
	 * @return
	 */
	public CheckWorkLogVO getCheckWorkLogInfoById(Integer id) {
		CheckWorkLogDO checkWorkLogDO = checkWorkLogDao.getCheckWorkLogInfo(id);
		if(checkWorkLogDO == null) {
			return null;
		}
		CheckWorkLogVO checkWorkLogVO = new CheckWorkLogVO();
		LsBeanUtils.copyAllProperties(checkWorkLogDO, checkWorkLogVO);
		return checkWorkLogVO;
	}

	/**
	 * 更新检查工作日志信息
	 * @param checkWorkLogVO
	 * @return
	 */
	public int update(CheckWorkLogVO checkWorkLogVO) {
		CheckWorkLogDO checkWorkLogDO = checkWorkLogDao.getCheckWorkLogInfo(checkWorkLogVO.getId());
		if (checkWorkLogDO == null) {
			return 0;
		}
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(checkWorkLogVO, checkWorkLogDO);
		return checkWorkLogDao.update(checkWorkLogDO);
	}

}
