package com.unis.inspectionresult.server.domain;

import com.unis.base.common.util.IdWorkerUtils;
import com.unis.common.utils.LsBeanUtils;
import com.unis.inspectionresult.common.vo.FileVO;
import com.unis.inspectionresult.server.dao.FileDao;
import com.unis.inspectionresult.server.entity.FileDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title FileDomain
 * @ProjectName 持久化
 * @Description
 * @date 2019/07/22 17点26分
 */
@Component
public class FileDomain extends BaseDomain {

	@Autowired
	private FileDao fileDao;

	@Autowired
	private IdWorkerUtils idWorker;

	/**
	 * 新增文件列表
	 * @param fileVOList
	 * @param sjId
	 * @return
	 */
	public void insertFileList(List<FileVO> fileVOList,String sjId) {
		if (fileVOList != null && fileVOList.size() > 0) {
			for (FileVO fileVO : fileVOList) {
				this.insertFile(fileVO,sjId);
			}
		}
	}

	/**
	 * 新增文件信息
	 * @param fileVO
	 * @param sjId
	 * @return
	 */
	public void insertFile(FileVO fileVO,String sjId) {
		FileDO fileDO = new FileDO();
		fileVO.setSjId(sjId);
		fileVO.setStatus(1);
		fileVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(fileVO, fileDO);
		long id = idWorker.nextId();
		fileDO.setId(id + "");
		fileDao.insert(fileDO);
	}


	/**
 	* 更新文件信息
	* @param fileVOList
 	* @param sjId
 	* @return
 	*/
	public void updateFileList(List<FileVO> fileVOList,String sjId) {
		if (fileVOList != null && fileVOList.size() > 0) {
			for (FileVO fileVO : fileVOList) {
				FileDO fileDO = fileDao.getFileInfo(fileVO.getId());
				if (fileDO == null) {
					if (fileVO.getFileId() != null) {
						this.insertFile(fileVO, sjId);
					}
				} else {
					LsBeanUtils.copyAllProperties(fileVO, fileDO);
					fileDao.update(fileDO);
				}
			}
		}
	}

	/**
	 * 查询文件列表
	 * @param sjId
	 * @return
	 */
	public List<FileVO> getFileList(String sjId) {
		List<FileVO> fileVOList = new ArrayList<>();
		List<FileDO> fileDOList = fileDao.getFileListBySjId(sjId);
		if (fileDOList != null) {
			for (FileDO fileDO : fileDOList) {
				FileVO fileVO = new FileVO();
				LsBeanUtils.copyAllProperties(fileDO, fileVO);
				fileVOList.add(fileVO);
			}
		}
		return fileVOList;
	}

}
