package com.unis.inspectionresult.server.domain;

import com.unis.common.utils.LsBeanUtils;
import com.unis.inspectionresult.common.vo.FileVO;
import com.unis.inspectionresult.common.vo.RectificationAcceptanceVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;
import com.unis.inspectionresult.server.dao.DailyCheckResultDao;
import com.unis.inspectionresult.server.dao.FileDao;
import com.unis.inspectionresult.server.dao.RectificationAcceptanceDao;
import com.unis.inspectionresult.server.entity.FileDO;
import com.unis.inspectionresult.server.entity.RectificationAcceptanceDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title RectificationAcceptanceDomain
 * @ProjectName 持久化
 * @Description
 * @date 2019/07/22 17点26分
 */
@Component
public class RectificationAcceptanceDomain extends BaseDomain {

	@Autowired
	private RectificationAcceptanceDao rectificationAcceptanceDao;

	@Autowired
	private FileDomain fileDomain;

	@Autowired
	private DailyCheckResultDao dailyCheckResultDao;

	/**
	 * 新增整改验收单信息
	 * @param rectificationAcceptanceVO
	 * @return
	 */
	public RectificationAcceptanceVO insert(RectificationAcceptanceVO rectificationAcceptanceVO) {
		//查询结果信息是否存在
		DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
		dailyCheckResultVO.setJgId(rectificationAcceptanceVO.getJgId());
		dailyCheckResultVO.setStatus(1);
		DailyCheckResultVO dailyCheckResultDO = dailyCheckResultDao.selectById(dailyCheckResultVO);
		if(dailyCheckResultDO==null) {
			return null;
		}
		//进行传递参数copy
		RectificationAcceptanceDO rectificationAcceptanceDO = new RectificationAcceptanceDO();
		//主键id  验收单id(结果id +YS+001)
		String ysdId = getMaxCodeById(rectificationAcceptanceDao.getMaxCodeById(rectificationAcceptanceVO.getJgId()), rectificationAcceptanceVO.getJgId() + "YS", 3);
		rectificationAcceptanceVO.setYsdId(ysdId);
		rectificationAcceptanceVO.setStatus(1);
		rectificationAcceptanceVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(rectificationAcceptanceVO, rectificationAcceptanceDO);
		rectificationAcceptanceDao.insert(rectificationAcceptanceDO);
		fileDomain.insertFileList(rectificationAcceptanceVO.getFileVOList(),ysdId);
		return rectificationAcceptanceVO;
	}


	/**
 	* 更新整改验收单信息
 	* @param rectificationAcceptanceVO
 	* @return
 	*/
	public int update(RectificationAcceptanceVO rectificationAcceptanceVO) {
		String ysdId = rectificationAcceptanceVO.getYsdId();
		RectificationAcceptanceDO rectificationAcceptanceDO = rectificationAcceptanceDao.getRectificationAcceptanceInfoByYsdId(ysdId);
		if (rectificationAcceptanceDO == null) {
			return 0;
		} else if (!rectificationAcceptanceVO.getJgId().equals(rectificationAcceptanceDO.getJgId())) {
			return -1;
		}
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(rectificationAcceptanceVO, rectificationAcceptanceDO);
		fileDomain.updateFileList(rectificationAcceptanceVO.getFileVOList(),ysdId);
		return rectificationAcceptanceDao.update(rectificationAcceptanceDO);
	}

	/**
	 * 根据结果ID获取整改验收单列表
	 * @param jgId
	 * @return
	 */
	public List<RectificationAcceptanceVO> getRectificationAcceptanceListInfoByJgId(String jgId) {
		List<RectificationAcceptanceDO> rectificationAcceptanceDOList = rectificationAcceptanceDao.getRectificationAcceptanceListInfoByJgId(jgId);
		List<RectificationAcceptanceVO> rectificationAcceptanceVOList = new ArrayList<>();
		if(rectificationAcceptanceDOList == null) {
			return rectificationAcceptanceVOList;
		}
		for (RectificationAcceptanceDO rectificationAcceptanceDO : rectificationAcceptanceDOList) {
			RectificationAcceptanceVO rectificationAcceptanceVO = new RectificationAcceptanceVO();
			LsBeanUtils.copyAllProperties(rectificationAcceptanceDO, rectificationAcceptanceVO);
			rectificationAcceptanceVO.setFileVOList(fileDomain.getFileList(rectificationAcceptanceDO.getYsdId()));
			rectificationAcceptanceVOList.add(rectificationAcceptanceVO);
		}
		return rectificationAcceptanceVOList;
	}

	/**
 	* 根据验收单ID获取整改验收单信息
 	* @param ysdId
 	* @return
 	*/
	public RectificationAcceptanceVO getRectificationAcceptanceInfoByYsdId(String ysdId) {
		RectificationAcceptanceDO rectificationAcceptanceDO = rectificationAcceptanceDao.getRectificationAcceptanceInfoByYsdId(ysdId);
		if(rectificationAcceptanceDO == null) {
			return null;
		}
		RectificationAcceptanceVO rectificationAcceptanceVO = new RectificationAcceptanceVO();
		LsBeanUtils.copyAllProperties(rectificationAcceptanceDO, rectificationAcceptanceVO);
		rectificationAcceptanceVO.setFileVOList(fileDomain.getFileList(ysdId));
		return rectificationAcceptanceVO;
	}


	public void deleteGz(String jgId) {
		rectificationAcceptanceDao.deleteGz(jgId);
	}


}
