package com.unis.inspectionresult.server.domain;

import com.unis.common.utils.LsBeanUtils;
import com.unis.inspectionresult.common.vo.RectificationDetailsVO;
import com.unis.inspectionresult.server.dao.RectificationDetailsDao;
import com.unis.inspectionresult.server.entity.RectificationDetailsDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title RectificationDetailsDomain
 * @ProjectName 持久化
 * @Description
 * @date 2019/07/22 17点26分
 */
@Component
public class RectificationDetailsDomain extends BaseDomain {

	@Autowired
	private RectificationDetailsDao rectificationDetailsDao;

	/**
	 * 新增整改详情列表
	 * @param rectificationDetailsVOList
	 * @param tzdId
	 * @return
	 */
	public void insertRectificationDetailsList(List<RectificationDetailsVO> rectificationDetailsVOList,String tzdId) {
		if (rectificationDetailsVOList != null && rectificationDetailsVOList.size() > 0) {
			for (RectificationDetailsVO rectificationDetailsVO : rectificationDetailsVOList) {
				this.insertRectificationDetails(rectificationDetailsVO,tzdId);
			}
		}
	}

	/**
	 * 新增整改详情信息
	 * @param rectificationDetailsVO
	 * @param tzdId
	 * @return
	 */
	public void insertRectificationDetails(RectificationDetailsVO rectificationDetailsVO,String tzdId) {
		RectificationDetailsDO rectificationDetailsDO = new RectificationDetailsDO();
		Integer id = rectificationDetailsDao.selectMaxId();
		if (id == null) {
			id = 0;
		}
		rectificationDetailsVO.setId(id + 1);
		rectificationDetailsVO.setTzdId(tzdId);
		rectificationDetailsVO.setStatus(1);
		rectificationDetailsVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(rectificationDetailsVO, rectificationDetailsDO);
		rectificationDetailsDao.insert(rectificationDetailsDO);
	}


	/**
 	* 更新整改详情信息
	* @param rectificationDetailsVOList
 	* @param tzdId
 	* @return
 	*/
	public void updateRectificationDetailsList(List<RectificationDetailsVO> rectificationDetailsVOList,String tzdId) {
		if (rectificationDetailsVOList != null && rectificationDetailsVOList.size() > 0) {
			for (RectificationDetailsVO rectificationDetailsVO : rectificationDetailsVOList) {
				RectificationDetailsDO rectificationDetailsDO = rectificationDetailsDao.getRectificationDetailsInfo(rectificationDetailsVO.getId());
				if (rectificationDetailsDO == null) {
					if (rectificationDetailsVO.getZgxq() != null) {
						this.insertRectificationDetails(rectificationDetailsVO, tzdId);
					}
				} else {
					LsBeanUtils.copyAllProperties(rectificationDetailsVO, rectificationDetailsDO);
					rectificationDetailsDao.update(rectificationDetailsDO);
				}
			}
		}
	}

	/**
	 * 查询整改详情列表
	 * @param tzdId
	 * @return
	 */
	public List<RectificationDetailsVO> getRectificationDetailsList(String tzdId) {
		List<RectificationDetailsVO> rectificationDetailsVOList = new ArrayList<>();
		List<RectificationDetailsDO> rectificationDetailsDOList = rectificationDetailsDao.getRectificationDetailsListByTzdId(tzdId);
		if (rectificationDetailsDOList != null && rectificationDetailsDOList.size() > 0) {
			for (RectificationDetailsDO rectificationDetailsDO : rectificationDetailsDOList) {
				RectificationDetailsVO rectificationDetailsVO = new RectificationDetailsVO();
				LsBeanUtils.copyAllProperties(rectificationDetailsDO, rectificationDetailsVO);
				rectificationDetailsVOList.add(rectificationDetailsVO);
			}
		}
		return rectificationDetailsVOList;
	}

}
