package com.unis.inspectionresult.server.domain;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.inspectionresult.common.vo.ApprovalOpinionsVO;
import com.unis.inspectionresult.common.vo.FileVO;
import com.unis.inspectionresult.common.vo.RectificationFeedbackDetailedVO;
import com.unis.inspectionresult.common.vo.RectificationFeedbackVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;
import com.unis.inspectionresult.server.dao.*;
import com.unis.inspectionresult.server.entity.ApprovalOpinionsDO;
import com.unis.inspectionresult.server.entity.FileDO;
import com.unis.inspectionresult.server.entity.RectificationFeedbackDetailedDO;
import com.unis.inspectionresult.server.entity.RectificationFeedbackDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title RectificationFeedbackDomain
 * @ProjectName 持久化
 * @Description
 * @date 2019/07/22 17点26分
 */
@Component
public class RectificationFeedbackDomain extends BaseDomain {

	@Autowired
	private RectificationFeedbackDao rectificationFeedbackDao;

	@Autowired
	private RectificationFeedbackDetailedDomain rectificationFeedbackDetailedDomain;

	@Autowired
	private FileDomain fileDomain;

	@Autowired
	private ApprovalOpinionsDomain approvalOpinionsDomain;

	@Autowired
	private DailyCheckResultDao dailyCheckResultDao;

	/**
	 * 新增整改反馈单信息
	 * @param rectificationFeedbackVO
	 * @return
	 */
	public RectificationFeedbackVO insert(RectificationFeedbackVO rectificationFeedbackVO) {
		//查询结果信息是否存在
		DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
		dailyCheckResultVO.setJgId(rectificationFeedbackVO.getJgId());
		dailyCheckResultVO.setStatus(1);
		DailyCheckResultVO dailyCheckResultDO = dailyCheckResultDao.selectById(dailyCheckResultVO);
		if(dailyCheckResultDO==null) {
			return null;
		}
		//进行传递参数copy
		RectificationFeedbackDO rectificationFeedbackDO = new RectificationFeedbackDO();
		//主键id  整改反馈单id(结果id+FK+001)
		String fkdId = getMaxCodeById(rectificationFeedbackDao.getMaxCodeById(rectificationFeedbackVO.getJgId()), rectificationFeedbackVO.getJgId() + "FK", 3);
		rectificationFeedbackVO.setFkdId(fkdId);
		rectificationFeedbackVO.setStatus(1);
		rectificationFeedbackVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(rectificationFeedbackVO, rectificationFeedbackDO);
		rectificationFeedbackDao.insert(rectificationFeedbackDO);
		rectificationFeedbackDetailedDomain.insertRectificationFeedbackDetailedList(rectificationFeedbackVO.getRectificationFeedbackDetailedVOList(),fkdId);
		fileDomain.insertFileList(rectificationFeedbackVO.getFileVOList(),fkdId);
		approvalOpinionsDomain.insertApprovalOpinions(rectificationFeedbackVO.getApprovalOpinionsVO(),fkdId);
		return rectificationFeedbackVO;
	}


	/**
 	* 更新整改反馈单信息
 	* @param rectificationFeedbackVO
 	* @return
 	*/
	public int update(RectificationFeedbackVO rectificationFeedbackVO) {
		String fkdId = rectificationFeedbackVO.getFkdId();
		RectificationFeedbackDO rectificationFeedbackDO = rectificationFeedbackDao.getRectificationFeedbackInfoByFkdId(fkdId);
		if (rectificationFeedbackDO == null) {
			return 0;
		} else if (!rectificationFeedbackVO.getJgId().equals(rectificationFeedbackDO.getJgId())) {
			return -1;
		}
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(rectificationFeedbackVO, rectificationFeedbackDO);
		rectificationFeedbackDetailedDomain.updateRectificationFeedbackDetailedList(rectificationFeedbackVO.getRectificationFeedbackDetailedVOList(),fkdId);
		fileDomain.updateFileList(rectificationFeedbackVO.getFileVOList(),fkdId);
		approvalOpinionsDomain.updateApprovalOpinions(rectificationFeedbackVO.getApprovalOpinionsVO(),fkdId);
		return rectificationFeedbackDao.update(rectificationFeedbackDO);
	}

	/**
	 * 根据结果ID获取整改反馈单信息
	 * @param jgId
	 * @return
	 */
	public List<RectificationFeedbackVO> getRectificationFeedbackInfoListByJgId(String jgId) {
		List<RectificationFeedbackDO> rectificationFeedbackDOList = rectificationFeedbackDao.getRectificationFeedbackInfoListByJgId(jgId);
		List<RectificationFeedbackVO> rectificationFeedbackVOList = new ArrayList<>();
		if (rectificationFeedbackDOList == null) {
			return rectificationFeedbackVOList;
		}
		for (RectificationFeedbackDO rectificationFeedbackDO : rectificationFeedbackDOList) {
			String fkdId = rectificationFeedbackDO.getFkdId();
			RectificationFeedbackVO rectificationFeedbackVO = new RectificationFeedbackVO();
			LsBeanUtils.copyAllProperties(rectificationFeedbackDO, rectificationFeedbackVO);
			rectificationFeedbackVO.setRectificationFeedbackDetailedVOList(rectificationFeedbackDetailedDomain.getRectificationFeedbackDetailedList(fkdId));
			rectificationFeedbackVO.setFileVOList(fileDomain.getFileList(fkdId));
			rectificationFeedbackVO.setApprovalOpinionsVO(approvalOpinionsDomain.getApprovalOpinions(fkdId));
			rectificationFeedbackVOList.add(rectificationFeedbackVO);
		}
		return rectificationFeedbackVOList;
	}

	/**
 	* 根据反馈单ID获取整改反馈单信息
 	* @param fkdId
 	* @return
 	*/
	public RectificationFeedbackVO getRectificationFeedbackInfoByFkdId(String fkdId) {
		RectificationFeedbackDO rectificationFeedbackDO = rectificationFeedbackDao.getRectificationFeedbackInfoByFkdId(fkdId);
		if(rectificationFeedbackDO == null) {
			return null;
		}
		RectificationFeedbackVO rectificationFeedbackVO = new RectificationFeedbackVO();
		LsBeanUtils.copyAllProperties(rectificationFeedbackDO, rectificationFeedbackVO);
		rectificationFeedbackVO.setRectificationFeedbackDetailedVOList(rectificationFeedbackDetailedDomain.getRectificationFeedbackDetailedList(fkdId));
		rectificationFeedbackVO.setFileVOList(fileDomain.getFileList(fkdId));
		rectificationFeedbackVO.setApprovalOpinionsVO(approvalOpinionsDomain.getApprovalOpinions(fkdId));
		return rectificationFeedbackVO;
	}


	public void deleteGz(String jgId) {
		rectificationFeedbackDao.deleteGz(jgId);
	}

}
