package com.unis.inspectionresult.server.domain;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.inspectionresult.common.vo.RectificationNoticeVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO;
import com.unis.inspectionresult.server.dao.DailyCheckResultDao;
import com.unis.inspectionresult.server.dao.RectificationNoticeDao;
import com.unis.inspectionresult.server.entity.RectificationNoticeDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * @author WangZL
 * @version 1.0
 * @Title RectificationNoticeDomain
 * @ProjectName 持久化
 * @Description
 * @date 2019/07/22 17点26分
 */
@Component
public class RectificationNoticeDomain extends BaseDomain {

	@Autowired
	private RectificationNoticeDao rectificationNoticeDao;

	@Autowired
	private RectificationDetailsDomain rectificationDetailsDomain;

	@Autowired
	private FileDomain fileDomain;

	@Autowired
	private DailyCheckResultDao dailyCheckResultDao;

	/**
	 * 新增责令整改通知单信息
	 * @param rectificationNoticeVO
	 * @return
	 */
	public RectificationNoticeVO insert(RectificationNoticeVO rectificationNoticeVO) {
		//查询结果信息是否存在
		DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
		dailyCheckResultVO.setJgId(rectificationNoticeVO.getJgId());
		dailyCheckResultVO.setStatus(1);
		DailyCheckResultVO dailyCheckResultDO = dailyCheckResultDao.selectById(dailyCheckResultVO);
		if(dailyCheckResultDO==null) {
			return null;
		}
		//主键id  责令整改通知单id(结果id+TZ+001)
		String maxTzdId = rectificationNoticeDao.getMaxCodeById(rectificationNoticeVO.getJgId());
		if (maxTzdId == null) {
			//进行传递参数copy
			RectificationNoticeDO rectificationNoticeDO = new RectificationNoticeDO();
			String tzdId = getMaxCodeById(maxTzdId, rectificationNoticeVO.getJgId() + "TZ", 3);
			rectificationNoticeVO.setTzdId(tzdId);
			// 粮食粮号：当前年度检查单位数量+1 0001
			Integer num=rectificationNoticeDao.getCountByJcdwId(DateUtil.getYearString().toString());
			if(num !=null){
				num+=1;
			}else{
				num=1;
			}
			rectificationNoticeVO.setLslh(String.format("%03d", num));
			rectificationNoticeVO.setStatus(1);
			rectificationNoticeVO.setCreateDate(new Date());
			LsBeanUtils.copyAllProperties(rectificationNoticeVO, rectificationNoticeDO);
			rectificationNoticeDao.insert(rectificationNoticeDO);
			rectificationDetailsDomain.insertRectificationDetailsList(rectificationNoticeVO.getRectificationDetailsVOList(),tzdId);
			fileDomain.insertFileList(rectificationNoticeVO.getFileVOList(),tzdId);
		} else {
			rectificationNoticeVO.setTzdId(maxTzdId);
			this.update(rectificationNoticeVO);
		}
		return rectificationNoticeVO;
	}


	/**
 	* 更新责令整改通知单信息
 	* @param rectificationNoticeVO
 	* @return
 	*/
	public int update(RectificationNoticeVO rectificationNoticeVO) {
		RectificationNoticeDO rectificationNoticeDO = rectificationNoticeDao.getRectificationNoticeInfo(rectificationNoticeVO.getJgId());
		if (rectificationNoticeDO == null) {
			return 0;
		}
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(rectificationNoticeVO, rectificationNoticeDO);
		String tzdId = rectificationNoticeVO.getTzdId();
		rectificationDetailsDomain.updateRectificationDetailsList(rectificationNoticeVO.getRectificationDetailsVOList(),tzdId);
		fileDomain.updateFileList(rectificationNoticeVO.getFileVOList(),tzdId);
		return rectificationNoticeDao.update(rectificationNoticeDO);
	}


	/**
 	* 根据结果ID获取责令整改通知单信息
 	* @param jgId
 	* @return
 	*/
	public RectificationNoticeVO getRectificationNoticeInfoByJgId(String jgId) {
		RectificationNoticeDO rectificationNoticeDO = rectificationNoticeDao.getRectificationNoticeInfo(jgId);
		if(rectificationNoticeDO == null) {
			return null;
		}
		RectificationNoticeVO rectificationNoticeVO = new RectificationNoticeVO();
		LsBeanUtils.copyAllProperties(rectificationNoticeDO, rectificationNoticeVO);
		String tzdId = rectificationNoticeVO.getTzdId();
		rectificationNoticeVO.setRectificationDetailsVOList(rectificationDetailsDomain.getRectificationDetailsList(tzdId));
		rectificationNoticeVO.setFileVOList(fileDomain.getFileList(tzdId));
		return rectificationNoticeVO;
	}


	public void updateGz(String jgId) {
		rectificationNoticeDao.updateGz(jgId);
	}


}
