/*
 * DailyCheckResultDetailDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-26 16:21:29 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.domain.resultback;

import java.util.*;
import java.util.stream.Collectors;

import com.unis.base.common.util.IdWorkerUtils;
import com.unis.inspectionresult.common.vo.resultback.*;
import com.unis.inspectionresult.server.dao.DailyCheckResultManeuverMapper;
import com.unis.inspectionresult.server.dao.DailyCheckResultSpecMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.utils.EntityUtil;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.FileVO;
import com.unis.inspectionresult.server.dao.DailyCheckResultDetailDao;
import com.unis.inspectionresult.server.dao.FileDao;
import com.unis.inspectionresult.server.entity.FileDO;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckResultDetailDO;

/**
 * T_BDJLZB-表单记录主表
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2019-08-26 16:21:29
 */
@Component
@Transactional
public class DailyCheckResultDetailDomain {

    @Autowired
    DailyCheckResultDetailDao dailyCheckResultDetailDao;

    @Autowired
    FormDetailDomain formDetailDomain;

    @Autowired
    FileDao fileDao;

    @Autowired
    private IdWorkerUtils idWorker;


    @Autowired
    private DailyCheckResultManeuverMapper dailyCheckResultManeuverMapper;
    @Autowired
    private DailyCheckResultSpecMapper dailyCheckResultSpecMapper;

   /**
    * 通用的插入处理
    * @param entity    <表单记录主表>对象
    */
    private void buildInsertData(DailyCheckResultDetailDO entity){
        entity.buildInsertData();
    }

   /**
    * 通用的更新处理
    * @param entity    <表单记录主表>对象
    */
    private void buildUpdateData(DailyCheckResultDetailDO entity){
        entity.buildUpdateData();
    }

    /**
     * <T_BDJLZB-表单记录主表>插入全部字段
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntity(DailyCheckResultDetailDO entity) {
        buildInsertData(entity);
        return dailyCheckResultDetailDao.insertEntity(entity);
    }

    /**
     * <T_BDJLZB-表单记录主表>插入全部字段
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(DailyCheckResultDetailVO resultDetailVO) {
        //有属性操作则优先在vo处理
        DailyCheckResultDetailDO entity = new DailyCheckResultDetailDO();
        LsBeanUtils.copyAllProperties(resultDetailVO, entity);
        int num= insertEntity(entity);
        if(num>0){
            //主键设置回去
            resultDetailVO.setBdzbid(entity.getBdzbid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>插入全部字段,可删除部分字段改为选择性插入
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int insertEntitySelective(DailyCheckResultDetailDO entity) {
        buildInsertData(entity);
        return dailyCheckResultDetailDao.insertEntitySelective(entity);
    }

    /**
     * <T_BDJLZB-表单记录主表>插入全部字段,可删除部分字段改为选择性插入
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(DailyCheckResultDetailVO resultDetailVO, String rwlxId) {
        //有属性操作则优先在vo处理
        DailyCheckResultDetailDO entity = new DailyCheckResultDetailDO();
        LsBeanUtils.copyAllProperties(resultDetailVO, entity);
        int num = insertEntitySelective(entity);
        if (num > 0) {
            //主键设置回去
            String bdzbid = entity.getBdzbid();
            resultDetailVO.setBdzbid(bdzbid);
            //T_BDJLMX-储备粮公司-表单记录明细表
            List<FormDetailVO> detailList = resultDetailVO.getDetailList();
            List<FormDetailVO> cxzwList = resultDetailVO.getCxzwList();
            List<FormDetailVO> jlList = resultDetailVO.getJlList();
            List<FormDetailVO> mbList = resultDetailVO.getMbList();
            List<FormDetailVO> clhcList = resultDetailVO.getClhcList();
            List<FormDetailVO> stockList = resultDetailVO.getStockList();

            int detailListSize = 0;
            if (detailList != null && (detailListSize = detailList.size()) > 0) {
                FormDetailVO formDetailVO = null;
                for (int i = 0; i < detailListSize; i++) {
                    formDetailVO = detailList.get(i);
                    //给子对象设置主表主键
                    formDetailVO.setBdzbid(bdzbid);
                    //子表主键生成部分根据实际情况修改
                    formDetailVO.setBdmxid(EntityUtil.getIdByParentId(FormDetailVO.class, bdzbid, i));
                    formDetailDomain.insertEntitySelective(formDetailVO);
                }
            }

            int cxzwListSize = 0;
            if (cxzwList != null && (cxzwListSize = cxzwList.size()) > 0) {
                FormDetailVO formDetailVO = null;
                for (int i = 0; i < cxzwListSize; i++) {
                    formDetailVO = cxzwList.get(i);
                    //给子对象设置主表主键
                    formDetailVO.setBdzbid(bdzbid);
                    //子表主键生成部分根据实际情况修改
                    formDetailVO.setBdmxid(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                    formDetailDomain.insertEntitySelective(formDetailVO);
                }
            }

            int jlListSize = 0;
            if (jlList != null && (jlListSize = jlList.size()) > 0) {
                FormDetailVO formDetailVO = null;
                for (int i = 0; i < jlListSize; i++) {
                    formDetailVO = jlList.get(i);
                    //给子对象设置主表主键
                    formDetailVO.setBdzbid(bdzbid);
                    //子表主键生成部分根据实际情况修改
                    formDetailVO.setBdmxid(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                    formDetailDomain.insertEntitySelective(formDetailVO);
                }
            }

            int mbListSize = 0;
            if (mbList != null && (mbListSize = mbList.size()) > 0) {
                FormDetailVO formDetailVO = null;
                for (int i = 0; i < mbListSize; i++) {
                    formDetailVO = mbList.get(i);
                    //给子对象设置主表主键
                    formDetailVO.setBdzbid(bdzbid);
                    //子表主键生成部分根据实际情况修改
                    formDetailVO.setBdmxid(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                    formDetailDomain.insertEntitySelective(formDetailVO);
                }
            }

            int clhcListSize = 0;
            if (clhcList != null && (clhcListSize = clhcList.size()) > 0) {
                FormDetailVO formDetailVO = null;
                for (int i = 0; i < clhcListSize; i++) {
                    formDetailVO = clhcList.get(i);
                    //给子对象设置主表主键
                    formDetailVO.setBdzbid(bdzbid);
                    //子表主键生成部分根据实际情况修改
                    formDetailVO.setBdmxid(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                    formDetailDomain.insertEntitySelective(formDetailVO);
                }
            }
            int stockListSize = 0;
            if (stockList != null && (stockListSize = stockList.size()) > 0) {
                FormDetailVO formDetailVO = null;
                for (int i = 0; i < stockListSize; i++) {
                    formDetailVO = stockList.get(i);
                    //给子对象设置主表主键
                    formDetailVO.setBdzbid(bdzbid);
                    //子表主键生成部分根据实际情况修改
                    formDetailVO.setBdmxid(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                    formDetailDomain.insertEntitySelective(formDetailVO);
                }
            }

            List<FileVO> fileList = resultDetailVO.getFileList();
            if (fileList != null && fileList.size() > 0) {
                for (FileVO fileVO : fileList) {
                    fileVO.setSjId(entity.getJgId());
                    FileDO fileDO = JsonUtils.parse(JsonUtils.serialize(fileVO), FileDO.class);
                    long id = idWorker.nextId();
                    fileDO.setId(id + "");
                    fileDao.insert(fileDO);
                }
            }

            switch (rwlxId) {
                case "5000150": // 成品粮 规格
                    List<DailyCheckResultSpecVo> specList = Optional.ofNullable(resultDetailVO.getSpecList()).orElse(new ArrayList<>());
                    for (DailyCheckResultSpecVo specVo : specList) {
                        specVo.setBdzbid(bdzbid);
                        dailyCheckResultSpecMapper.insertInfo(specVo);
                    }
                    break;
                case "5000170": // 原粮 机动点
                    List<DailyCheckResultManeuverVo> maneuverList = Optional.ofNullable(resultDetailVO.getManeuverList()).orElse(new ArrayList<>());
                    for (DailyCheckResultManeuverVo maneuverVo : maneuverList) {
                        maneuverVo.setBdzbid(bdzbid);
                        dailyCheckResultManeuverMapper.insertInfo(maneuverVo);
                    }
                    break;
            }
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>更改状态
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateStatusByEntity(DailyCheckResultDetailDO entity) {
        return dailyCheckResultDetailDao.updateStatusByEntity(entity);
    }

    /**
     * <T_BDJLZB-表单记录主表>更改状态
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(DailyCheckResultDetailVO resultDetailVO) {
        //有属性操作则优先在vo处理
        DailyCheckResultDetailDO entity = new DailyCheckResultDetailDO();
        LsBeanUtils.copyAllProperties(resultDetailVO, entity);
        int num= updateStatusByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            resultDetailVO.setBdzbid(entity.getBdzbid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体更新单条或者多条数据
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntity(DailyCheckResultDetailDO entity) {
        buildUpdateData(entity);
        return dailyCheckResultDetailDao.updateByEntity(entity);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体更新单条或者多条数据
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(DailyCheckResultDetailVO resultDetailVO) {
        //有属性操作则优先在vo处理
        DailyCheckResultDetailDO entity = new DailyCheckResultDetailDO();
        LsBeanUtils.copyAllProperties(resultDetailVO, entity);
        int num= updateByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            resultDetailVO.setBdzbid(entity.getBdzbid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体选择性更新
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int updateByEntitySelective(DailyCheckResultDetailDO entity) {
        buildUpdateData(entity);
        return dailyCheckResultDetailDao.updateByEntitySelective(entity);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体选择性更新(存在则更新,不存在则插入,其余删除)
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Transactional
    public ResponseWrapper updateByEntitySelective(DailyCheckResultDetailVO resultDetailVO, String rwlxId) {
        //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
        //有属性操作则优先在vo处理
        DailyCheckResultDetailDO entity= new DailyCheckResultDetailDO();
        LsBeanUtils.copyAllProperties(resultDetailVO, entity);
        int num= updateByEntitySelective(entity);
        if (num > 0) {
            //主键设置回去(此处实际不需要)
            String bdzbid = entity.getBdzbid();
            resultDetailVO.setBdzbid(bdzbid);
            //T_BDJLMX-储备粮公司-表单记录明细表
            List<FormDetailVO> detailList = resultDetailVO.getDetailList();
            int detailListSize = 0;
            if (detailList != null && (detailListSize = detailList.size()) > 0) {
                FormDetailVO formDetailVODb = new FormDetailVO();
                //给子对象设置主表主键
                formDetailVODb.setBdzbid(bdzbid);
                List<FormDetailVO> detailListDb = formDetailDomain.selectByEntity(formDetailVODb);
                String maxDetailId = "";
                if (detailListDb.size() > 0) {
                    //获取子表最大的id号
                    detailListDb.sort(Comparator.comparing(FormDetailVO::getBdmxid).reversed());
                    maxDetailId = detailListDb.get(0).getBdmxid();
                } else {
                    maxDetailId = EntityUtil.getIdByParentId(FormDetailVO.class, bdzbid, 0);
                }
                Map<String, FormDetailVO> detailListMap = detailListDb.stream()
                        .collect(Collectors.toMap(a -> a.getBdmxid(), p -> p));
                String keyTemp = null;
                FormDetailVO formDetailVO = null;
                for (int i = 0; i < detailListSize; i++) {
                    formDetailVO = detailList.get(i);
                    if (StringUtils.isEmpty(formDetailVO.getBdzbid())) {
                        //不存在则插入
                        //给子对象设置主表主键
                        formDetailVO.setBdzbid(bdzbid);
                        //子表主键生成部分根据实际情况修改
                        formDetailVO.setBdmxid(EntityUtil.getIdByChildId(maxDetailId, i));
                        formDetailDomain.insertEntitySelective(formDetailVO);
                    } else {
                        //存在则更新
                        keyTemp = formDetailVO.getBdmxid();
                        if (detailListMap.containsKey(keyTemp)) {
                            detailListMap.remove(keyTemp);
                        }
                        formDetailDomain.updateByEntitySelective(formDetailVO);
                    }
                }
                //剩余的删除
                for (Map.Entry<String, FormDetailVO> formDetailVOEntry : detailListMap.entrySet()) {
                    formDetailDomain.deleteByEntity(formDetailVOEntry.getValue());
                }
            }
            //文件列表
            List<FileVO> fileList = resultDetailVO.getFileList();
            if (fileList != null && fileList.size() > 0) {
                FileDO fileDO = new FileDO();
                fileDO.setSjId(resultDetailVO.getJgId());
                List<FileDO> fileDoList = fileDao.selectByEntity(fileDO);
                Map<String, FileDO> fileDoListMap = fileDoList.stream()
                        .collect(Collectors.toMap(a -> a.getId(), p -> p));
                for (FileVO fileVO : fileList) {
                    fileVO.setSjId(resultDetailVO.getJgId());
                    if (fileVO.getId() == null) {
                        fileDO = JsonUtils.parse(
                                JsonUtils.serialize(fileVO), FileDO.class);
                        long id = idWorker.nextId();
                        fileDO.setId(id + "");
                        fileDao.insert(fileDO);
                    } else {
                        fileDO = JsonUtils.parse(
                                JsonUtils.serialize(fileVO), FileDO.class);
                        fileDO.buildUpdateData();
                        fileDao.updateByPrimaryKeySelective(fileDO);
                        fileDoListMap.remove(fileVO.getId());
                    }
                }
                //剩余的删除
                for (Map.Entry<String, FileDO> entry : fileDoListMap.entrySet()) {
                    fileDao.deleteByEntity(entry.getValue());
                }
            }

            switch (rwlxId) {
                case "5000150": // 成品粮 规格
                    dailyCheckResultSpecMapper.delete(new DailyCheckResultSpecVo(bdzbid));
                    List<DailyCheckResultSpecVo> specList = resultDetailVO.getSpecList();
                    if (null == specList) {
                        break;
                    }
                    for (DailyCheckResultSpecVo specVo : specList) {
                        specVo.setBdzbid(bdzbid);
                        dailyCheckResultSpecMapper.insertInfo(specVo);
                    }
                    break;
                case "5000170": // 原粮 机动点
                    dailyCheckResultManeuverMapper.delete(new DailyCheckResultManeuverVo(bdzbid));
                    List<DailyCheckResultManeuverVo> maneuverList = resultDetailVO.getManeuverList();
                    if (null == maneuverList) {
                        break;
                    }
                    for (DailyCheckResultManeuverVo maneuverVo : maneuverList) {
                        maneuverVo.setBdzbid(bdzbid);
                        dailyCheckResultManeuverMapper.insertInfo(maneuverVo);
                    }
                    break;
            }
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体选择性更新(子表先删除再插入)
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelectiveSimple(DailyCheckResultDetailVO resultDetailVO) {
        //此处是先删除再直接更新,较为简单
        //有属性操作则优先在vo处理
        DailyCheckResultDetailDO entity= new DailyCheckResultDetailDO();
        LsBeanUtils.copyAllProperties(resultDetailVO, entity);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            resultDetailVO.setBdzbid(entity.getBdzbid());
            //T_BDJLMX-储备粮公司-表单记录明细表
            List<FormDetailVO> detailList=resultDetailVO.getDetailList();
            int detailListSize=0;
            if(detailList!=null && (detailListSize=detailList.size())>0){
                FormDetailVO formDetailVODb=new FormDetailVO();
                //给子对象设置主表主键
                formDetailVODb.setBdzbid(resultDetailVO.getBdzbid());
                //先删除
                formDetailDomain.deleteByEntity(formDetailVODb);
                FormDetailVO formDetailVO=null;
                //再重新插入
                for(int i=0;i<detailListSize;i++){
                    formDetailVO=detailList.get(i);
                    //给子对象设置主表主键
                    formDetailVO.setBdzbid(resultDetailVO.getBdzbid());
                    //子表主键生成部分根据实际情况修改
                    formDetailVO.setBdmxid(EntityUtil.getIdByParentId(FormDetailVO.class,resultDetailVO.getBdzbid(),i));
                    formDetailDomain.insertEntitySelective(formDetailVO);
                }
            }
            List<FileDO> fileList=fileDao.getFileListBySjId(resultDetailVO.getBdzbid());
            List<FileVO> fileVOList=JsonUtils.parseList(
                    JsonUtils.serialize(fileList),FileVO.class);
            resultDetailVO.setFileList(fileVOList);
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体单条或者批量删除
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int deleteByEntity(DailyCheckResultDetailDO entity) {
        DailyCheckResultDetailVO resultDetailVO = new DailyCheckResultDetailVO();
        LsBeanUtils.copyAllProperties(entity, resultDetailVO);
        return dailyCheckResultDetailDao.deleteByEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体单条或者批量删除
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(DailyCheckResultDetailVO resultDetailVO) {
        int num= dailyCheckResultDetailDao.deleteByEntity(resultDetailVO);
        if(num>0){
            //T_BDJLMX-储备粮公司-表单记录明细表
            FormDetailVO formDetailVODb=new FormDetailVO();
            formDetailVODb.setBdzbid(resultDetailVO.getBdzbid());
            formDetailDomain.deleteByEntity(formDetailVODb);
            //文件列表
            FileDO fileDO=new FileDO();
            fileDO.setSjId(resultDetailVO.getJgId());
            fileDao.deleteByEntity(fileDO);
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int deleteShamByEntity(DailyCheckResultDetailDO entity) {
        DailyCheckResultDetailVO resultDetailVO = new DailyCheckResultDetailVO();
        LsBeanUtils.copyAllProperties(entity, resultDetailVO);
        return dailyCheckResultDetailDao.deleteShamByEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(DailyCheckResultDetailVO resultDetailVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= dailyCheckResultDetailDao.deleteShamByEntity(resultDetailVO);
        if(num>0){
            //T_BDJLMX-储备粮公司-表单记录明细表
            FormDetailVO formDetailVO=new FormDetailVO();
            formDetailVO.setBdzbid(resultDetailVO.getBdzbid());
            //设置子表状态和父表一致
            formDetailVO.setStatus(resultDetailVO.getStatus());
            formDetailDomain.deleteShamByEntity(formDetailVO);
            //文件列表
            FileDO fileDO=new FileDO();
            fileDO.setSjId(resultDetailVO.getJgId());
            fileDO.setStatus(resultDetailVO.getStatus());
            fileDao.deleteShamByEntity(fileDO);
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体查询数量
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int selectCountByEntity(DailyCheckResultDetailVO resultDetailVO) {
        int num= dailyCheckResultDetailDao.selectCountByEntity(resultDetailVO);
        return num;
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体(唯一标示)查询一条数据
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public DailyCheckResultDetailVO selectById(DailyCheckResultDetailDO entity) {
        DailyCheckResultDetailVO resultDetailVO = new DailyCheckResultDetailVO();
        LsBeanUtils.copyAllProperties(entity, resultDetailVO);
        return dailyCheckResultDetailDao.selectById(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体(唯一标示)查询一条数据
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public DailyCheckResultDetailVO selectById(DailyCheckResultDetailVO resultDetailVO) {
        DailyCheckResultDetailVO resultDetailVODb = dailyCheckResultDetailDao.selectById(resultDetailVO);
        if (resultDetailVODb != null) {
            //T_BDJLMX-储备粮公司-表单记录明细表
            FormDetailVO formDetailVO = new FormDetailVO();
            formDetailVO.setBdzbid(resultDetailVODb.getBdzbid());
            List<FormDetailVO> formDetailVOList = formDetailDomain.selectByEntity(formDetailVO);
            resultDetailVODb.setDetailList(formDetailVOList);
            //获取文件
            List<FileDO> fileList = fileDao.getFileListBySjId(resultDetailVO.getJgId());
            List<FileVO> fileVOList = JsonUtils.parseList(
                    JsonUtils.serialize(fileList), FileVO.class);
            resultDetailVO.setFileList(fileVOList);
        }
        return resultDetailVODb;
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体查询分页列表
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<DailyCheckResultDetailVO> selectPageByEntity(int pageNo,int pageSize
        ,DailyCheckResultDetailVO resultDetailVO,String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return dailyCheckResultDetailDao.selectPageByEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体查询列表
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<DailyCheckResultDetailVO> selectByEntity(DailyCheckResultDetailDO entity) {
        DailyCheckResultDetailVO resultDetailVO = new DailyCheckResultDetailVO();
        LsBeanUtils.copyAllProperties(entity, resultDetailVO);
        return dailyCheckResultDetailDao.selectByEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体查询列表
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<DailyCheckResultDetailVO> selectByEntity(DailyCheckResultDetailVO resultDetailVO) {
        return dailyCheckResultDetailDao.selectByEntity(resultDetailVO);
    }

	public void updateGz(String jgId) {
		dailyCheckResultDetailDao.updateGz(jgId);
	}

}
