/*
 * DailyCheckResultDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-26 16:21:29 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.domain.resultback;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Comparator;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import javax.transaction.Transactional;

import com.unis.base.common.util.IdWorkerUtils;
import com.unis.inspectionresult.common.constant.*;
import com.unis.inspectionresult.common.vo.*;
import com.unis.inspectionresult.common.vo.resultback.*;
import com.unis.inspectionresult.server.dao.*;
import com.unis.inspectionresult.server.entity.RectificationNoticeDO;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.time.DateFormatUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.esotericsoftware.minlog.Log;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.UUIDUtils;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionresult.common.utils.EntityUtil;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.utils.getPlanStatusUtil;
import com.unis.inspectionresult.server.domain.BaseDomain;
import com.unis.inspectionresult.server.domain.CheckWorkLogDomain;
import com.unis.inspectionresult.server.domain.RectificationAcceptanceDomain;
import com.unis.inspectionresult.server.domain.RectificationFeedbackDomain;
import com.unis.inspectionresult.server.domain.RectificationNoticeDomain;
import com.unis.inspectionresult.server.entity.FileDO;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckProcessAdjustmentDO;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckResultDO;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckTerritorialSupervisionDO;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckTransferredToDealWithDO;
import com.unis.inspectionresult.server.service.backlog.BacklogMQService;
import com.unis.inspectiontask.common.vo.MemberVO;
import com.unis.inspectiontask.common.vo.PerformanceQueryVO;
import com.unis.inspectiontask.common.vo.TeamVO;
import com.unis.inspectiontask.common.vo.backlog.ReceiverCollectionVO;

import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;

/**
 * T_JCJG-检查结果
 *
 * @author lipenghe at 2019-08-26 16:21:29
 */
@Component
@Transactional
public class DailyCheckResultDomain {

	@Autowired
	DailyCheckResultDao dailyCheckResultDao;

	@Autowired
	RectificationNoticeDomain rectificationNoticeDomain;

	@Autowired
	RectificationFeedbackDomain rectificationFeedbackDomain;

	@Autowired
	FileDao fileDao;

	@Autowired
	DailyCheckResultDetailDomain dailyCheckResultDetailDomain;

	@Autowired
	RectificationAcceptanceDomain rectificationAcceptanceDomain;

	@Autowired
	ReformDelayReviewDomain reformDelayReviewDomain;

	@Autowired
	BaseDomain baseDomain;

	@Autowired
	CheckWorkLogDomain checkWorkLogDomain;

	@Autowired
	private DailyCheckProcessAdjustmentDao processAdjustmentDao;

	@Autowired
	private DailyCheckTransferredToDealWithDao transferredToDealWithDao;

	@Autowired
	private IdWorkerUtils idWorker;

	@Autowired
	FormDetailDomain formDetailDomain;

	@Autowired
	private DailyCheckTerritorialSupervisionDao territorialSupervisionDao;

	@Autowired
	private BacklogMQService backlogService;

	@Autowired
	private CheckResultRescheduDao checkResultRescheduDao;

	@Autowired
	private RectificationNoticeDao rectificationNoticeDao;

	@Autowired
	private DailyCheckResultDetailDao dailyCheckResultDetailDao;

	@Autowired
    private DailyCheckResultManeuverMapper dailyCheckResultManeuverMapper;
	@Autowired
    private DailyCheckResultSpecMapper dailyCheckResultSpecMapper;

	/**
	 * 通用的插入处理
	 *
	 * @param entity <检查结果>对象
	 */
	private void buildInsertData(DailyCheckResultDO entity) {
		entity.buildInsertData();
		String taskId = entity.getRwId();
		if(StringUtils.isEmpty(taskId)) {
			taskId = "RC" + idWorker.nextId();
		}
		String pk = baseDomain.selectByTableNameAndAttr(EntityUtil.getTableName(DailyCheckResultDO.class), "JG_ID",
				taskId, 3);
		entity.setJgId(pk);
	}

	/**
	 * 通用的更新处理
	 *
	 * @param entity <检查结果>对象
	 */
	private void buildUpdateData(DailyCheckResultDO entity) {
		entity.buildUpdateData();
	}

	/**
	 * <T_JCJG-检查结果>插入全部字段
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int insertEntity(DailyCheckResultDO entity) {
		buildInsertData(entity);
		return dailyCheckResultDao.insertEntity(entity);
	}

	/**
	 * <T_JCJG-检查结果>插入全部字段
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper insertEntity(DailyCheckResultVO checkResultVO) {
		// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		int num = insertEntity(entity);
		if (num > 0) {
			// 主键设置回去
			checkResultVO.setJgId(entity.getJgId());
		}
		return ResponseWrapper.choose(num);
	}

	/**
	 * <T_JCJG-检查结果>插入全部字段,可删除部分字段改为选择性插入
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int insertEntitySelective(DailyCheckResultDO entity) {
		buildInsertData(entity);
		return dailyCheckResultDao.insertSelective(entity);
	}

	/**
	 * <T_JCJG-检查结果>插入全部字段,可删除部分字段改为选择性插入
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper insertEntitySelective(DailyCheckResultVO checkResultVO) {
		// 添加同一任务和被检单位的唯一判断
		DailyCheckResultVO checkResultVODb = new DailyCheckResultVO();
		checkResultVODb.setRwId(checkResultVO.getRwId());
		checkResultVODb.setBjdwId(checkResultVO.getBjdwId());
		List<DailyCheckResultVO> list = dailyCheckResultDao.selectByEntity(checkResultVODb);
		//是否为新增企业，如果是则同一被检单位允许下发多次
		boolean isNewEnterprise = false;
		if(null != checkResultVO.getIsNewEnterprise()) {
			isNewEnterprise = checkResultVO.getIsNewEnterprise();
		}
		// 当上级任务名称选择其他时，同一被检单位允许下发多次
		String taskId = checkResultVO.getRwId();
		if (StringUtils.isNotEmpty(taskId) && !isNewEnterprise && CollectionUtils.isNotEmpty(list)) {
			return ResponseWrapper.error("同一被检单位只能下发一次");
		} else {
			// 数据预处理,状态,业务判断(限期截止时间或检查结束时间不为空处理)
			if (StringUtils.isEmpty(checkResultVO.getJgTbbh())) {
				checkResultVO.setJgTbbh(DailyCheckStatusConstant.TO_BE_CHECK.getValue());
				checkResultVO.setJgTbmc(DailyCheckStatusConstant.TO_BE_CHECK.getName());
			}
			// 限期截止时间
			Date timeLimit = checkResultVO.getJgJzsj();
			// 检查结束时间
			Date CheckEndTime = checkResultVO.getJcjssj();
			if(!ObjectUtils.isEmpty(timeLimit) || !ObjectUtils.isEmpty(CheckEndTime)) {
				checkOverDue(checkResultVO);
			}
			// 有属性操作则优先在vo处理
			DailyCheckResultDO entity = new DailyCheckResultDO();
			LsBeanUtils.copyAllProperties(checkResultVO, entity);
			// 处理检查子项和检查内容（需求新增）
			JSONArray checkContentArr = checkResultVO.getCheckContentArr();
			if (!ObjectUtils.isEmpty(checkContentArr)) {
				entity.setJcnr(JSON.toJSONString(checkContentArr));
			}
			JSONArray taskCheckItems = checkResultVO.getTaskCheckItems();
			if (!ObjectUtils.isEmpty(taskCheckItems)) {
				entity.setJczx(JSON.toJSONString(taskCheckItems));
			}
			//监管区域
			JSONObject supervisionArea = checkResultVO.getJgqyObj();
			if(!ObjectUtils.isEmpty(supervisionArea)) {
				entity.setJgqy(JSON.toJSONString(supervisionArea));
			}
			//处理检查组
			TeamVO teamVO = checkResultVO.getTeamVO();
			if(!ObjectUtils.isEmpty(teamVO)) {
				entity.setJczcy(JSON.toJSONString(teamVO));
			}
			int num = insertEntitySelective(entity);
			dataPreview(checkResultVO);
			if (num > 0) {
				// 主键设置回去
				checkResultVO.setJgId(entity.getJgId());
				// T_BDJLZB-表单记录主表
				List<DailyCheckResultDetailVO> detailList = checkResultVO.getDetailList();
				int detailListSize = 0;
				if (detailList != null && (detailListSize = detailList.size()) > 0) {
					DailyCheckResultDetailVO resultDetailVO = null;
					DailyCheckResultDetailVO resultDetail = null;
                    String rwlxId = checkResultVO.getRwlxId();
                    for (int i = 0; i < detailListSize; i++) {
						resultDetailVO = detailList.get(i);
						resultDetailVO.setJgId(entity.getJgId());
						// 子表主键生成部分根据实际情况修改
                        resultDetailVO.setBdzbid(EntityUtil.getIdByParentId(DailyCheckResultDetailVO.class, entity.getJgId(), (int) (Math.random() * 100)));
						// 验重
						DailyCheckResultDetailVO detailInfo = null;
						String bdzbid = resultDetailVO.getBdzbid();
						detailInfo = selectDailyCheckResultDetailById(bdzbid);
						while(detailInfo != null) {
							bdzbid = EntityUtil.getIdByParentId(DailyCheckResultDetailVO.class,
									entity.getJgId(), (int) (Math.random() * 100));
							detailInfo = selectDailyCheckResultDetailById(bdzbid);
						}
						resultDetailVO.setBdzbid(bdzbid);
                        dailyCheckResultDetailDomain.insertEntitySelective(resultDetailVO, rwlxId);
                        //添加附件
						List<FileVO> fileList = resultDetailVO.getFileList();
						if(CollectionUtils.isNotEmpty(fileList)) {
							for(FileVO vo : fileList) {
								FileDO record = new FileDO();
								LsBeanUtils.copyAllProperties(vo, record);
								record.setSjId(resultDetailVO.getBdzbid());
								if (null == vo.getId()) {
									long id = idWorker.nextId();
									record.setId(id + "");
									record.buildInsertData();
									fileDao.insertSelective(record);
								} else {
									record.buildUpdateData();
									fileDao.updateByPrimaryKeySelective(record);
								}
							}
						}
					}
				}
				// T_BDZGYQSP-储备粮公司-表单整改延期审批
				ReformDelayReviewVO reformDelayReviewVO = checkResultVO.getReformDelayReviewVO();
				if (reformDelayReviewVO != null && String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVO.getSfyq())) {
					reformDelayReviewVO.setJgId(entity.getJgId());
					// 子表主键生成部分根据实际情况修改
					reformDelayReviewVO.setBdzgyqid(EntityUtil.getIdByParentId(ReformDelayReviewVO.class, entity.getJgId(), 1));
					reformDelayReviewDomain.insertEntitySelective(reformDelayReviewVO);
				}
				// T_ZLZGTZD-通知单
				RectificationNoticeVO rectificationNoticeVO = checkResultVO.getRectificationNoticeVO();
				if (rectificationNoticeVO != null
						&& (String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVO.getZgtzd())
						|| String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVO.getZgysb()))) {
					rectificationNoticeVO.setJgId(entity.getJgId());
					// 子表主键生成部分根据实际情况修改
					rectificationNoticeVO
							.setTzdId(EntityUtil.getIdByParentId(RectificationNoticeVO.class, entity.getJgId(), 1));
					rectificationNoticeDomain.insert(rectificationNoticeVO);
				}
				// T_ZGFKD-反馈单
				/*
				 * RectificationFeedbackVO
				 * rectificationFeedbackVO=checkResultVO.getRectificationFeedbackVO();
				 * if(rectificationFeedbackVO!=null){
				 * rectificationFeedbackVO.setJgId(entity.getJgId());
				 * rectificationFeedbackVO.setFkdId(EntityUtil.getIdByParentId(
				 * RectificationFeedbackVO.class,entity.getJgId(),1));
				 * rectificationFeedbackDomain.insert(rectificationFeedbackVO); }
				 */
				List<RectificationFeedbackVO> rectificationFeedbackVOList = checkResultVO
						.getRectificationFeedbackVOList();
				if (rectificationFeedbackVOList != null && rectificationFeedbackVOList.size() > 0) {
					for (RectificationFeedbackVO rectificationFeedbackVO : rectificationFeedbackVOList) {
						rectificationFeedbackVO.setJgId(entity.getJgId());
						rectificationFeedbackVO.setFkdId(
								EntityUtil.getIdByParentId(RectificationFeedbackVO.class, entity.getJgId(), 1));
						rectificationFeedbackDomain.insert(rectificationFeedbackVO);
					}
				}
				// 验收单列表
				List<RectificationAcceptanceVO> rectificationAcceptanceVOList = checkResultVO
						.getRectificationAcceptanceVOList();
				if (rectificationAcceptanceVOList != null && rectificationAcceptanceVOList.size() > 0) {
					for (RectificationAcceptanceVO rectificationAcceptanceVO : rectificationAcceptanceVOList) {
						rectificationAcceptanceVO.setJgId(entity.getJgId());
						rectificationAcceptanceVO.setYsdId(
								EntityUtil.getIdByParentId(RectificationAcceptanceVO.class, entity.getJgId(), 1));
						rectificationAcceptanceDomain.insert(rectificationAcceptanceVO);
					}
				}
				// 文件列表
				List<FileVO> fileList = checkResultVO.getFileList();
				if (fileList != null && fileList.size() > 0) {
					for (FileVO fileVO : fileList) {
						fileVO.setSjId(entity.getJgId());
						FileDO fileDO = JsonUtils.parse(JsonUtils.serialize(fileVO), FileDO.class);
						long id = idWorker.nextId();
						fileDO.setId(id + "");
						fileDO.buildInsertData();
						fileDao.insert(fileDO);
					}
				}

				//新增的数据无之前的状态,则状态为下发时的0
				DailyCheckResultVO old=JsonUtils.parse(JsonUtils.serialize(checkResultVO), DailyCheckResultVO.class);
				old.setJgTbbh("0");

				// 添加待办
				this.addBacklog(checkResultVO, checkResultVO.getJgTbbh(),old);
			}
			return ResponseWrapper.choose(num);
		}
	}

	/**
	 * 根据主键查询表单记录
	 * @param bdzbid
	 * @return
	 */
	public DailyCheckResultDetailVO selectDailyCheckResultDetailById(String bdzbid) {
		DailyCheckResultDetailVO resultDetail = new DailyCheckResultDetailVO();
		resultDetail.setBdzbid(bdzbid);
		resultDetail.setStatus(null);
		return dailyCheckResultDetailDao.selectById(resultDetail);
	}

	/**
	 * <T_JCJG-检查结果>更改状态
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int updateStatusByEntity(DailyCheckResultDO entity) {
		return dailyCheckResultDao.updateStatusByEntity(entity);
	}

	/**
	 * <T_JCJG-检查结果>更改状态
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper updateStatusByEntity(DailyCheckResultVO checkResultVO) {
		// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		int num = updateStatusByEntity(entity);
		if (num > 0) {
			// 主键设置回去(此处实际不需要)
			checkResultVO.setJgId(entity.getJgId());
		}
		return ResponseWrapper.choose(num);
	}

	/**
	 * <T_JCJG-检查结果>结果反馈撤回
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper updateBackByEntity(DailyCheckResultVO checkResultVO) {
		// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		DailyCheckResultVO dailyCheckResultVO= selectById(entity);
		if (dailyCheckResultVO !=null) {
			if(!(DailyCheckStatusConstant.TO_BE_CHECK.getValue().equals(dailyCheckResultVO.getJgTbbh())
					|| DailyCheckStatusConstant.TO_BE_SUBMIT.getValue().equals(dailyCheckResultVO.getJgTbbh())
					|| DailyCheckStatusConstant.HEADER_REVIEW.getValue().equals(dailyCheckResultVO.getJgTbbh()))){
				entity.setJgTbbh(DailyCheckStatusConstant.TO_BE_SUBMIT.getValue());
				entity.setJgTbmc(DailyCheckStatusConstant.TO_BE_SUBMIT.getName());
				int num = updateByEntitySelective(entity);

				// 20210805 add 撤回后检查制定任务状态并更新
				String jhid = dailyCheckResultVO.getJhid(); // 任务id
				// 查询计划信息
				InspectionplanVO inspectionplanVO = dailyCheckResultDao.selectJcjhById(jhid);
				if(null != inspectionplanVO) {
					// 查询当前计划下的检查任务
					List<DailyCheckResultByPlanShowVO> dailyCheckResultByPlanList = getCheckResultListByPlanId(inspectionplanVO.getJhId());
					// 判断当前计划下的任务是否都未完成
					if (CollectionUtils.isNotEmpty(dailyCheckResultByPlanList)) {
						Integer planStatus = getPlanStatusUtil.getPlanStatus(dailyCheckResultByPlanList, inspectionplanVO);
						Log.info("执行更新计划状态->计划名称：" + inspectionplanVO.getJhName() + "  计划主键：" + jhid + "  最终状态值为"+planStatus);
						if(null != planStatus) {
							// 更新计划状态
							InspectionplanVO updatePlan = new InspectionplanVO();
							updatePlan.setJhId(jhid);
							updatePlan.setJhzt(planStatus);
							dailyCheckResultDao.updateJcjhByPrimaryKey(updatePlan);
						}
					}
				}

				if(num>0){
					//删除审批信息
					dailyCheckResultDao.updateGz(checkResultVO.getJgId());
					dailyCheckResultDetailDomain.updateGz(checkResultVO.getJgId());
					rectificationNoticeDomain.updateGz(checkResultVO.getJgId());

					rectificationFeedbackDomain.deleteGz(checkResultVO.getJgId());
					rectificationAcceptanceDomain.deleteGz(checkResultVO.getJgId());
					checkResultRescheduDao.deleteGz(checkResultVO.getJgId());
					return ResponseWrapper.success();
				}else{
					return ResponseWrapper.error("有检查组已执行，请联系检查组");
				}
			}
		}

	/*	// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		DailyCheckResultVO dailyCheckResultVO= selectById(entity);
		if(dailyCheckResultVO!=null){
			deleteByEntity(checkResultVO);

			RectificationNoticeDO rectificationNoticeDO=new RectificationNoticeDO();
			rectificationNoticeDO.setJgId(checkResultVO.getJgId());
			rectificationNoticeDao.delete(rectificationNoticeDO);
			rectificationFeedbackDomain.deleteGz(checkResultVO.getJgId());
			rectificationAcceptanceDomain.deleteGz(checkResultVO.getJgId());
			checkResultRescheduDao.deleteGz(checkResultVO.getJgId());
		}*/
		return ResponseWrapper.success("撤回成功");
	}

	/**
	 * <T_JCJG-检查结果>制定任务的撤回,非结果反馈撤回
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper deleteBackByEntity(DailyCheckResultVO checkResultVO) {
		// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		List<DailyCheckResultVO> dailyCheckResultVOList= selectByEntity(entity);
		int num=dailyCheckResultVOList.size();
		if (num > 0) {
			boolean bool=true;
			for(DailyCheckResultVO dailyCheckResultVO: dailyCheckResultVOList){
				//制定任务是只有这3个状态能撤回,结果反馈反着的,具体问业务人员,懵逼
				if(!(DailyCheckStatusConstant.TO_BE_CHECK.getValue().equals(dailyCheckResultVO.getJgTbbh())
					|| DailyCheckStatusConstant.TO_BE_SUBMIT.getValue().equals(dailyCheckResultVO.getJgTbbh())
					|| DailyCheckStatusConstant.HEADER_REVIEW.getValue().equals(dailyCheckResultVO.getJgTbbh()))){
					bool=false;
					break;
				}
			}
			if(!bool){
				System.out.println("当前状态不可撤回");
				return ResponseWrapper.error("有子任务不可撤回");
			}else{
				for(DailyCheckResultVO dailyCheckResultVO : dailyCheckResultVOList){
					deleteByEntity(dailyCheckResultVO);
				}
				return ResponseWrapper.success("撤回成功");
			}
		}
		return ResponseWrapper.success();
	}

	/**
	 * <T_JCJG-检查结果>根据实体更新单条或者多条数据
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int updateByEntity(DailyCheckResultDO entity) {
		buildUpdateData(entity);
		return dailyCheckResultDao.updateByEntity(entity);
	}

	/**
	 * <T_JCJG-检查结果>根据实体更新单条或者多条数据
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper updateByEntity(DailyCheckResultVO checkResultVO) {
		// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		int num = updateByEntity(entity);
		if (num > 0) {
			// 主键设置回去(此处实际不需要)
			checkResultVO.setJgId(entity.getJgId());
		}
		return ResponseWrapper.choose(num);
	}

	/**
	 * <T_JCJG-检查结果>根据实体选择性更新
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int updateByEntitySelective(DailyCheckResultDO entity) {
		buildUpdateData(entity);
		return dailyCheckResultDao.updateByEntitySelective(entity);
	}

	public boolean checkOverDue(DailyCheckResultVO checkResultVO) {
		boolean doCheck = false;

		Calendar calendar = Calendar.getInstance();
		calendar.set(Calendar.HOUR_OF_DAY, 0);
		calendar.set(Calendar.MINUTE, 0);
		calendar.set(Calendar.SECOND, 0);
		calendar.set(Calendar.MILLISECOND, 0);
		Date date = calendar.getTime();
		Date jzsjDate = null;
		// 提交的时候 如果是无需整改-->判断时间 已完成/超期完成 jgZglxbh
		if (ReformStatusConstant.LIMIT_REFORM.getValue().equals(checkResultVO.getJgZglxbh())
				&& DailyCheckStatusConstant.FINISHED.getValue().equals(checkResultVO.getJgTbbh())) {
			// 限期截止时间
			jzsjDate = checkResultVO.getJgJzsj();
			if (jzsjDate == null && checkResultVO.getJgId() != null) {
				DailyCheckResultDO dailyCheckResultDO = new DailyCheckResultDO();
				dailyCheckResultDO.setJgId(checkResultVO.getJgId());
				DailyCheckResultVO checkResultVODb = dailyCheckResultDao.selectById(dailyCheckResultDO);
				if (checkResultVODb != null) {
					jzsjDate = checkResultVODb.getJgJzsj();
				}
			}
			doCheck = true;
		} else if (ReformStatusConstant.NO_REFORM.getValue().equals(checkResultVO.getJgZglxbh())
				&& DailyCheckStatusConstant.TO_BE_REFORM.getValue().equals(checkResultVO.getJgTbbh())
				|| ReformStatusConstant.SCENE_REFORM.getValue().equals(checkResultVO.getJgZglxbh())
				&& DailyCheckStatusConstant.FINISHED.getValue().equals(checkResultVO.getJgTbbh())) {
			// 检查结束时间
			jzsjDate = checkResultVO.getJcjssj();
			if (jzsjDate == null && checkResultVO.getJgId() != null) {
				DailyCheckResultDO dailyCheckResultDO = new DailyCheckResultDO();
				dailyCheckResultDO.setJgId(checkResultVO.getJgId());
				DailyCheckResultVO checkResultVODb = dailyCheckResultDao.selectById(dailyCheckResultDO);
				if (checkResultVODb != null) {
					jzsjDate = checkResultVODb.getJcjssj();
				}
			}
			doCheck = true;
		}
		if (doCheck) {
			if (jzsjDate != null) {
				if (date.compareTo(jzsjDate) > 0) {
					checkResultVO.setJgTbbh(DailyCheckStatusConstant.OVERDUE_FINISH.getValue());
					checkResultVO.setJgTbmc(DailyCheckStatusConstant.OVERDUE_FINISH.getName());
				} else {
					checkResultVO.setJgTbbh(DailyCheckStatusConstant.FINISHED.getValue());
					checkResultVO.setJgTbmc(DailyCheckStatusConstant.FINISHED.getName());
				}
				return true;
			}
			return false;
		}
		return true;
	}

	public void dataPreview(DailyCheckResultVO checkResultVO) {
		if (DailyCheckStatusConstant.OVERDUE_FINISH.getValue().equals(checkResultVO.getJgTbbh())
				|| DailyCheckStatusConstant.FINISHED.getValue().equals(checkResultVO.getJgTbbh())) {

			DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
			dailyCheckResultVO.setRwId(checkResultVO.getRwId());
			List<DailyCheckResultVO> resultVOList = dailyCheckResultDao.selectByEntity(dailyCheckResultVO);
			boolean done = true;
			for (DailyCheckResultVO temp : resultVOList) {
				if(!temp.getJgId().equals(checkResultVO.getJgId())){
					if (!(DailyCheckStatusConstant.OVERDUE_FINISH.getValue().equals(temp.getJgTbbh())
							|| DailyCheckStatusConstant.FINISHED.getValue().equals(temp.getJgTbbh()))) {
						done = false;
						break;
					}
				}
			}
			checkResultVO.setCallBackOnFinish(done);
		} else {
			checkResultVO.setCallBackOnFinish(false);
		}
	}

	/**
	 * <T_JCJG-检查结果>根据实体选择性更新(存在则更新,不存在则插入,其余删除)
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper updateByEntitySelective(DailyCheckResultVO checkResultVO) {
		DailyCheckResultVO dailyCheckResultVO = dailyCheckResultDao.selectById(checkResultVO);
		// 此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
		// 数据预处理,状态,业务判断(限期截止时间或检查结束时间不为空处理)
		if (StringUtils.isEmpty(checkResultVO.getJgTbbh())) {
			checkResultVO.setJgTbbh(DailyCheckStatusConstant.TO_BE_CHECK.getValue());
			checkResultVO.setJgTbmc(DailyCheckStatusConstant.TO_BE_CHECK.getName());
		}
		// 限期截止时间
		Date timeLimit = checkResultVO.getJgJzsj();
		// 检查结束时间
		Date CheckEndTime = checkResultVO.getJcjssj();
		if(!ObjectUtils.isEmpty(timeLimit) || !ObjectUtils.isEmpty(CheckEndTime)) {
			checkOverDue(checkResultVO);
		}
		// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		// 处理检查子项和检查内容（需求新增）
		JSONArray checkContentArr = checkResultVO.getCheckContentArr();
		if (!ObjectUtils.isEmpty(checkContentArr)) {
			entity.setJcnr(JSON.toJSONString(checkContentArr));
		}
		JSONArray taskCheckItems = checkResultVO.getTaskCheckItems();
		if (!ObjectUtils.isEmpty(taskCheckItems)) {
			entity.setJczx(JSON.toJSONString(taskCheckItems));
		}
		//监管区域
		JSONObject supervisionArea = checkResultVO.getJgqyObj();
		if(!ObjectUtils.isEmpty(supervisionArea)) {
			entity.setJgqy(JSON.toJSONString(supervisionArea));
		}
		//处理检查组
		TeamVO teamVO = checkResultVO.getTeamVO();
		if(!ObjectUtils.isEmpty(teamVO)) {
			entity.setJczcy(JSON.toJSONString(teamVO));
		}
		int num = updateByEntitySelective(entity);
		dataPreview(checkResultVO);
		if (num > 0) {
			// 主键设置回去(此处实际不需要)
			checkResultVO.setJgId(entity.getJgId());
			//添加组长审批（2.0新增需求）
			DailyCheckProcessAdjustmentAuditVO teamLeaderAudit = checkResultVO.getTeamLeaderAudit();
			if(!ObjectUtils.isEmpty(teamLeaderAudit)) {
				String lcId = teamLeaderAudit.getLcId();
				DailyCheckProcessAdjustmentDO record = new DailyCheckProcessAdjustmentDO();
				LsBeanUtils.copyAllProperties(teamLeaderAudit, record);
				if(StringUtils.isEmpty(lcId)) {
					record.setLclx(UnitsTypeConstant.TEAM_LEADER_FOR_APPROVAL);
					this.insertProcessAdjustment(record);
				} else {
					this.updateProcessAdjustment(record);
				}
			}
			// T_BDJLZB-表单记录主表
			List<DailyCheckResultDetailVO> detailList = checkResultVO.getDetailList();
			int detailListSize = 0;
			if (detailList != null && (detailListSize = detailList.size()) > 0) {
				DailyCheckResultDetailVO resultDetailVODb = new DailyCheckResultDetailVO();
				// 给子对象设置主表主键
				resultDetailVODb.setJgId(entity.getJgId());
				List<DailyCheckResultDetailVO> detailListDb = dailyCheckResultDetailDomain.selectByEntity(resultDetailVODb);
				String maxDetailId = "";
				if (detailListDb.size() > 0) {
					// 获取子表最大的id号
					detailListDb.sort(Comparator.comparing(DailyCheckResultDetailVO::getBdzbid).reversed());
					maxDetailId = detailListDb.get(0).getBdzbid();
				} else {
					maxDetailId = EntityUtil.getIdByParentId(DailyCheckResultDetailVO.class, entity.getJgId(), 0);
				}
				Map<String, DailyCheckResultDetailVO> detailListMap = detailListDb.stream()
						.collect(Collectors.toMap(a -> a.getBdzbid(), p -> p));
				String keyTemp = null;
                String rwlxId = checkResultVO.getRwlxId();
				DailyCheckResultDetailVO resultDetailVO = null;
				for (int i = 0; i < detailListSize; i++) {
					resultDetailVO = detailList.get(i);
					if (StringUtils.isEmpty(resultDetailVO.getJgId())) {
						// 不存在则插入
						// 给子对象设置主表主键
						resultDetailVO.setJgId(entity.getJgId());
						// 子表主键生成部分根据实际情况修改
						resultDetailVO.setBdzbid(EntityUtil.getIdByChildId(maxDetailId, i));
                        dailyCheckResultDetailDomain.insertEntitySelective(resultDetailVO, rwlxId);
					} else {
						// 存在则更新
						keyTemp = resultDetailVO.getBdzbid();
						if (detailListMap.containsKey(keyTemp)) {
							detailListMap.remove(keyTemp);
						}
						dailyCheckResultDetailDomain.updateByEntitySelective(resultDetailVO, rwlxId);
					}
					//添加附件
					List<FileVO> fileList = resultDetailVO.getFileList();
					this.insertFileList(fileList, resultDetailVO.getBdzbid());
				}
				// 剩余的删除
				for (Map.Entry<String, DailyCheckResultDetailVO> resultDetailVOEntry : detailListMap.entrySet()) {
					dailyCheckResultDetailDomain.deleteByEntity(resultDetailVOEntry.getValue());
				}
			}
			//改期
			List<CheckResultRescheduVO> checkResultRescheduVOs = checkResultVO.getCheckResultRescheduVOs();
			if(checkResultRescheduVOs != null && checkResultRescheduVOs.size() > 0) {
				CheckResultRescheduVO checkResultRescheduVO = new CheckResultRescheduVO();
				checkResultRescheduVO.setJgId(checkResultVO.getJgId());
				checkResultRescheduDao.delete(checkResultRescheduVO);
				for(CheckResultRescheduVO vo:checkResultRescheduVOs) {
					vo.setId(UUIDUtils.uuid());
					vo.setJgId(checkResultVO.getJgId());
					checkResultRescheduDao.insert(vo);
				}
			}
			// T_BDZGYQSP-储备粮公司-表单整改延期审批
			ReformDelayReviewVO reformDelayReviewVO = checkResultVO.getReformDelayReviewVO();
			if (reformDelayReviewVO != null
					&& String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVO.getSfyq())) {
				reformDelayReviewVO.setJgId(entity.getJgId());
				ReformDelayReviewVO delayReviewVODb = new ReformDelayReviewVO();
				delayReviewVODb.setJgId(checkResultVO.getJgId());
				delayReviewVODb = reformDelayReviewDomain.selectById(delayReviewVODb);
				if (delayReviewVODb != null) {
					reformDelayReviewDomain.updateByEntitySelective(reformDelayReviewVO);
				} else {
					// 子表主键生成部分根据实际情况修改
					reformDelayReviewVO.setBdzgyqid(
							EntityUtil.getIdByParentId(ReformDelayReviewVO.class, checkResultVO.getJgId(), 1));
					reformDelayReviewDomain.insertEntitySelective(reformDelayReviewVO);
				}
			}
			// T_ZLZGTZD-通知单
			RectificationNoticeVO rectificationNoticeVO = checkResultVO.getRectificationNoticeVO();
			if (rectificationNoticeVO != null
					&& (String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVO.getZgtzd())
					|| String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVO.getZgysb()))) {
				RectificationNoticeVO rectificationNoticeVODb = rectificationNoticeDomain
						.getRectificationNoticeInfoByJgId(checkResultVO.getJgId());
				if (rectificationNoticeVODb != null) {
					rectificationNoticeDomain.update(rectificationNoticeVO);
				} else {
					rectificationNoticeVO.setJgId(entity.getJgId());
					// 子表主键生成部分根据实际情况修改
					rectificationNoticeVO
							.setTzdId(EntityUtil.getIdByParentId(RectificationNoticeVO.class, entity.getJgId(), 1));
					rectificationNoticeDomain.insert(rectificationNoticeVO);
				}
			}
			// T_ZGFKD-反馈单
			List<RectificationFeedbackVO> rectificationFeedbackVOList = checkResultVO.getRectificationFeedbackVOList();
			int rectificationFeedbackVOSize = 0;
			if (rectificationFeedbackVOList != null
					&& (rectificationFeedbackVOSize = rectificationFeedbackVOList.size()) > 0) {
				List<RectificationFeedbackVO> rectificationFeedbackVODb = rectificationFeedbackDomain
						.getRectificationFeedbackInfoListByJgId(checkResultVO.getJgId());
				// List<String>
				// rectificationList=rectificationFeedbackVODb.stream().map(RectificationFeedbackVO::getFkdId).collect(Collectors.toList());
				RectificationFeedbackVO rectificationFeedbackVO = null;
				for (int i = 0; i < rectificationFeedbackVOSize; i++) {
					rectificationFeedbackVO = rectificationFeedbackVOList.get(i);
					rectificationFeedbackVO.setJgId(checkResultVO.getJgId());
					String feedBackId = rectificationFeedbackVO.getFkdId();
					if (StringUtils.isNotEmpty(feedBackId)) {
						rectificationFeedbackDomain.update(rectificationFeedbackVO);
					} else {
						feedBackId = EntityUtil.getIdByParentId(RectificationFeedbackVO.class, entity.getJgId(), 1);
						rectificationFeedbackVO.setFkdId(feedBackId);
						rectificationFeedbackDomain.insert(rectificationFeedbackVO);
					}
					//添加区粮办办结处理（2.0新增需求）
					DailyCheckTransferredToDealWithVO transferredToDealWithVO = rectificationFeedbackVO.getTransferredToDealWithVO();
					if(!ObjectUtils.isEmpty(transferredToDealWithVO)) {
						String pk = transferredToDealWithVO.getBjId();
						DailyCheckTransferredToDealWithDO record = new DailyCheckTransferredToDealWithDO();
						LsBeanUtils.copyAllProperties(transferredToDealWithVO, record);
						if(StringUtils.isNotEmpty(pk)) {
							this.updateTransferredToDealWith(record);
						} else {
							record.setJgId(entity.getJgId());
							record.setFkdId(feedBackId);
							pk = this.insertTransferredToDealWith(record);
						}
						//处理附件
						List<FileVO> fileList = transferredToDealWithVO.getFileList();
						if(StringUtils.isNotEmpty(pk)) {
							this.insertFileList(fileList, pk);
						}
					}
				}
			}
			// 验收单列表
			List<RectificationAcceptanceVO> rectificationAcceptanceVOList = checkResultVO
					.getRectificationAcceptanceVOList();
			if (rectificationAcceptanceVOList != null && rectificationAcceptanceVOList.size() > 0) {
				for (RectificationAcceptanceVO rectificationAcceptanceVO : rectificationAcceptanceVOList) {
					rectificationAcceptanceVO.setJgId(entity.getJgId());
					if (StringUtils.isNotEmpty(rectificationAcceptanceVO.getYsdId())) {
						rectificationAcceptanceDomain.update(rectificationAcceptanceVO);
					} else {
						rectificationAcceptanceVO.setYsdId(
								EntityUtil.getIdByParentId(RectificationAcceptanceVO.class, entity.getJgId(), 1));
						rectificationAcceptanceDomain.insert(rectificationAcceptanceVO);
					}
				}
			}
			// 文件列表
			List<FileVO> fileList = checkResultVO.getFileList();
			if (fileList != null && fileList.size() > 0) {
				FileDO fileDO = new FileDO();
				fileDO.setSjId(checkResultVO.getJgId());
				List<FileDO> fileDoList = fileDao.selectByEntity(fileDO);
				Map<String, FileDO> fileDoListMap = fileDoList.stream()
						.collect(Collectors.toMap(a -> a.getId(), p -> p));
				for (FileVO fileVO : fileList) {
					fileVO.setSjId(checkResultVO.getJgId());
					if (fileVO.getId() == null) {
						fileDO = JsonUtils.parse(JsonUtils.serialize(fileVO), FileDO.class);
						long id = idWorker.nextId();
						fileDO.setId(id + "");
						fileDO.buildInsertData();
						fileDao.insert(fileDO);
					} else {
						fileDO = JsonUtils.parse(JsonUtils.serialize(fileVO), FileDO.class);
						//修改此处 存在报错（java.sql.SQLException: A syntax error has occurred）
						//fileDao.updateByEntitySelective(fileDO);
						fileDO.buildUpdateData();
						fileDao.updateByPrimaryKeySelective(fileDO);
						fileDoListMap.remove(fileVO.getId());
					}
				}
				// 剩余的删除
				for (Map.Entry<String, FileDO> entry : fileDoListMap.entrySet()) {
					fileDao.deleteByEntity(entry.getValue());
				}
			}
			// 检查工作日志
			/*CheckWorkLogVO checkWorkLogVO = checkResultVO.getCheckWorkLogVO();
			if (checkWorkLogVO != null) {
				if (checkWorkLogVO.getId() != null) {
					checkWorkLogDomain.update(checkWorkLogVO);
				} else {
					checkWorkLogDomain.insert(checkWorkLogVO);
				}
			}*/
			// 组长审核通过后的日常检查结果才应该进工作日志 2021-07-16 update
			String JgTbbh = checkResultVO.getJgTbbh();
			if(("20").equals(JgTbbh)) { // 审核操作
				DailyCheckProcessAdjustmentAuditVO spjgVo = checkResultVO.getTeamLeaderAudit();
				CheckWorkLogVO checkWorkLogVO = checkResultVO.getCheckWorkLogVO();
				if (checkWorkLogVO != null && (spjgVo != null && spjgVo.getSpjg() == 1)) { // 审核通过
					if (checkWorkLogVO.getId() != null) {
						checkWorkLogDomain.update(checkWorkLogVO);
					} else {
						checkWorkLogDomain.insert(checkWorkLogVO);
					}
				}
			}

			/**
			 * 添加属地监管业务逻辑（2.0新增）
			 *   1.检查结果状态为17（区粮办办结）
			 *   2.整改反馈单必须有一条记录
			 */
			String checkResultStatus = checkResultVO.getJgTbbh();
			if (StringUtils.isNotEmpty(checkResultStatus)
					&& DailyCheckStatusConstant.DISTRICT_GRAIN_OFFICE_CLOSED.getValue().equals(checkResultStatus)
					&& CollectionUtils.isNotEmpty(rectificationFeedbackVOList)
					&& rectificationFeedbackVOList.size() == 1) {
				DailyCheckTerritorialSupervisionDO record = new DailyCheckTerritorialSupervisionDO();
				long id = idWorker.nextId();
				record.setId(id + "");
				record.setJgId(checkResultVO.getJgId());
				record.setRwId(checkResultVO.getRwId());
				if(!ObjectUtils.isEmpty(supervisionArea)) {
					record.setJgqyId(supervisionArea.getString("jgqyId"));
				}
				record.buildInsertData();
				territorialSupervisionDao.insertSelective(record);
			}
			// 添加待办
//			if(DailyCheckStatusConstant.TO_BE_CHECK.getValue().equals(checkResultStatus) || DailyCheckStatusConstant.TO_BE_SUBMIT.getValue().equals(checkResultStatus)) {
//				// 待检查和待提交
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, false);
//				checkResultVO.setUserList(userList);
//			} else if(DailyCheckStatusConstant.TO_BE_ACCEPT.getValue().equals(checkResultStatus)) { // 待验收状态
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, true);
//				checkResultVO.setUserList(userList);
//			} else if (DailyCheckStatusConstant.HEADER_REVIEW.getValue().equals(checkResultStatus)
//					|| DailyCheckStatusConstant.TO_BE_REVIEW.getValue().equals(checkResultStatus)
//					|| "23".equals(checkResultStatus)) {
//				// 组长审批、延期审批、办结处理
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverListByCurrentTeam(checkResultVO, userList);
//				checkResultVO.setUserList(userList);
//			}
//			if(DailyCheckStatusConstant.CHECK_TO_BE_SEAL.getValue().equals(checkResultStatus) || DailyCheckStatusConstant.ACCEPT_TO_BE_SEAL.getValue().equals(checkResultStatus)) {//检查单位盖章
//				// 待检查和待提交
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, false);
//				checkResultVO.setUserList(userList);
//			} else if(DailyCheckStatusConstant.COMPANY_TO_BE_SEAL.getValue().equals(checkResultStatus)||"16".equals(checkResultStatus)) { //被检查企业待盖章
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, true);
//				checkResultVO.setUserList(userList);
//			} else if(DailyCheckStatusConstant.TO_BE_REFORM.getValue().equals(checkResultStatus)) { //待整改
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, true);
//				checkResultVO.setUserList(userList);
//			} else if(DailyCheckStatusConstant.TO_BE_ACCEPT.getValue().equals(checkResultStatus) ||DailyCheckStatusConstant.HEADER_REVIEW.getValue().equals(checkResultStatus)) { //待验收，组长审批
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, true);
//				checkResultVO.setUserList(userList);
//			} else if("21".equals(checkResultStatus)) { //待调整审批
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, true);
//				checkResultVO.setUserList(userList);
//			} else if(DailyCheckStatusConstant.DISTRICT_GRAIN_OFFICE_CLOSED.getValue().equals(checkResultStatus)) { //区粮办办接
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverList(checkResultVO, userList, true);
//				checkResultVO.setUserList(userList);
//			}
//			else if (DailyCheckStatusConstant.HEADER_REVIEW.getValue().equals(checkResultStatus)
//					|| DailyCheckStatusConstant.TO_BE_REVIEW.getValue().equals(checkResultStatus)
//					|| "23".equals(checkResultStatus)) {
//				// 组长审批、延期审批、办结处理
//				List<ReceiverCollectionVO> userList = Lists.newArrayList();
//				this.addReceiverListByCurrentTeam(checkResultVO, userList);
//				checkResultVO.setUserList(userList);
//			}
			//2的时候修改不触发待办
			if(!("2".equals(checkResultStatus) && "2".equals(dailyCheckResultVO.getJgTbbh()))){
				this.addBacklog(checkResultVO, checkResultStatus, dailyCheckResultVO);
			}
		}
		if(num>0){
			return ResponseWrapper.success(checkResultVO);
		}
		return ResponseWrapper.fail("更新失败");
	}

	// 获取检查组成员 及 检查组组长
	public void addReceiverList(DailyCheckResultVO checkResultVO, List<ReceiverCollectionVO> userList, boolean isLeader) {
		List<TeamVO> teamVOList = checkResultVO.getTaskVO().getTeamVOs();
		if(!CollectionUtils.isEmpty(teamVOList)) {
			teamVOList.parallelStream().forEach( teamObj -> {
				List<MemberVO> memberVOList = teamObj.getMembers();
				memberVOList.forEach(memberObj -> {
					ReceiverCollectionVO receiver = new ReceiverCollectionVO();
					receiver.setUserId(memberObj.getZyId());
					receiver.setUserName(memberObj.getZyName());
					Integer type = memberObj.getZylx();
					// 0 代表为检查组组长
					if(isLeader && null != type && 0 == type) {
						userList.add(receiver);
					} else {
						userList.add(receiver);
					}
				});
			});
		}
	}

	/**
	 * 获取当前检查组组长
	 */
	public void addReceiverListByCurrentTeam(DailyCheckResultVO checkResultVO, List<ReceiverCollectionVO> userList) {
		TeamVO teamVO = null;
		String userId = CurrentUtil.getUserId();
		if(null != checkResultVO) {
			List<TeamVO> teamVOList = checkResultVO.getTaskVO().getTeamVOs();
			for(TeamVO vo : teamVOList) {
				List<MemberVO> memberList = vo.getMembers();
				if(CollectionUtils.isNotEmpty(memberList)) {
					for(MemberVO member : memberList) {
						String memberId = member.getZyId();
						if(StringUtils.isNotEmpty(memberId) && StringUtils.isNotEmpty(userId) && userId.equals(memberId)) {
							teamVO = vo;
							break;
						}
					}
				}
			}
		}
		if(!ObjectUtils.isEmpty(teamVO)) {
			List<MemberVO> memberVOList = teamVO.getMembers();
			memberVOList.forEach(memberObj -> {
				ReceiverCollectionVO receiver = new ReceiverCollectionVO();
				receiver.setUserId(memberObj.getZyId());
				receiver.setUserName(memberObj.getZyName());
				Integer type = memberObj.getZylx();
				// 0 代表为检查组组长
				if(null != type && 0 == type) {
					userList.add(receiver);
				}
			});
		}
	}

	/**
	 *
	 * @Description: 日常检查添加待办
	 * @author: 王帅
	 * @param dailyCheckResultVO
	 * @param: @param checkResultVO
	 * @param: @param checkResultStatus  参数
	 * @return: void    返回类型
	 */
	private void addBacklog(DailyCheckResultVO checkResultVO, String checkResultStatus, DailyCheckResultVO dailyCheckResultVO) {
		/**
		 * 添加待办
		 * 任务类型 1.日常检查（5000110） 2.防汛检查（5000120） 3.储备粮公司-日常检查（5000150）4.专项检查-储备粮（5000160）
		 * 日常检查企业端状态：1.待盖章 2.待整改 3.已整改待盖章 4.已验收待盖章
		 * 防汛检查企业端状态：1.待整改 2.已整改待盖章 3.已验收待盖章
		 * 储备粮公司-日常检查企业端状态：1.待整改 2.已整改待盖章 3.已验收待盖章
		 */
		//是否是pad端的判断
		String isPad=checkResultVO.getIsPad()!=null?String.valueOf(checkResultVO.getIsPad()):"0";
		String tyname=null;
		String deptId = CurrentUtil.getDeptId();
		String taskTypeId = checkResultVO.getRwlxId();
		List<ReceiverCollectionVO> userList = checkResultVO.getUserList(); // 待办接收人列表
		if(StringUtils.isNotEmpty(taskTypeId) && !CollectionUtils.isEmpty(userList)) {
			String itemUrl = checkResultVO.getItemUrl(); // 详情Url
			String itemQuery = checkResultVO.getItemQuery(); // 详情跳转参数
			String status = checkResultVO.getJgTbbh();
			String statusName = checkResultVO.getJgTbmc();
			String taskName = checkResultVO.getRwmc();
			String title = "";

			if("5000110".equals(taskTypeId)) { // 日常检查
				switch (checkResultStatus) {

				case "0": // 待检查
					status = "0";
					statusName = DailyCheckStatusConstant.TO_BE_CHECK.getName();
					title = "日常检查（" + taskName + "）待检查";
					isPad="1";
					tyname="CHECK-"+taskTypeId;
					break;

				case "1": // 待检查
					statusName = DailyCheckStatusConstant.CHECK_TO_BE_SEAL.getName();
					title = "日常检查（" + taskName + "）待盖章";
					break;

				case "2": // 待提交
					status = "2";
					statusName = DailyCheckStatusConstant.TO_BE_SUBMIT.getName();
					title = "日常检查（" + taskName + "）待提交";
					break;

				case "3": // 待整改
					status = "3";
					statusName = DailyCheckStatusConstant.TO_BE_REFORM.getName();
					title = "日常检查（" + taskName +"）待整改";
					break;

				case "4": // 延期审批
					status = "4";
					statusName = DailyCheckStatusConstant.TO_BE_REVIEW.getName();
					title = "日常检查（" + taskName + "）延期审批";
					break;

				case "5": // 延期审批
					status = "5";
					statusName = DailyCheckStatusConstant.REVIEWED.getName();
					title = "日常检查（" + taskName + "）待整改";
					break;

				case "6": // 延期审批
					status = "6";
					statusName = DailyCheckStatusConstant.OVERDUE_REFUSE.getName();
					title = "日常检查（" + taskName + "）待整改";
					break;

				case "7":
					status = "7";
					statusName = DailyCheckStatusConstant.COMPANY_TO_BE_SEAL.getName();
					title = "日常检查（" + taskName + "）待盖章";
					break;

				case "10": // 待验收
					status = "10";
					statusName = DailyCheckStatusConstant.TO_BE_ACCEPT.getName();
					title = "日常检查（" + taskName + "）待验收";
					break;

				case "11": // 验收检查单位盖章
					status = "11";
					statusName = DailyCheckStatusConstant.ACCEPT_TO_BE_SEAL.getName();
					title = "日常检查（" + taskName + "）验收待盖章";
					break;
				case "12":
					status = "12";
					statusName = DailyCheckStatusConstant.FINISHED.getName();
					title = "日常检查（" + taskName + "）已完成";
					break;
				case "16": // 验收被检企业盖章
					status = "16";
					statusName = "验收被检单位盖章";
					title = "日常检查（" + taskName + "）验收待盖章";
					break;

				case "17": // 区粮办办结
					status = "17";
					isPad="1";
					tyname="DEALQLB-"+taskTypeId;
					statusName = DailyCheckStatusConstant.DISTRICT_GRAIN_OFFICE_CLOSED.getName();
					title = "日常检查（" + taskName + "）区粮办办结";
					break;

				case "18": // 组长审批
					status = "18";
					isPad="1";
					tyname="REVIEW-"+taskTypeId;

					statusName = DailyCheckStatusConstant.HEADER_REVIEW.getName();
					title = "日常检查（" + taskName + "）组长审批";
					break;

				case "20": // 组长审批
					status = "20";
					statusName = "待企业上传";
					title = "日常检查（" + taskName + "）待企业上传";
					break;

				case "21": // 组长审批
					status = "21";
					statusName = "调整审批";
					title = "日常检查（" + taskName + "）调整审批";
					break;

				case "23": // 办结处理
					status = "23";
					statusName = "办结处理";
					title = "日常检查（" + taskName + "）办结处理";
					isPad="1";
					tyname="DEAL-5000110";
					break;
				case "31": ///待送达
					status = "31";
					statusName = "待整改";
					title = "日常检查（" + taskName + "）待整改";
					isPad="1";
					tyname="ACCEPT-"+taskTypeId;
					break;
				case "33": // 办结处理
					status = "33";
					statusName = "组长审批";
					title = "日常检查（" + taskName + "）组长审批";
//					isPad="1";
//					tyname="REVIEW-5000110";
					break;

				default:
					break;
				}

				if(status.equals("7")||status.equals("4")&&checkResultVO.getZgtzd().equals("1")) {
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-31", null, status, statusName);
				}
				if(!"2".equals(checkResultStatus) ||
						("2".equals(checkResultStatus) && "0".equals(dailyCheckResultVO.getJgTbbh())) ){
					backlogService.addDeals(isPad, tyname,checkResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, status, statusName);
				}else if("2".equals(checkResultStatus) && "18".equals(dailyCheckResultVO.getJgTbbh())){
					 backlogService.deleteDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, dailyCheckResultVO.getJgTbbh(),  dailyCheckResultVO.getJgTbmc());
				}
				//提交时处理 0
				if("18".equals(checkResultStatus)){
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-0" , null, status, statusName);
				}
			} else if("5000120".equals(taskTypeId)||"5000160".equals(taskTypeId)) { // 防汛检查
				String rwlxmc = "5000120".equals(taskTypeId)? "防汛检查": "专项检查";
				switch (checkResultStatus) {
				// 被检单位待盖章
				case "0":
					status = "0";
					statusName = DailyCheckStatusConstant.TO_BE_CHECK.getName();
					title = rwlxmc+"（" + taskName + "）待检查";
//					if( "5000120".equals(taskTypeId)){
//						isPad="1";
//						tyname="CHECK-5000120";
//					}else{
//						//粮食储备处
//						if(InspectionConstant.LiangShiChuBeiChu.equals(deptId)){
//							isPad="1";
//							tyname="CHECK-5000160";
//						}else if( InspectionConstant.JianDuJianChaChu.equals(deptId)){
//							//监督检查处
//							isPad="1";
//							tyname="CHECK-5000140";
//						}
//					}
					break;

				case "1":
					status = "1";
					statusName = DailyCheckStatusConstant.CHECK_TO_BE_SEAL.getName();
					title = rwlxmc+"（" + taskName + "）待盖章";
					break;
				//LPH新增的类型
				case "2":
					status = "2";
					statusName = DailyCheckStatusConstant.TO_BE_SUBMIT.getName();
					title = rwlxmc+"（" + taskName + "）待提交";
					break;
				//LPH新增的类型
				case "18": // 组长审批
					status = "18";
					statusName = DailyCheckStatusConstant.HEADER_REVIEW.getName();
					title = rwlxmc+"（" + taskName + "）组长审批";
					break;
				case "3":
					status = "3";
					statusName = DailyCheckStatusConstant.TO_BE_REFORM.getName();
					title = rwlxmc+"（" + taskName +"）待整改";
					break;

				// 被检单位待盖章
				case "7":
					status = "7";
					statusName = DailyCheckStatusConstant.COMPANY_TO_BE_SEAL.getName();
					title = rwlxmc+"（" + taskName + "）待盖章";
					break;

				case "10":
					status = "10";
					statusName = DailyCheckStatusConstant.TO_BE_ACCEPT.getName();
					title = rwlxmc+"（" + taskName + "）待验收";
//					if( "5000120".equals(taskTypeId)){
//						isPad="1";
//						tyname="DEAL-5000120";
//					}else{
//						//粮食储备处
//						if(InspectionConstant.LiangShiChuBeiChu.equals(deptId)){
//							isPad="1";
//							tyname="CHECK-5000160";
//						}
//					}
					break;

				case "11":
					status = "11";
					statusName = DailyCheckStatusConstant.ACCEPT_TO_BE_SEAL.getName();
					title = rwlxmc+"（" + taskName + "）验收待盖章";
					break;
				case "12":
					status = "12";
					statusName = DailyCheckStatusConstant.FINISHED.getName();
					title = rwlxmc+"（" + taskName + "）已完成";
//					if( "5000160".equals(taskTypeId) && InspectionConstant.JianDuJianChaChu.equals(deptId)){
//						isPad="1";
//						tyname="DEAL-5000140";
//					}
					break;
				case "16":
					status = "16";
					statusName = "验收被检单位盖章";
					title = rwlxmc+"（" + taskName + "）验收待盖章";
					break;

				default:
					break;
				}
				if(!"2".equals(checkResultStatus)){
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, status, statusName);
				}
				//提交时处理 0
				if("1".equals(checkResultStatus) || "7".equals(checkResultStatus)){
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-0" , null, status, statusName);
				}
			} else if ("5000150".equals(taskTypeId)||"5000170".equals(taskTypeId)) { /*5000150
			/*  5000150  市级储备成品粮油检查
				5000170   市级储备原粮检查
				*/
				//String rwlxmc = "5000150".equals(taskTypeId)? "市级储备成品粮油检查": "市级储备粮检查";
				String rwlxmc = "5000150".equals(taskTypeId)? "市级储备成品粮油检查": "市级储备原粮检查";
				switch (checkResultStatus) {
				//lph修改,之前0是da待提交,可能有误
				case "0":
					status = "0";
					statusName = DailyCheckStatusConstant.TO_BE_CHECK.getName();
					title = rwlxmc+"（" + taskName + "）待检查";
//					if("5000150".equals(taskTypeId)){
//						isPad="1";
//						tyname="CHECK-5000150";
//					}else{
//						isPad="1";
//						tyname="CHECK-5000170";
//					}
					break;
				case "1":
					status = "1";
					statusName = DailyCheckStatusConstant.CHECK_TO_BE_SEAL.getName();
					title = rwlxmc+"（" + taskName + "）待盖章";
					break;
				//LPH新增的类型
				case "2": // 待提交
					status = "2";
					statusName = DailyCheckStatusConstant.TO_BE_SUBMIT.getName();
					title = "rwlxmc（" + taskName + "）待提交";
//					if("5000150".equals(taskTypeId)){
//						isPad="1";
//						tyname="ADD-5000150";
//					}else{
//						isPad="1";
//						tyname="ADD-5000170";
//					}
					break;
				//LPH新增的类型
				case "18": // 组长审批
					status = "18";
					statusName = DailyCheckStatusConstant.HEADER_REVIEW.getName();
					title = rwlxmc+"（" + taskName + "）组长审批";
					break;
				case "3":
					status = "3";
					statusName = DailyCheckStatusConstant.TO_BE_REFORM.getName();
					title = rwlxmc+"（" + taskName +"）待整改";
					break;
					// 被检单位待盖章
				case "7":
					status = "7";
					isPad="1";
					statusName = DailyCheckStatusConstant.COMPANY_TO_BE_SEAL.getName();
					title = rwlxmc+"（" + taskName + "）待盖章";
					break;

				case "10":
					status = "10";
					statusName = DailyCheckStatusConstant.TO_BE_ACCEPT.getName();
					title = rwlxmc+"（" + taskName + "）待验收";
//					if("5000150".equals(taskTypeId)){
//						isPad="1";
//						tyname="DEAL-5000150";
//					}else{
//						isPad="1";
//						tyname="DEAL-5000170";
//					}
					break;
				case "11":
					status = "11";
					statusName = DailyCheckStatusConstant.ACCEPT_TO_BE_SEAL.getName();
					title = rwlxmc+"（" + taskName + "）验收待盖章";
					break;
				case "12":
					status = "12";
					isPad="1";
					statusName = DailyCheckStatusConstant.FINISHED.getName();
					title = rwlxmc+"（" + taskName + "）已完成";
					break;
				case "16":
					status = "16";
					statusName = "验收被检单位盖章";
					title = rwlxmc+"（" + taskName + "）验收待盖章";
					break;

				default:
					break;
				}
				if(!"2".equals(checkResultStatus)){
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, status, statusName);
				}
				//提交时处理 0
				if("1".equals(checkResultStatus) || "7".equals(checkResultStatus)){
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-0" , null, status, statusName);
				}
				if("1".equals(checkResultStatus) || "7".equals(checkResultStatus)){
					//7的状态填加提交人已办
					String newTyname ="SUB-"+taskTypeId;
					String userName=CurrentUtil.getUserName();
					String userId=CurrentUtil.getUserId();
					String newStatusName ="已提交";

					backlogService.addDealsYwjc(dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" +
									dailyCheckResultVO, dailyCheckResultVO.getRwlxMc()+"（"+dailyCheckResultVO.getRwmc()+"）"+newStatusName, status, newStatusName,isPad,newTyname, itemUrl, itemQuery,
							dailyCheckResultVO.getItemQueryHaveDone(),dailyCheckResultVO.getItemUrlHaveDone(), userList,
							userId,userName, dailyCheckResultVO.getBjdwName());
					//不往下继续执行,不产生待办
					return;
				}
			} else if("5000180".equals(taskTypeId)) { // 防汛检查
			    // 5000180    安全生产检查
				String rwlxmc = "安全生产检查";
                switch (checkResultStatus) {
                    // 被检单位待盖章
                    case "0":
                        status = "0";
                        statusName = DailyCheckStatusConstant.TO_BE_CHECK.getName();
                        title = rwlxmc + "（" + taskName + "）待检查";
//					isPad="1";
//					tyname="CHECK-5000180";
                        break;
                    case "1":
                        status = "1";
                        statusName = DailyCheckStatusConstant.CHECK_TO_BE_SEAL.getName();
                        title = rwlxmc + "（" + taskName + "）待盖章";
                        break;
                    //LPH新增的类型
                    case "2":
                        status = "2";
                        statusName = DailyCheckStatusConstant.TO_BE_SUBMIT.getName();
                        title = rwlxmc + "（" + taskName + "）待提交";
                        break;
                    //LPH新增的类型
                    case "18": // 组长审批
                        status = "18";
                        statusName = DailyCheckStatusConstant.HEADER_REVIEW.getName();
                        title = rwlxmc + "（" + taskName + "）组长审批";
                        break;
                    case "3":
                        status = "3";
                        statusName = DailyCheckStatusConstant.TO_BE_REFORM.getName();
                        title = rwlxmc + "（" + taskName + "）待整改";
                        break;

                    // 被检单位待盖章
                    case "7":
                        status = "7";
                        isPad = "1";
                        statusName = DailyCheckStatusConstant.COMPANY_TO_BE_SEAL.getName();
                        title = rwlxmc + "（" + taskName + "）待盖章";
                        break;

                    case "10":
                        status = "10";
                        statusName = DailyCheckStatusConstant.TO_BE_ACCEPT.getName();
                        title = rwlxmc + "（" + taskName + "）待验收";
                        break;

                    case "11":
                        status = "11";
                        statusName = DailyCheckStatusConstant.ACCEPT_TO_BE_SEAL.getName();
                        title = rwlxmc + "（" + taskName + "）验收待盖章";
                        break;
                    case "12":
                        status = "12";
                        isPad = "1";
                        statusName = DailyCheckStatusConstant.FINISHED.getName();
                        title = rwlxmc + "（" + taskName + "）已完成";
                        break;
                    case "16":
                        status = "16";
                        statusName = "验收被检单位盖章";
                        title = rwlxmc + "（" + taskName + "）验收待盖章";
                        break;

                    default:
                        break;
                }
				if(!"2".equals(checkResultStatus)){
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, status, statusName);
				}
				//提交时处理 0
				if("12".equals(checkResultStatus)|| "7".equals(checkResultStatus)){
					backlogService.addDeals(isPad, tyname,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-0" , null, status, statusName);
				}

				if("7".equals(checkResultStatus) || "12".equals(checkResultStatus)){
					//7的状态填加提交人已办
					String newTyname ="SUB-5000180";
					String userName=CurrentUtil.getUserName();
					String userId=CurrentUtil.getUserId();
					String newStatusName =null;
					if("7".equals(checkResultStatus)){
						newStatusName="已提交";
					} else if("12".equals(checkResultStatus)){
						newStatusName="已完成";
					}

					backlogService.addDealsYwjc(dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" +
									dailyCheckResultVO, dailyCheckResultVO.getRwlxMc()+"（"+dailyCheckResultVO.getRwmc()+"）"+newStatusName, status, newStatusName,isPad,newTyname, itemUrl, itemQuery,
							dailyCheckResultVO.getItemQueryHaveDone(),dailyCheckResultVO.getItemUrlHaveDone(), userList,
							userId,userName, dailyCheckResultVO.getBjdwName());
					//不往下继续执行,不产生待办
					return;
				}
			}

			//待办事项Id生成规则：主键+任务类型+状态
			if(taskTypeId.equals("5000110")&&checkResultVO.getZgtzd()!=null&&checkResultVO.getZgtzd().equals("1")&&(checkResultVO.getJgTbbh().equals("31")||checkResultVO.getJgTbbh().equals("3"))) {//下发责令整改通知单
				if(checkResultVO.getJgTbbh().equals("31"))//31清理一次待办
					backlogService.addNeedToDeals(checkResultVO.getJgId() + "-" + taskTypeId + "-" + checkResultStatus, title, status, statusName,isPad,tyname, itemUrl, itemQuery,checkResultVO.getItemQueryHaveDone(),checkResultVO.getItemUrlHaveDone(), dailyCheckResultVO.getBjdwName(), userList);
			} else {
				//LPH新增
				if(status.equals("2") || status.equals("18") ){
					isPad="1";
					if(status.equals("2")){
						tyname="ADD-"+taskTypeId;
					}else if(status.equals("18")){
						tyname="REVIEW-"+taskTypeId;
					}
					if("5000110".equals(checkResultVO.getRwlxId())&&"18".equals(checkResultStatus)){
						List<ReceiverCollectionVO> leaderList=new ArrayList<>();
						List<ReceiverCollectionVO> memberList=new ArrayList<>();

						for(ReceiverCollectionVO receiverCollectionVO: userList){
							if(receiverCollectionVO.getRylx()==1){
								memberList.add(receiverCollectionVO);
							}else{
								leaderList.add(receiverCollectionVO);
							}
						}
						if("0".equals(dailyCheckResultVO.getJgTbbh())){
							//新增的时候,组员直接进办结
							String newTyname ="SUB-5000110";
							backlogService.addDealsYwjc(checkResultVO.getJgId() + "-" + taskTypeId + "-" +
											checkResultStatus, title, status, statusName,isPad,newTyname, itemUrl, itemQuery,
									checkResultVO.getItemQueryHaveDone(),checkResultVO.getItemUrlHaveDone(), memberList,
									CurrentUtil.getUserId(),CurrentUtil.getUserName(), dailyCheckResultVO.getBjdwName());
						}
						//组长进待办
						backlogService.addNeedToDeals(checkResultVO.getJgId() + "-" + taskTypeId + "-" + checkResultStatus, title, status, statusName,isPad,tyname, itemUrl, itemQuery,checkResultVO.getItemQueryHaveDone(),checkResultVO.getItemUrlHaveDone(), dailyCheckResultVO.getBjdwName(), leaderList);
					}else{
						backlogService.addNeedToDeals(checkResultVO.getJgId() + "-" + taskTypeId + "-" + checkResultStatus, title, status, statusName,isPad,tyname, itemUrl, itemQuery,checkResultVO.getItemQueryHaveDone(),checkResultVO.getItemUrlHaveDone(), dailyCheckResultVO.getBjdwName(), userList);
					}
				}else{
					AppVO appVO=checkResultVO.getAppVO();
					if(appVO!=null){
						isPad=appVO.getIspad();
						tyname=appVO.getTyname();
					}
					backlogService.addNeedToDeals(checkResultVO.getJgId() + "-" + taskTypeId + "-" + checkResultStatus, title, status, statusName,isPad,tyname, itemUrl, itemQuery,checkResultVO.getItemQueryHaveDone(),checkResultVO.getItemUrlHaveDone(), dailyCheckResultVO.getBjdwName(), userList);
				}
			}

		} else if(checkResultVO.getJgTbbh().equals("12")) {
			backlogService.addDeals(isPad,tyname ,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, "12", "已完成");
		} else if(checkResultVO.getJgTbbh().equals("13")) {
			backlogService.addDeals(isPad,tyname ,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, "13", "超期完成");
		} else if(checkResultVO.getJgTbbh().equals("20")) {
			backlogService.addDeals(isPad,tyname ,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, "20", "待企业上传");
		} else if(checkResultVO.getJgTbbh().equals("31")) {
//			isPad="1";
//			//5000160  专项检查-监督检查处
//			if( "5000160".equals(taskTypeId) && InspectionConstant.JianDuJianChaChu.equals(deptId)){
//				isPad="1";
//				tyname="DEAL-5000140";
//			}else{
//				tyname="ACCEPT-5000110";
//			}
			backlogService.addDeals(isPad,tyname ,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, "31", "待送达");
		} else if(checkResultVO.getJgTbbh().equals("31")) {
//			isPad="1";
//			tyname="ACCEPT-5000110";
			backlogService.addDeals(isPad,tyname ,dailyCheckResultVO.getJgId() + "-" + taskTypeId + "-" + dailyCheckResultVO.getJgTbbh(), null, "31", "待送达");
		}
	}

	@Transactional(rollbackOn = Exception.class)
	public void insertFileList(List<FileVO> fileList, String dataId) {
		// 先删除掉原有附件 再执行新增操作
		Example example = new Example(FileDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("sjId", dataId);
		fileDao.deleteByExample(example);
		// 不为空则执行新增操作
		if (CollectionUtils.isNotEmpty(fileList)) {
			for (FileVO vo : fileList) {
				FileDO record = new FileDO();
				LsBeanUtils.copyAllProperties(vo, record);
				record.setSjId(dataId);
				long id = idWorker.nextId();
				record.setId(id + "");
				record.buildInsertData();
				fileDao.insertSelective(record);
			}
		}
	}

	/**
	 * <T_JCJG-检查结果>根据实体选择性更新(子表先删除再插入)
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper updateByEntitySelectiveSimple(DailyCheckResultVO checkResultVO) {
		// 此处是先删除再直接更新,较为简单
		// 有属性操作则优先在vo处理
		DailyCheckResultDO entity = new DailyCheckResultDO();
		LsBeanUtils.copyAllProperties(checkResultVO, entity);
		int num = updateByEntitySelective(entity);
		if (num > 0) {
			// 主键设置回去(此处实际不需要)
			checkResultVO.setJgId(entity.getJgId());
			// T_BDJLZB-表单记录主表
			List<DailyCheckResultDetailVO> detailList = checkResultVO.getDetailList();
			int detailListSize = 0;
			if (detailList != null && (detailListSize = detailList.size()) > 0) {
				DailyCheckResultDetailVO resultDetailVODb = new DailyCheckResultDetailVO();
				// 给子对象设置主表主键
				resultDetailVODb.setJgId(checkResultVO.getJgId());
				// 先删除
				dailyCheckResultDetailDomain.deleteByEntity(resultDetailVODb);
				DailyCheckResultDetailVO resultDetailVO = null;
				// 再重新插入
				for (int i = 0; i < detailListSize; i++) {
					resultDetailVO = detailList.get(i);
					// 给子对象设置主表主键
					resultDetailVO.setJgId(checkResultVO.getJgId());
					// 子表主键生成部分根据实际情况修改
					resultDetailVO.setBdzbid(
							EntityUtil.getIdByParentId(DailyCheckResultDetailVO.class, checkResultVO.getJgId(), i));
					dailyCheckResultDetailDomain.insertEntitySelective(resultDetailVO, null);
				}
			}
			// T_BDZGYQSP-储备粮公司-表单整改延期审批
			ReformDelayReviewVO reformDelayReviewVO = checkResultVO.getReformDelayReviewVO();
			if (reformDelayReviewVO != null
					&& String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVO.getSfyq())) {
				// 给子对象设置主表主键
				reformDelayReviewVO.setJgId(checkResultVO.getJgId());
				ReformDelayReviewVO delayReviewVODb = new ReformDelayReviewVO();
				delayReviewVODb.setJgId(checkResultVO.getJgId());
				delayReviewVODb = reformDelayReviewDomain.selectById(delayReviewVODb);
				if (delayReviewVODb != null) {
					reformDelayReviewDomain.updateByEntitySelective(reformDelayReviewVO);
				} else {
					// 子表主键生成部分根据实际情况修改
					reformDelayReviewVO.setBdzgyqid(
							EntityUtil.getIdByParentId(ReformDelayReviewVO.class, checkResultVO.getJgId(), 1));
					reformDelayReviewDomain.insertEntitySelective(reformDelayReviewVO);
				}
			}
		}
		return ResponseWrapper.choose(num);
	}

	/**
	 * <T_JCJG-检查结果>根据实体单条或者批量删除
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int deleteByEntity(DailyCheckResultDO entity) {
		DailyCheckResultVO checkResultVO = new DailyCheckResultVO();
		LsBeanUtils.copyAllProperties(entity, checkResultVO);
		return dailyCheckResultDao.deleteByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>根据实体单条或者批量删除
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper deleteByEntity(DailyCheckResultVO checkResultVO) {
		int num = dailyCheckResultDao.deleteByEntity(checkResultVO);
		if (num > 0) {
			// T_BDJLZB-表单记录主表
			DailyCheckResultDetailVO resultDetailVODb = new DailyCheckResultDetailVO();
			resultDetailVODb.setJgId(checkResultVO.getJgId());
			dailyCheckResultDetailDomain.deleteByEntity(resultDetailVODb);
			// T_BDZGYQSP-储备粮公司-表单整改延期审批
			ReformDelayReviewVO delayReviewVODb = new ReformDelayReviewVO();
			delayReviewVODb.setJgId(checkResultVO.getJgId());
			reformDelayReviewDomain.deleteByEntity(delayReviewVODb);
			//责令整改通知单
			RectificationNoticeDO rectificationNoticeDO=new RectificationNoticeDO();
			rectificationNoticeDO.setJgId(checkResultVO.getJgId());
			rectificationNoticeDao.delete(rectificationNoticeDO);
			//整改反馈单
			rectificationFeedbackDomain.deleteGz(checkResultVO.getJgId());
			//整改验收单
			rectificationAcceptanceDomain.deleteGz(checkResultVO.getJgId());
			//改期申请对象
			checkResultRescheduDao.deleteGz(checkResultVO.getJgId());

			// 文件列表
			FileDO fileDO = new FileDO();
			fileDO.setSjId(checkResultVO.getJgId());
			fileDao.deleteByEntity(fileDO);
		}
		return ResponseWrapper.choose(num);
	}

	/**
	 * <T_JCJG-检查结果>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int deleteShamByEntity(DailyCheckResultDO entity) {
		DailyCheckResultVO checkResultVO = new DailyCheckResultVO();
		LsBeanUtils.copyAllProperties(entity, checkResultVO);
		return dailyCheckResultDao.deleteShamByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public ResponseWrapper deleteShamByEntity(DailyCheckResultVO checkResultVO) {
		// 自行在controller设置状态,则可删除,亦可还原
		if (StringUtils.isNotEmpty(checkResultVO.getRwId())) {
			DailyCheckResultVO dailyCheckResultVO = new DailyCheckResultVO();
			dailyCheckResultVO.setRwId(checkResultVO.getRwId());
			dailyCheckResultVO.setJgTbbhList(Arrays.asList(new String[] { DailyCheckStatusConstant.FINISHED.getValue(),
					DailyCheckStatusConstant.OVERDUE_FINISH.getValue() }));
			List<DailyCheckResultVO> list = dailyCheckResultDao.selectByEntity(dailyCheckResultVO);
			if (list.size() > 0) {
				return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "有完成的任务,无法撤回", null);
			}
		}
		int num = dailyCheckResultDao.deleteShamByEntity(checkResultVO);
//        if(num>0){
		// T_BDJLZB-表单记录主表
		// 下次会生成新的结果id，无需所有所有子表数据删除
		/*
		 * DailyCheckResultDetailVO resultDetailVO=new DailyCheckResultDetailVO();
		 * resultDetailVO.setJgId(checkResultVO.getJgId()); //设置子表状态和父表一致
		 * resultDetailVO.setStatus(checkResultVO.getStatus());
		 * dailyCheckResultDetailDomain.deleteShamByEntity(resultDetailVO);
		 * //T_BDZGYQSP-储备粮公司-表单整改延期审批 ReformDelayReviewVO delayReviewVO=new
		 * ReformDelayReviewVO(); delayReviewVO.setJgId(checkResultVO.getJgId());
		 * //设置子表状态和父表一致 delayReviewVO.setStatus(checkResultVO.getStatus());
		 * reformDelayReviewDomain.deleteShamByEntity(delayReviewVO); //文件列表 FileDO
		 * fileDO=new FileDO(); fileDO.setSjId(checkResultVO.getJgId());
		 * fileDO.setStatus(checkResultVO.getStatus());
		 * fileDao.deleteShamByEntity(fileDO);
		 */
//        }
		if (num > 0) {
			return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
		}
		return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
	}

	/**
	 * <T_JCJG-检查结果>根据实体查询数量
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public int selectCountByEntity(DailyCheckResultVO checkResultVO) {
		int num = dailyCheckResultDao.selectCountByEntity(checkResultVO);
		return num;
	}

	/**
	 * <T_JCJG-检查结果>根据实体(唯一标示)查询一条数据
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public DailyCheckResultVO selectById(DailyCheckResultDO entity) {
		DailyCheckResultVO checkResultVO = new DailyCheckResultVO();
		LsBeanUtils.copyAllProperties(entity, checkResultVO);
		return dailyCheckResultDao.selectById(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>根据实体(唯一标示)查询一条数据
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public DailyCheckResultVO selectById(DailyCheckResultVO checkResultVO) {
		DailyCheckResultVO checkResultVODb = dailyCheckResultDao.selectById(checkResultVO);
		if (checkResultVODb != null) {
			String checkResultId = checkResultVODb.getJgId();
			// 处理检查子项和检查内容（需求新增）
			String checkContent = checkResultVODb.getJcnr();
			if (StringUtils.isNotEmpty(checkContent)) {
				checkResultVODb.setCheckContentArr(JSON.parseArray(checkContent));
			}
			String taskCheckItems = checkResultVODb.getJczx();
			if (StringUtils.isNotEmpty(taskCheckItems)) {
				checkResultVODb.setTaskCheckItems(JSON.parseArray(taskCheckItems));
			}
			//展示组长审批（2.0新增需求）
			DailyCheckProcessAdjustmentDO auditEntity = this.viewProcessAdjustment(checkResultId, UnitsTypeConstant.TEAM_LEADER_FOR_APPROVAL);
			if(!ObjectUtils.isEmpty(auditEntity)) {
				DailyCheckProcessAdjustmentAuditVO teamLeaderAudit = new DailyCheckProcessAdjustmentAuditVO();
				LsBeanUtils.copyAllProperties(auditEntity, teamLeaderAudit);
				checkResultVODb.setTeamLeaderAudit(teamLeaderAudit);
			}
			//监管区域
			String supervisionArea = checkResultVODb.getJgqy();
			if(StringUtils.isNotEmpty(supervisionArea)) {
				checkResultVODb.setJgqyObj(JSON.parseObject(supervisionArea));
			}
			// T_BDJLZB-表单记录主表
			DailyCheckResultDetailVO resultDetailVO = new DailyCheckResultDetailVO();
			resultDetailVO.setJgId(checkResultId);
            List<DailyCheckResultDetailVO> resultDetailVOList = dailyCheckResultDetailDomain.selectByEntity(resultDetailVO);
			// 添加表单附件
			if(CollectionUtils.isNotEmpty(resultDetailVOList)) {
                String rwlxId = checkResultVODb.getRwlxId();
                resultDetailVOList.forEach( detail -> {
					String detailId = detail.getBdzbid();
					Example example = new Example(FileDO.class);
					Criteria criteria = example.createCriteria();
					criteria.andEqualTo("sjId", detailId);
					criteria.andEqualTo("status", 1);
					example.orderBy("createDate").desc();
					List<FileDO> list = fileDao.selectByExample(example);
					if(CollectionUtils.isNotEmpty(list)) {
						List<FileVO> voList = Lists.newArrayList();
						LsBeanUtils.copyCollection(list, voList, FileVO.class);
						detail.setFileList(voList);
					}

		            //T_BDJLMX-储备粮公司-表单记录明细表
		            FormDetailVO formDetailVO=new FormDetailVO();
		            formDetailVO.setBdzbid(detailId);
					List<FormDetailVO> mbList = new ArrayList<>();
					List<FormDetailVO> clhcList = new ArrayList<>();
					List<FormDetailVO> jlList = new ArrayList<>();
					List<FormDetailVO> cxzwList = new ArrayList<>();
		            List<FormDetailVO> formDetailVOList=formDetailDomain.selectByEntity(formDetailVO);
		            detail.setDetailList(formDetailVOList);
					formDetailVOList.stream().forEach(vo->{
						if (vo.getMbcd()!=null){
							mbList.add(vo);
						}
						if (vo.getJl()!=null){
							jlList.add(vo);
						}
						if(vo.getClcxzzwcd()!=null){
							cxzwList.add(vo);
						}
						if (vo.getLsccqk()!=null){
							clhcList.add(vo);
						}
					});
					detail.setClhcList(clhcList);
					detail.setCxzwList(cxzwList);
					detail.setJlList(jlList);
					detail.setMbList(mbList);
                    switch (rwlxId) {
                        case "5000170": // 原粮 机动点
                            DailyCheckResultManeuverVo queryManeuver = new DailyCheckResultManeuverVo();
                            queryManeuver.setBdzbid(detailId);
                            List<DailyCheckResultManeuverVo> maneuverVoList = dailyCheckResultManeuverMapper.select(queryManeuver);
                            detail.setManeuverList(maneuverVoList);
                            break;
                        case "5000150": // 成品粮 规格
                            DailyCheckResultSpecVo querySpec = new DailyCheckResultSpecVo();
                            querySpec.setBdzbid(detailId);
                            List<DailyCheckResultSpecVo> specVoList = dailyCheckResultSpecMapper.select(querySpec);
                            detail.setSpecList(specVoList);
                            break;
                    }
                });
			}
			checkResultVODb.setDetailList(resultDetailVOList);
			// T_BDZGYQSP-储备粮公司-表单整改延期审批
			if (String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVODb.getSfyq())) {
				ReformDelayReviewVO delayReviewVO = new ReformDelayReviewVO();
				delayReviewVO.setJgId(checkResultId);
				delayReviewVO = reformDelayReviewDomain.selectById(delayReviewVO);
				checkResultVODb.setReformDelayReviewVO(delayReviewVO);
			}
			// T_ZLZGTZD-通知单
			if (String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVODb.getZgtzd())
					|| String.valueOf(BaseStatusConstant.STATUS_NORMAL).equals(checkResultVODb.getZgysb())) {
				RectificationNoticeVO rectificationNoticeVO = rectificationNoticeDomain
						.getRectificationNoticeInfoByJgId(checkResultId);
				checkResultVODb.setRectificationNoticeVO(rectificationNoticeVO);
			}
			// 验收单列表
			List<RectificationAcceptanceVO> rectificationAcceptanceVOList = rectificationAcceptanceDomain
					.getRectificationAcceptanceListInfoByJgId(checkResultId);
			checkResultVODb.setRectificationAcceptanceVOList(rectificationAcceptanceVOList);
			// T_ZGFKD-反馈单
			List<RectificationFeedbackVO> rectificationFeedbackVOList = rectificationFeedbackDomain
					.getRectificationFeedbackInfoListByJgId(checkResultId);
			if(CollectionUtils.isNotEmpty(rectificationFeedbackVOList)) {
				rectificationFeedbackVOList.forEach( feedBack -> {
					//展示区粮办办结处理
					DailyCheckTransferredToDealWithDO transferredToDealWithDO = this.viewTransferredToDealWith(checkResultId, feedBack.getFkdId());
					if(!ObjectUtils.isEmpty(transferredToDealWithDO)) {
						DailyCheckTransferredToDealWithVO vo = new DailyCheckTransferredToDealWithVO();
						LsBeanUtils.copyAllProperties(transferredToDealWithDO, vo);
						//处理附件
						Example example = new Example(FileDO.class);
						Criteria criteria = example.createCriteria();
						criteria.andEqualTo("sjId", vo.getBjId());
						criteria.andEqualTo("status", 1);
						example.orderBy("createDate").desc();
						List<FileDO> list = fileDao.selectByExample(example);
						if(CollectionUtils.isNotEmpty(list)) {
							List<FileVO> voList = Lists.newArrayList();
							LsBeanUtils.copyCollection(list, voList, FileVO.class);
							vo.setFileList(voList);
						}
						feedBack.setTransferredToDealWithVO(vo);
					}
				});
			}
			checkResultVODb.setRectificationFeedbackVOList(rectificationFeedbackVOList);
			// 获取文件
			List<FileDO> fileList = fileDao.getFileListBySjId(checkResultId);
			List<FileVO> fileVOList = JsonUtils.parseList(JsonUtils.serialize(fileList), FileVO.class);
			checkResultVODb.setFileList(fileVOList);
			//添加调整流程对象（新增需求）
			DailyCheckProcessAdjustmentDO processAdjustmentEntity = this.viewProcessAdjustment(checkResultId, UnitsTypeConstant.PROCESS_ADJUSTMENT);
			if(!ObjectUtils.isEmpty(processAdjustmentEntity)) {
				DailyCheckProcessAdjustmentShowVO showVO = new DailyCheckProcessAdjustmentShowVO();
				LsBeanUtils.copyAllProperties(processAdjustmentEntity, showVO);
				checkResultVODb.setProcessAdjustmentShowVO(showVO);
			}
			checkResultVODb.setCheckResultRescheduVOs(checkResultRescheduDao.selectList(checkResultVODb.getJgId()));

		}
		return checkResultVODb;
	}

	/**
	 * <T_JCJG-检查结果>根据实体(唯一标示)查询一条数据
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public DailyCheckResultVO selectSingleByIdResult(DailyCheckResultVO checkResultVO) {
		DailyCheckResultVO checkResultVODb = dailyCheckResultDao.selectById(checkResultVO);
		return checkResultVODb;
	}

	/**
	 * <T_JCJG-检查结果>根据实体查询分页列表
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public Page<DailyCheckResultVO> selectPageByEntity(int pageNo, int pageSize, DailyCheckResultVO checkResultVO,
													   String order) {
		PageHelper.startPage(pageNo, pageSize, order);
		return dailyCheckResultDao.selectPageByEntity(checkResultVO);
	}

    /**
     * <T_JCJG-检查结果>日常结果---查询分页列表
     *
     * @param checkResultVO <检查结果>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public Page<DailyCheckResultVO> selectDailyPageByEntity(int pageNo, int pageSize, DailyCheckResultVO checkResultVO, String order) {
        PageHelper.startPage(pageNo, pageSize);
        Page<DailyCheckResultVO> pageInfo = dailyCheckResultDao.selectDailyPageByEntity(checkResultVO);
        if (CollectionUtils.isNotEmpty(pageInfo.getResult())) {
            Set<String> taskIds = checkResultVO.getTeamTaskIds();
            for (DailyCheckResultVO record : pageInfo.getResult()) {
                String checkResultId = record.getJgId();
                if (StringUtils.isNotEmpty(checkResultId)) {
                    record.setIsProcessAdjustment(isExistProcessAdjustment(checkResultId));
                } else {
                    record.setIsProcessAdjustment(false);
                }
                // 新增日常检查校验是否可修改（当前用户是否为检查组成员）
                int revisable = record.getRevisable();
                String teamMember = record.getJczcy();
                if (0 == revisable && StringUtils.isNotEmpty(teamMember) && teamMember.contains(checkResultVO.getTeamMember())) {
                    record.setRevisable(1);
                    continue;
                }
                //任务派发下来的检查结果 检验是否可修改（当前用户是否为检查组成员）
                String taskId = record.getRwId();
                if (StringUtils.isNotEmpty(taskId) && CollectionUtils.isNotEmpty(taskIds)) {
                    if (taskIds.contains(taskId)) {
                        record.setRevisable(1);
                    }
                }
            }
        }
        return pageInfo;
    }

	/**
	 * <T_JCJG-检查结果>日常结果---查询分页列表
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public Page<DailyCheckResultVO> selectTeamPageByEntity(int pageNo, int pageSize, DailyCheckResultVO checkResultVO, String order) {
		PageHelper.startPage(pageNo, pageSize, order);
		return dailyCheckResultDao.selectTeamPageByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>根据实体查询列表
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public List<DailyCheckResultVO> selectByEntity(DailyCheckResultDO entity) {
		DailyCheckResultVO checkResultVO = new DailyCheckResultVO();
		LsBeanUtils.copyAllProperties(entity, checkResultVO);
		return dailyCheckResultDao.selectByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>根据实体查询列表
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	public List<DailyCheckResultVO> selectByEntity(DailyCheckResultVO checkResultVO) {
		return dailyCheckResultDao.selectByEntity(checkResultVO);
	}

	/**
	 * 查询列表
	 *
	 * @param vo
	 * @return
	 */
	public PageInfo<DailyCheckResultQJVO> getAllList(DailyCheckResultQueryVO vo) {
		List<DailyCheckResultDO> allList = dailyCheckResultDao.getAllList(vo);
		PageInfo<DailyCheckResultDO> page = new PageInfo<DailyCheckResultDO>(allList);

		PageInfo<DailyCheckResultQJVO> voList = new PageInfo<DailyCheckResultQJVO>();

		LsBeanUtils.copyAllProperties(page, voList);
		return voList;
	}

	/**
	 * @Title: selectQyZgLists @Description: 方法描述:(企业整改数据统计 - 整改) @param @param
	 * checkResultVO @param @return 设定文件zgtzd @return ResponseWrapper 返回类型 @throws
	 */

	public DailyCheckResultQuarterListVO selectQyZgLists(String year) {
		DailyCheckResultVO dailyCheckResultV = new DailyCheckResultVO();
		dailyCheckResultV.setZgtzd(DailyCheckStatusConstant.BE_REFORMYXF.getValue());
		dailyCheckResultV.setYear(year);
		List<DailyCheckResultVO> dailyCheckResultVOList = dailyCheckResultDao.selectByEntity(dailyCheckResultV);

		if (dailyCheckResultVOList == null) {
			return null;
		}

		// 季度算法 (v1-1)/3 +1

		int firstSeason = 0;
		int sencondSeason = 0;
		int thirdSeason = 0;
		int fourSeason = 0;
		// 遍历数据 提交时间
		for (DailyCheckResultVO dailyCheckResultVO : dailyCheckResultVOList) {
			int Month = Integer.parseInt(setMonth(dailyCheckResultVO.getJgTjsj()));
			// 第一季
			if (((Month - 1) / 3) + 1 == Integer.parseInt(DailyCheckStatusConstant.FIRSTSEASON.getValue())) {
				firstSeason++;
			}
			// 第二季
			if (((Month - 1) / 3) + 1 == Integer.parseInt(DailyCheckStatusConstant.SENCONDSEASON.getValue())) {
				sencondSeason++;
			}
			// 第三季
			if (((Month - 1) / 3) + 1 == Integer.parseInt(DailyCheckStatusConstant.THIRDSEASON.getValue())) {
				thirdSeason++;
			}
			// 第四季
			if (((Month - 1) / 3) + 1 == Integer.parseInt(DailyCheckStatusConstant.FOURSEASON.getValue())) {
				fourSeason++;
			}
		}
		// 返回统计数据
		List<DailyCheckResultQuarterVO> dailyCheckResultQuarterList = new ArrayList<DailyCheckResultQuarterVO>();

		DailyCheckResultQuarterVO dailyCheckResultQuarterVO = new DailyCheckResultQuarterVO();
		dailyCheckResultQuarterVO.setFirstSeason(firstSeason);
		dailyCheckResultQuarterVO.setSencondSeason(sencondSeason);
		dailyCheckResultQuarterVO.setThirdSeason(thirdSeason);
		dailyCheckResultQuarterVO.setFourSeason(fourSeason);
		dailyCheckResultQuarterVO.setYear(year);
		dailyCheckResultQuarterList.add(dailyCheckResultQuarterVO);

		DailyCheckResultQuarterListVO dailyCheckResultQuarterLists = new DailyCheckResultQuarterListVO();
		dailyCheckResultQuarterLists.setDailyCheckResultQuarterVO(dailyCheckResultQuarterList);

		return dailyCheckResultQuarterLists;
	}

	/**
	 *
	 * @Title: formatDate @Description: 方法描述:(得到日期字符串 默认格式（yyyy-MM-dd）
	 * pattern可以为："yyyy-MM-dd" "HH:mm:ss" "E") @param @param date @param @param
	 * pattern @param @return 设定文件 @return String 返回类型 @throws
	 */
	public static String formatDate(Date date, Object... pattern) {
		String formatDate = null;
		if (pattern != null && pattern.length > 0) {
			formatDate = DateFormatUtils.format(date, pattern[0].toString());
		} else {
			formatDate = DateFormatUtils.format(date, "yyyy-MM-dd");
		}
		return formatDate;
	}

	/**
	 *
	 * @Title: setMonth @Description: 方法描述:( 得到当前月份字符串 格式（MM）) @param @param
	 * T @param @return 设定文件 @return String 返回类型 @throws
	 */
	public static String setMonth(Date T) {
		return formatDate(T, "MM");
	}

	public Page<DailyCheckResultVO> inspectionResultExport(DailyCheckResultVO checkResultVO, String order) {
		return dailyCheckResultDao.selectTeamPageByEntity(checkResultVO);
	}

	public Page<DailyCheckResultVO> selectDailyPageByCompanyEntity(int pageNo, int pageSize,
																   DailyCheckResultVO checkResultVO, String order) {
		PageHelper.startPage(pageNo, pageSize, order);
		return dailyCheckResultDao.selectDailyPageByCompanyEntity(checkResultVO);
	}

	public Page<DailyCheckResultVO> dailyCheckResultYlCplPage(int pageNo, int pageSize,
																   DailyCheckResultVO checkResultVO, String order) {
		PageHelper.startPage(pageNo, pageSize, order);
		return dailyCheckResultDao.dailyCheckResultYlCplPage(checkResultVO);
	}

	public Page<DailyCheckResultVO> dailyCheckResultPageForKSH(int pageNo, int pageSize,DailyCheckSearchVO dailyCheckSearchVO) {
		PageHelper.startPage(pageNo, pageSize);
		return dailyCheckResultDao.dailyCheckResultPageForKSH(dailyCheckSearchVO);
	}
	/**
	 * 根据bjdwId, rwId查询检查时间
	 *
	 * @param rwId
	 * @param bjdwId
	 * @return
	 */
	public DailyCheckInspectionTimeAndResultIdVO getInspectionTime(String rwId, String bjdwId) {
		Map<String, String> queryMap = new HashMap<>();
		queryMap.put("rwId", rwId);
		queryMap.put("bjdwId", bjdwId);
		return dailyCheckResultDao.getInspectionTime(queryMap);
	}

	/**
	 *
	 * @Description: 日常检查结果修改
	 * @author: 王帅
	 * @param: @param  record
	 * @param: @return 参数
	 * @return: boolean 返回类型
	 */
	@Transactional(rollbackOn = Exception.class)
	public boolean updateCheckResultStatus(DailyCheckResultDO record) {
		return dailyCheckResultDao.updateByPrimaryKeySelective(record) > 0;
	}

	/**
	 *
	 * @Description: 调整流程-添加
	 * @author: 王帅
	 * @param: @param  record
	 * @param: @return 参数
	 * @return: boolean 返回类型
	 */
	@Transactional(rollbackOn = Exception.class)
	public boolean insertProcessAdjustment(DailyCheckProcessAdjustmentDO record) {
		record.buildInsertData();
		String pk = baseDomain.selectByTableNameAndAttr(EntityUtil.getTableName(DailyCheckProcessAdjustmentDO.class), "LC_ID",
				DateUtil.getNowDateFormat("yyyyMMdd"), 3);
		record.setLcId(pk);
		return processAdjustmentDao.insertSelective(record) > 0;
	}

	/**
	 *
	 * @Description: 调整流程-修改
	 * @author: 王帅
	 * @param: @param  record
	 * @param: @return 参数
	 * @return: boolean 返回类型
	 */
	@Transactional(rollbackOn = Exception.class)
	public boolean updateProcessAdjustment(DailyCheckProcessAdjustmentDO record) {
		record.buildUpdateData();
		return processAdjustmentDao.updateByPrimaryKeySelective(record) > 0;
	}

	/**
	 *
	 * @Description: 调整流程-查看详情
	 * @author: 王帅
	 * @param: @param  checkResultId
	 * @param: @return 参数
	 * @return: DailyCheckProcessAdjustmentDO 返回类型
	 */
	public DailyCheckProcessAdjustmentDO viewProcessAdjustment(String checkResultId, String type) {
		Example example = new Example(DailyCheckProcessAdjustmentDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("jgId", checkResultId);
		criteria.andEqualTo("lclx", type);

		return processAdjustmentDao.selectOneByExample(example);
	}

	/**
	 *
	 * @Description: 调整流程-判断是否存在
	 * @author: 王帅
	 * @param: @param  checkResultId
	 * @param: @return 参数
	 * @return: boolean 返回类型
	 */
	public boolean isExistProcessAdjustment(String checkResultId) {
		Example example = new Example(DailyCheckProcessAdjustmentDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("jgId", checkResultId);
		criteria.andEqualTo("lclx", UnitsTypeConstant.PROCESS_ADJUSTMENT);

		return ObjectUtils.isEmpty(processAdjustmentDao.selectOneByExample(example));
	}

	/**
	 * 根据任务id查询特定状态结果数据
	 * @param performanceQueryVO
	 * @return
	 */
	public List<DailyCheckResultPerformanceVO> getinspectionList(PerformanceQueryVO performanceQueryVO) {
		return dailyCheckResultDao.getinspectionList(performanceQueryVO);
	}

	/**
	 * 根据结果id列表结果数据
	 * @param performanceQueryVO
	 * @return
	 */
	public List<DailyCheckResultVO> getInspectionListByjgIdList(PerformanceQueryVO performanceQueryVO) {
		Integer pageNum = performanceQueryVO.getPageNum();
		Integer pageSize = performanceQueryVO.getPageSize();
		List<DailyCheckResultVO> resultList = Lists.newArrayList();
		if(!ObjectUtils.isEmpty(pageSize) && !ObjectUtils.isEmpty(pageNum)) {
			PageHelper.startPage(pageNum, pageSize);
			resultList = dailyCheckResultDao.getInspectionListByjgIdList(performanceQueryVO);
		} else {
			resultList = dailyCheckResultDao.getInspectionListByjgIdList(performanceQueryVO);
		}
		return resultList;
	}

	/**
	 * 根据结果id列表分页查询
	 * @param performanceQueryVO
	 * @return
	 */
	public PageInfo<DailyCheckResultVO> getInspectionResultPageByjgIdList(PerformanceQueryVO performanceQueryVO) {
		Integer pageNum = performanceQueryVO.getPageNum();
		Integer pageSize = performanceQueryVO.getPageSize();
		PageHelper.startPage(pageNum, pageSize);
		Page<DailyCheckResultVO> resultList = (Page<DailyCheckResultVO>)dailyCheckResultDao.getInspectionListByjgIdList(performanceQueryVO);
		return new PageInfo<DailyCheckResultVO>(resultList);
	}

	/**
	 *
	 * @Description: 区粮办办结处理新增
	 * @author: 王帅
	 * @param: @param  record
	 * @param: @return 参数
	 * @return: boolean 返回类型
	 */
	@Transactional(rollbackOn = Exception.class)
	public String insertTransferredToDealWith(DailyCheckTransferredToDealWithDO record) {
		record.buildInsertData();
		String pk = baseDomain.selectByTableNameAndAttr(
				EntityUtil.getTableName(DailyCheckTransferredToDealWithDO.class), "BJ_ID",
				DateUtil.getNowDateFormat("yyyyMMdd"), 3);
		record.setBjId(pk);
		boolean result = transferredToDealWithDao.insertSelective(record) > 0;
		return result ? pk : null;
	}

	/**
	 *
	 * @Description: 区粮办办结处理修改
	 * @author: 王帅
	 * @param: @param  record
	 * @param: @return 参数
	 * @return: boolean 返回类型
	 */
	@Transactional(rollbackOn = Exception.class)
	public boolean updateTransferredToDealWith(DailyCheckTransferredToDealWithDO record) {
		record.buildUpdateData();
		return transferredToDealWithDao.updateByPrimaryKeySelective(record) > 0;
	}

	/**
	 *
	 * @Description: 区粮办办结处理查看详情
	 * @author: 王帅
	 * @param: @param  checkResultId
	 * @param: @return 参数
	 * @return: DailyCheckTransferredToDealWithDO 返回类型
	 */
	public DailyCheckTransferredToDealWithDO viewTransferredToDealWith(String checkResultId, String feedBackId) {
		Example example = new Example(DailyCheckTransferredToDealWithDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("jgId", checkResultId);
		criteria.andEqualTo("fkdId", feedBackId);

		return transferredToDealWithDao.selectOneByExample(example);
	}

	/**
	 * 根据任务时间查询特定状态结果数据
	 * @param developmentSituationQueryVO
	 * @return
	 */
	public DevelopmentSituationVO developmentSituation(DevelopmentSituationQueryVO developmentSituationQueryVO) {
		return dailyCheckResultDao.developmentSituation(developmentSituationQueryVO);
	}

	/**
	 * 根据任务时间查询任务列表
	 * @param developmentSituationQueryVO
	 * @return
	 */
	public List<String> developmentSituationByRwIdList(DevelopmentSituationQueryVO developmentSituationQueryVO) {
		return dailyCheckResultDao.developmentSituationByRwIdList(developmentSituationQueryVO);
	}

	/**
	 *
	 * @Description: 展示检查结果列表通过计划Id
	 * @author: 王帅
	 * @param: @param  planId
	 * @param: @return 参数
	 * @return: List<DailyCheckResultVO> 返回类型
	 */
	public List<DailyCheckResultByPlanShowVO> getCheckResultListByPlanId(String planId) {
		List<DailyCheckResultDO> entityList = dailyCheckResultDao.showCheckResultByPlan(planId);
		if (CollectionUtils.isNotEmpty(entityList)) {
			List<DailyCheckResultByPlanShowVO> showList = Lists.newArrayList();
			entityList.forEach((entity) -> {
				DailyCheckResultByPlanShowVO showVO = new DailyCheckResultByPlanShowVO();
				LsBeanUtils.copyAllProperties(entity, showVO);
				showList.add(showVO);
			});
			return showList;
		}

		return null;
	}

	/**
	 *
	 * @Description: 获取监管区域
	 * @author: 王帅
	 * @param: @param  orgId
	 * @param: @return 参数
	 * @return: List<DailyCheckTerritorialSupervisionVO> 返回类型
	 */
	public List<DailyCheckTerritorialSupervisionVO> getTerritorialSupervisionByOrgId(String orgId) {
		if (StringUtils.isEmpty(orgId)) {
			return null;
		}
		Example example = new Example(DailyCheckTerritorialSupervisionDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andEqualTo("jgqyId", orgId);
		List<DailyCheckTerritorialSupervisionVO> showVOList = Lists.newArrayList();
		List<DailyCheckTerritorialSupervisionDO> recordList = territorialSupervisionDao.selectByExample(example);
		if (CollectionUtils.isNotEmpty(recordList)) {
			recordList.stream().forEach(record -> {
				DailyCheckTerritorialSupervisionVO showVO = new DailyCheckTerritorialSupervisionVO();
				LsBeanUtils.copyAllProperties(record, showVO);
				showVOList.add(showVO);
			});
			return showVOList;
		}

		return null;
	}

	public List<DailyCheckResultVO> dailyCheckResultList(String bjdwId) {
		List<DailyCheckResultVO> dailyCheckResultVOs = dailyCheckResultDao.selectDailyListByBjdwid(bjdwId);
		return dailyCheckResultVOs;
	}

	public Page<ResultApplyVO> selectDailyPageByEntity(int pageNum, int pageSize, ResultApplyQuery resultApplyQuery,
			String string) {
		PageHelper.startPage(pageNum, pageSize);
		if(CurrentUtil.getDeptName().contains("粮食储备")) {
			resultApplyQuery.setDqcsmc("5000120");
		} else {
			resultApplyQuery.setDqcsmc("5000110");
		}
		Page<ResultApplyVO> pageInfo = dailyCheckResultDao.selectResultApplyVOPage(resultApplyQuery);
		return pageInfo;
	}

	public Page<ResultApplyVO> selectDailyDisPageByEntity(int pageNum, int pageSize, ResultApplyQuery resultApplyQuery,
			String string) {
		PageHelper.startPage(pageNum, pageSize);
		resultApplyQuery.setDqcsmc(CurrentUtil.getOrgId());
		resultApplyQuery.setDepotCode(CurrentUtil.getDeptId());
		Page<ResultApplyVO> pageInfo = dailyCheckResultDao.selectResultApplyDisVOPage(resultApplyQuery);
		return pageInfo;
	}



	public List<BaseKcVO> selectKc(String tyshxydm){
		List<BaseKcVO> baseKcVOs = dailyCheckResultDao.selectKc(tyshxydm);
		for(BaseKcVO baseKcVO:baseKcVOs) {
			BaseKcVO kcVO = dailyCheckResultDao.selectWd(baseKcVO.getCfbh());
			if(kcVO!=null) {
				baseKcVO.setCfwd(kcVO.getCfwd());
				baseKcVO.setCfsd(kcVO.getCfsd());
			}
		}
		return baseKcVOs;
	}

	public List<BaseKcVO> selectBatchWd(List<String> cfbhList){
		List<BaseKcVO> kcVOList = dailyCheckResultDao.selectBatchWd(cfbhList);
		return  kcVOList;
	}


	public List<BaseKcVO> selectChengPinKc(String tyshxydm){
		List<BaseKcVO> baseKcVOs = dailyCheckResultDao.selectChengPinKc(tyshxydm);
		for(BaseKcVO baseKcVO:baseKcVOs) {
			BaseKcVO kcVO = dailyCheckResultDao.selectWd(baseKcVO.getCfbh());
			if(kcVO!=null) {
				baseKcVO.setCfwd(kcVO.getCfwd());
				baseKcVO.setCfsd(kcVO.getCfsd());
			}
		}
		return baseKcVOs;
	}
}
