/*
 * FormDetailDomain.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-27 15:27:34 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.domain.resultback;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.constant.BaseStatusConstant;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.resultback.FormDetailVO;
import com.unis.inspectionresult.server.dao.FormDetailDao;
import com.unis.inspectionresult.server.entity.resultback.FormDetailDO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * T_BDJLMX-储备粮公司-表单记录明细表
 * DO处理自身,VO处理包括子表
 * @author lipenghe at 2019-08-27 15:27:34
 */
@Component
@Transactional
public class FormDetailDomain {

    @Autowired
    FormDetailDao formDetailDao;

   /**
    * 通用的插入处理
    * @param entity    <储备粮公司-表单记录明细表>对象
    */
    private void buildInsertData(FormDetailDO entity){
        entity.buildInsertData();
    }

   /**
    * 通用的更新处理
    * @param entity    <储备粮公司-表单记录明细表>对象
    */
    private void buildUpdateData(FormDetailDO entity){
        entity.buildUpdateData();
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>插入全部字段
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int insertEntity(FormDetailDO entity) {
        buildInsertData(entity);
        return formDetailDao.insertEntity(entity);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>插入全部字段
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntity(FormDetailVO formDetailVO) {
        //有属性操作则优先在vo处理
        FormDetailDO entity=JsonUtils.parse(
            JsonUtils.serialize(formDetailVO),FormDetailDO.class);
        int num= insertEntity(entity);
        if(num>0){
            //主键设置回去
            formDetailVO.setBdmxid(entity.getBdmxid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>插入全部字段,可删除部分字段改为选择性插入
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int insertEntitySelective(FormDetailDO entity) {
        buildInsertData(entity);
        return formDetailDao.insertEntitySelective(entity);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>插入全部字段,可删除部分字段改为选择性插入
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper insertEntitySelective(FormDetailVO formDetailVO) {
        //有属性操作则优先在vo处理
        FormDetailDO entity=JsonUtils.parse(
            JsonUtils.serialize(formDetailVO),FormDetailDO.class);
        int num= insertEntitySelective(entity);
        if(num>0){
            //主键设置回去
            formDetailVO.setBdmxid(entity.getBdmxid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>更改状态
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateStatusByEntity(FormDetailDO entity) {
        return formDetailDao.updateStatusByEntity(entity);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>更改状态
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateStatusByEntity(FormDetailVO formDetailVO) {
        //有属性操作则优先在vo处理
        FormDetailDO entity=JsonUtils.parse(
            JsonUtils.serialize(formDetailVO),FormDetailDO.class);
        int num= updateStatusByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            formDetailVO.setBdmxid(entity.getBdmxid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体更新单条或者多条数据
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateByEntity(FormDetailDO entity) {
        buildUpdateData(entity);
        return formDetailDao.updateByEntity(entity);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体更新单条或者多条数据
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntity(FormDetailVO formDetailVO) {
        //有属性操作则优先在vo处理
        FormDetailDO entity=JsonUtils.parse(
            JsonUtils.serialize(formDetailVO),FormDetailDO.class);
        int num= updateByEntity(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            formDetailVO.setBdmxid(entity.getBdmxid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体选择性更新
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int updateByEntitySelective(FormDetailDO entity) {
        buildUpdateData(entity);
        return formDetailDao.updateByEntitySelective(entity);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体选择性更新(存在则更新,不存在则插入,其余删除)
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelective(FormDetailVO formDetailVO) {
        //此处是直接更新,较为繁琐,适用于子表数据有关联(被其他数据使用),缺少排序在字段会出现顺序与修改数据的顺序不一致的问题,
        //有属性操作则优先在vo处理
        FormDetailDO entity=JsonUtils.parse(
            JsonUtils.serialize(formDetailVO),FormDetailDO.class);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            formDetailVO.setBdmxid(entity.getBdmxid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体选择性更新(子表先删除再插入)
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper updateByEntitySelectiveSimple(FormDetailVO formDetailVO) {
        //此处是先删除再直接更新,较为简单
        //有属性操作则优先在vo处理
        FormDetailDO entity=JsonUtils.parse(
            JsonUtils.serialize(formDetailVO),FormDetailDO.class);
        int num= updateByEntitySelective(entity);
        if(num>0){
            //主键设置回去(此处实际不需要)
            formDetailVO.setBdmxid(entity.getBdmxid());
        }
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体单条或者批量删除
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public int deleteByEntity(FormDetailDO entity) {
        FormDetailVO formDetailVO=JsonUtils.parse(
            JsonUtils.serialize(entity),FormDetailVO.class);
        return formDetailDao.deleteByEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体单条或者批量删除
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteByEntity(FormDetailVO formDetailVO) {
        int num= formDetailDao.deleteByEntity(formDetailVO);
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int deleteShamByEntity(FormDetailDO entity) {
        FormDetailVO formDetailVO=JsonUtils.parse(
            JsonUtils.serialize(entity),FormDetailVO.class);
        return formDetailDao.deleteShamByEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体假删除,根据实体属性单条或批量删除只是改变了状态不在页面显示,数据仍存在
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public ResponseWrapper deleteShamByEntity(FormDetailVO formDetailVO) {
        //自行在controller设置状态,则可删除,亦可还原
        int num= formDetailDao.deleteShamByEntity(formDetailVO);
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体查询数量
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public int selectCountByEntity(FormDetailVO formDetailVO) {
        int num= formDetailDao.selectCountByEntity(formDetailVO);
        return num;
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体(唯一标示)查询一条数据
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public FormDetailVO selectById(FormDetailDO entity) {
        FormDetailVO formDetailVO=JsonUtils.parse(
            JsonUtils.serialize(entity),FormDetailVO.class);
        return formDetailDao.selectById(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体(唯一标示)查询一条数据
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public FormDetailVO selectById(FormDetailVO formDetailVO) {
        FormDetailVO formDetailVODb= formDetailDao.selectById(formDetailVO);
        return formDetailVODb;
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体查询分页列表
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV 
     */
    public Page<FormDetailVO> selectPageByEntity(int pageNo,int pageSize
        ,FormDetailVO formDetailVO,String order) {
        PageHelper.startPage(pageNo,pageSize,order);
        return formDetailDao.selectPageByEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体查询列表
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<FormDetailVO> selectByEntity(FormDetailDO entity) {
        FormDetailVO formDetailVO=JsonUtils.parse(
            JsonUtils.serialize(entity),FormDetailVO.class);
        return formDetailDao.selectByEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体查询列表
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    public List<FormDetailVO> selectByEntity(FormDetailVO formDetailVO) {
        return formDetailDao.selectByEntity(formDetailVO);
    }

}
