package com.unis.inspectionresult.server.entity;
import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.MappedSuperclass;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.common.utils.CurrentUtil;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;


/**
 * 基础实体类
 * 所有继承该实体类的实体在映射成表的时候会自动加入该类中的字段
 *
 * @author huangxing
 */
@Getter
@Setter
@MappedSuperclass
public abstract class BaseEntity implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
     * 状态默认为1
     */
    @ApiModelProperty(value = "状态#(状态，1：正常，0：已作废)", notes ="状态")
    @Column(name="STATUS",length=5,precision=5,scale=0)
    private Integer status = 1;
    
    /**
     * 创建人
     */
    @ApiModelProperty(value = "创建人", notes ="创建人")
    @Column(name="CREATEOR",length=32)
    private String createor;
    
    /**
     * 创建人编号
     */
    @ApiModelProperty(value = "创建人编号", notes ="创建人编号")
    @Column(name="CREATEOR_CODE",length=18)
    private String createorCode;

    /**
     * 创建时间
     */
    @ApiModelProperty(value = "创建时间", notes ="创建时间")
    @Column(name="CREATE_DATE")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date createDate;

    /**
     * 刷新时间
     */
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date refreshTime;
    
    /**
     * 刷新人
     */
    @ApiModelProperty("刷新人")
	@Column(name="refresher")
    private String refresher;
    
    /**
     * 刷新时间
     */
    @ApiModelProperty(value = "刷新时间", notes ="刷新时间")
    @Column(name="REFRESH_DATE")
    @DateTimeFormat( pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "PRC")
    private Date refreshDate;
    
    /**
     * 刷新人编号
     */
    @ApiModelProperty("刷新人编号")
	@Column(name="refresher_code")
    private String refresherCode;

    /**
     * 备注
     */
    @ApiModelProperty("备注")
	@Column(name="remark")
    private String remark;

    /**
     * 后续加上创建人等信息
     */
    public void buildInsertData(){
        Date date=new Date();
        this.status=1;
        this.createDate=date;
        this.refreshDate=date;
        this.createor=CurrentUtil.getUserName();
        this.createorCode=CurrentUtil.getUserId();
    }

    /**
     * 后续加上修改人等信息
     */
    public void buildUpdateData(){
        Date date=new Date();
        this.refreshDate=date;
        this.refresher=CurrentUtil.getUserName();
        this.refresherCode=CurrentUtil.getUserId();
    }
}
