/*
 * DailyCheckResultDetailServiceImpl.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-30 16:13:16 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.service.impl;

import com.github.pagehelper.Page;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.base.PageResult;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultDetailListVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultDetailShowVO;
import com.unis.inspectionresult.common.vo.resultback.DailyCheckResultDetailVO;
import com.unis.inspectionresult.server.domain.resultback.DailyCheckResultDetailDomain;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckResultDetailDO;
import com.unis.inspectionresult.server.service.DailyCheckResultDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * T_BDJLZB-表单记录主表
 * @author lipenghe at 2019-08-30 16:13:16
 */
@Component
@Transactional
public class DailyCheckResultDetailServiceImpl implements DailyCheckResultDetailService {

    @Autowired
    DailyCheckResultDetailDomain dailyCheckResultDetailDomain;

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 插入全部字段
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntityResult(DailyCheckResultDetailVO resultDetailVO) {
        return dailyCheckResultDetailDomain.insertEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 插入全部字段,可删除部分字段改为选择性插入
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntitySelectiveResult(DailyCheckResultDetailVO resultDetailVO) {
        return dailyCheckResultDetailDomain.insertEntitySelective(resultDetailVO, null);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 更改状态
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateStatusByEntityResult(DailyCheckResultDetailVO resultDetailVO, String limit) {
        return dailyCheckResultDetailDomain.updateStatusByEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体更新单条或者多条数据
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntityResult(DailyCheckResultDetailVO resultDetailVO, String limit) {
        return dailyCheckResultDetailDomain.updateByEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体选择性更新
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(DailyCheckResultDetailVO resultDetailVO, String limit) {
        return dailyCheckResultDetailDomain.updateByEntitySelective(resultDetailVO, null);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体选择性更新,更新单表专属
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(DailyCheckResultDetailDO entity, String limit) {
        int num= dailyCheckResultDetailDomain.updateByEntitySelective(entity);
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体单条或者批量删除
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper deleteByEntityResult(DailyCheckResultDetailVO resultDetailVO, String limit) {
        return dailyCheckResultDetailDomain.deleteByEntity(resultDetailVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体(唯一标示)查询一条数据
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(DailyCheckResultDetailDO entity) {
        DailyCheckResultDetailVO resultDetailVO=dailyCheckResultDetailDomain.selectById(entity);
        DailyCheckResultDetailShowVO resultDetailShowVO= JsonUtils.parse(
            JsonUtils.serialize(resultDetailVO), DailyCheckResultDetailShowVO.class);
        return ResponseWrapper.success(resultDetailShowVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体(唯一标示)查询一条数据
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(DailyCheckResultDetailVO resultDetailVO) {
        DailyCheckResultDetailVO resultDetailVODb=dailyCheckResultDetailDomain.selectById(resultDetailVO);
        DailyCheckResultDetailShowVO resultDetailShowVO=JsonUtils.parse(
            JsonUtils.serialize(resultDetailVODb), DailyCheckResultDetailShowVO.class);
        return ResponseWrapper.success(resultDetailShowVO);
    }

    /**
     * <T_BDJLZB-表单记录主表>根据实体查询分页列表
     * 带限制条件
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectPageByEntityResult(int pageNo, int pageSize
        , DailyCheckResultDetailVO resultDetailVO, String order) {
        Page<DailyCheckResultDetailVO> resultDetailVOPage=dailyCheckResultDetailDomain.selectPageByEntity(pageNo,pageSize,resultDetailVO,order);
        PageResult<DailyCheckResultDetailVO> resultDetailVOPageResult=new PageResult<>(resultDetailVOPage);
        PageResult<DailyCheckResultDetailListVO> resultDetailListVOPageResult=JsonUtils.parse(
            JsonUtils.serialize(resultDetailVOPageResult),PageResult.class);
        return ResponseWrapper.success(resultDetailListVOPageResult);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体查询列表
     * @param entity    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByEntityResult(DailyCheckResultDetailDO entity) {
        List<DailyCheckResultDetailVO> resultDetailVOList=dailyCheckResultDetailDomain.selectByEntity(entity);
        List<DailyCheckResultDetailListVO> resultDetailListVOList=JsonUtils.parseList(
            JsonUtils.serialize(resultDetailVOList), DailyCheckResultDetailListVO.class);
        return ResponseWrapper.success(resultDetailListVOList);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回结果对象,带限制条件
     * 根据实体查询列表
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByEntityResult(DailyCheckResultDetailVO resultDetailVO) {
        List<DailyCheckResultDetailVO> resultDetailVOList=dailyCheckResultDetailDomain.selectByEntity(resultDetailVO);
        List<DailyCheckResultDetailListVO> resultDetailListVOList=JsonUtils.parseList(
            JsonUtils.serialize(resultDetailVOList), DailyCheckResultDetailListVO.class);
        return ResponseWrapper.success(resultDetailListVOList);
    }

    /**
     * <T_BDJLZB-表单记录主表>返回初始化数据
     * 根据实体查询初始化数据
     * @param resultDetailVO    <表单记录主表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectInitDataResult(DailyCheckResultDetailVO resultDetailVO) {
        return ResponseWrapper.success();
    }

}
