/*
 * DailyCheckResultServiceImpl.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-26 16:21:29 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.constant.UnitsTypeConstant;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.BaseKcVO;
import com.unis.inspectionresult.common.vo.ResultApplyQuery;
import com.unis.inspectionresult.common.vo.ResultApplyVO;
import com.unis.inspectionresult.common.vo.base.PageResult;
import com.unis.inspectionresult.common.vo.resultback.*;
import com.unis.inspectionresult.server.domain.resultback.DailyCheckResultDomain;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckProcessAdjustmentDO;
import com.unis.inspectionresult.server.entity.resultback.DailyCheckResultDO;
import com.unis.inspectionresult.server.service.DailyCheckResultService;
import com.unis.inspectiontask.common.vo.PerformanceQueryVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import java.util.Date;
import java.util.List;

/**
 * T_JCJG-检查结果
 *
 * @author lipenghe at 2019-08-26 16:21:29
 */
@Component
@Transactional
public class DailyCheckResultServiceImpl implements DailyCheckResultService {

	@Autowired
	DailyCheckResultDomain dailyCheckResultDomain;

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 插入全部字段
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper insertEntityResult(DailyCheckResultVO checkResultVO) {
		return dailyCheckResultDomain.insertEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 插入全部字段,可删除部分字段改为选择性插入
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper insertEntitySelectiveResult(DailyCheckResultVO checkResultVO) {
		ResponseWrapper responseWrapper = dailyCheckResultDomain.insertEntitySelective(checkResultVO);
		if (responseWrapper != null && responseWrapper.getInfoCode() == 200) {
			return ResponseWrapper.success(checkResultVO);
		}
		return responseWrapper;
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 更改状态
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper updateStatusByEntityResult(DailyCheckResultVO checkResultVO, String limit) {
		return dailyCheckResultDomain.updateStatusByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 结果反馈撤回
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper updateBackByEntity(DailyCheckResultVO checkResultVO, String limit) {
		return dailyCheckResultDomain.updateBackByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 制定任务的撤回,非结果反馈撤回
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper deleteBackByEntity(DailyCheckResultVO checkResultVO, String limit) {
		return dailyCheckResultDomain.deleteBackByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体更新单条或者多条数据
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper updateByEntityResult(DailyCheckResultVO checkResultVO, String limit) {
		return dailyCheckResultDomain.updateByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体选择性更新
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper updateByEntitySelectiveResult(DailyCheckResultVO checkResultVO, String limit) {
		ResponseWrapper responseWrapper = dailyCheckResultDomain.updateByEntitySelective(checkResultVO);
		if (responseWrapper != null && responseWrapper.getInfoCode() == 200) {
			return ResponseWrapper.success(checkResultVO);
		}
		return responseWrapper;
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体选择性更新,更新单表专属
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper updateByEntitySelectiveResult(DailyCheckResultDO entity, String limit) {
		int num = dailyCheckResultDomain.updateByEntitySelective(entity);
		return ResponseWrapper.choose(num);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体单条或者批量删除
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper deleteByEntityResult(DailyCheckResultVO checkResultVO, String limit) {
		// return dailyCheckResultDomain.deleteByEntity(checkResultVO);
		return dailyCheckResultDomain.deleteShamByEntity(checkResultVO);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体(唯一标示)查询一条数据
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper selectByIdResult(DailyCheckResultDO entity) {
		DailyCheckResultVO checkResultVO = dailyCheckResultDomain.selectById(entity);
		if (checkResultVO != null) {
			DailyCheckResultShowVO checkResultShowVO = JsonUtils.parse(JsonUtils.serialize(checkResultVO),
					DailyCheckResultShowVO.class);
			return ResponseWrapper.success(checkResultShowVO);
		}
		return ResponseWrapper.notFound();
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体(唯一标示)查询一条数据
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper selectByIdResult(DailyCheckResultVO checkResultVO) {
		DailyCheckResultVO checkResultVODb = dailyCheckResultDomain.selectById(checkResultVO);
		if (checkResultVODb != null) {
			DailyCheckResultShowVO checkResultShowVO = JsonUtils.parse(JsonUtils.serialize(checkResultVODb), DailyCheckResultShowVO.class);
			return ResponseWrapper.success(checkResultShowVO);
		}
		return ResponseWrapper.notFound();
	}

	/**
	 * <T_JCJG-检查结果>返回简单结果对象,带限制条件 根据实体(唯一标示)查询一条数据
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper selectSingleByIdResult(DailyCheckResultVO checkResultVO) {
		DailyCheckResultVO checkResultVODb = dailyCheckResultDomain.selectById(checkResultVO);
		if (checkResultVODb != null) {
			DailyCheckResultShowVO checkResultShowVO = JsonUtils.parse(JsonUtils.serialize(checkResultVODb),
					DailyCheckResultShowVO.class);
			return ResponseWrapper.success(checkResultShowVO);
		}
		return ResponseWrapper.notFound();
	}

	/**
	 * <T_JCJG-检查结果>根据实体查询分页列表 带限制条件
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper selectPageByEntityResult(int pageNo, int pageSize, DailyCheckResultVO checkResultVO, String order) {
		int type = checkResultVO.getType();
		Page<DailyCheckResultVO> checkResultVOPage;
		/*
		 * if(type==1){
		 * checkResultVOPage=dailyCheckResultDomain.selectDailyPageByEntity(pageNo,
		 * pageSize,checkResultVO,order); }else {
		 * checkResultVOPage=dailyCheckResultDomain.selectPageByEntity(pageNo,pageSize,
		 * checkResultVO,order); }
		 */
		if (checkResultVO.getDistinguish() != null) {
			checkResultVOPage = dailyCheckResultDomain.selectDailyPageByCompanyEntity(pageNo, pageSize, checkResultVO, order);
		} else {
			checkResultVOPage = dailyCheckResultDomain.selectDailyPageByEntity(pageNo, pageSize, checkResultVO, order);
		}
		PageResult<DailyCheckResultVO> checkResultVOPageResult = new PageResult<>(checkResultVOPage);
        PageResult<DailyCheckResultListVO> checkResultListVOPageResult = JsonUtils.parse(JsonUtils.serialize(checkResultVOPageResult), PageResult.class);
		return ResponseWrapper.success(checkResultListVOPageResult);
	}

	public ResponseWrapper dailyCheckResultYlCplPage(int pageNo, int pageSize, DailyCheckResultVO checkResultVO, String order) {
		int type = checkResultVO.getType();
		Page<DailyCheckResultVO> checkResultVOPage;
			checkResultVOPage = dailyCheckResultDomain.dailyCheckResultYlCplPage(pageNo, pageSize, checkResultVO, order);
		PageResult<DailyCheckResultVO> checkResultVOPageResult = new PageResult<DailyCheckResultVO>(checkResultVOPage);
		PageResult<DailyCheckResultListVO> checkResultListVOPageResult = JsonUtils.parse(JsonUtils.serialize(checkResultVOPageResult), PageResult.class);
		return ResponseWrapper.success(checkResultListVOPageResult);
		}

	/**
	 * <T_JCJG-检查结果>根据实体查询分页列表 带限制条件
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author wys
	 */
	@Override
	public ResponseWrapper dailyCheckResultPageForKSH(int pageNo, int pageSize, DailyCheckSearchVO dailyCheckSearchVO) {
		Page<DailyCheckResultVO> checkResultVOPage = dailyCheckResultDomain.dailyCheckResultPageForKSH(pageNo, pageSize, dailyCheckSearchVO);
		PageResult<DailyCheckResultVO> checkResultVOPageResult = new PageResult<DailyCheckResultVO>(checkResultVOPage);
		PageResult<DailyCheckResultListVO> checkResultListVOPageResult = JsonUtils
				.parse(JsonUtils.serialize(checkResultVOPageResult), PageResult.class);
		return ResponseWrapper.success(checkResultListVOPageResult);
	}

	/**
	 * <T_JCJG-检查结果>根据实体查询分页列表 带限制条件
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@SuppressWarnings({ "unused", "unchecked" })
	@Override
	public ResponseWrapper selectTeamPageByEntityResult(int pageNo, int pageSize, DailyCheckResultVO checkResultVO,
			String order) {
		int type = checkResultVO.getType();
		Page<DailyCheckResultVO> checkResultVOPage = dailyCheckResultDomain.selectTeamPageByEntity(pageNo, pageSize, checkResultVO, order);
		PageResult<DailyCheckResultVO> checkResultVOPageResult = new PageResult<>(checkResultVOPage.getTotal(), checkResultVOPage.getPages(), pageNo, checkResultVOPage);
        PageResult<DailyCheckResultListVO> checkResultListVOPageResult = JsonUtils.parse(JsonUtils.serialize(checkResultVOPageResult), PageResult.class);
		return ResponseWrapper.success(checkResultListVOPageResult);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体查询列表
	 *
	 * @param entity <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper selectByEntityResult(DailyCheckResultDO entity) {
		List<DailyCheckResultVO> checkResultVOList = dailyCheckResultDomain.selectByEntity(entity);
		List<DailyCheckResultListVO> checkResultListVOList = JsonUtils.parseList(JsonUtils.serialize(checkResultVOList),
				DailyCheckResultListVO.class);
		return ResponseWrapper.success(checkResultListVOList);
	}

	/**
	 * <T_JCJG-检查结果>返回结果对象,带限制条件 根据实体查询列表
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper selectByEntityResult(DailyCheckResultVO checkResultVO) {
		List<DailyCheckResultVO> checkResultVOList = dailyCheckResultDomain.selectByEntity(checkResultVO);
		List<DailyCheckResultListVO> checkResultListVOList = JsonUtils.parseList(JsonUtils.serialize(checkResultVOList),
				DailyCheckResultListVO.class);
		return ResponseWrapper.success(checkResultListVOList);
	}

	/**
	 * <T_JCJG-检查结果>返回初始化数据 根据实体查询初始化数据
	 *
	 * @param checkResultVO <检查结果>对象
	 * @author lipenghe with LAPTOP-IJQ2SDFV
	 */
	@Override
	public ResponseWrapper selectInitDataResult(DailyCheckResultVO checkResultVO) {
		return ResponseWrapper.success(checkResultVO);
	}

	/**
	 * 查询列表
	 */
	@Override
	public PageInfo<DailyCheckResultQJVO> getAllList(DailyCheckResultQueryVO vo) {
		PageInfo<DailyCheckResultQJVO> allList = dailyCheckResultDomain.getAllList(vo);
		return allList;

	}

	/**
	 * (非 Javadoc)
	 * <p>
	 * Title: selectQyZgLists
	 * </p>
	 * <p>
	 * Description: 企业整改数据统计 - 整改
	 * </p>
	 *
	 * @param checkResultVO
	 * @return
	 * @see com.unis.inspectionresult.server.service.DailyCheckResultService#selectQyZgLists(com.unis.inspectionresult.common.vo.resultback.DailyCheckResultVO)
	 */
	@Override
	public ResponseWrapper selectQyZgLists(String year) {
		DailyCheckResultQuarterListVO dailyCheckResultQuarterVO = dailyCheckResultDomain.selectQyZgLists(year);
		return ResponseWrapper.success(dailyCheckResultQuarterVO);
	}

	@Override
	public ResponseWrapper inspectionResultExport(DailyCheckResultVO checkResultVO, String order) {
		Page<DailyCheckResultVO> checkResultVOPage;
		/*
		 * if(type==1){
		 * checkResultVOPage=dailyCheckResultDomain.selectDailyPageByEntity(pageNo,
		 * pageSize,checkResultVO,order); }else {
		 * checkResultVOPage=dailyCheckResultDomain.selectPageByEntity(pageNo,pageSize,
		 * checkResultVO,order); }
		 */
		checkResultVOPage = dailyCheckResultDomain.inspectionResultExport(checkResultVO, order);
		PageResult<DailyCheckResultVO> checkResultVOPageResult = new PageResult<DailyCheckResultVO>(checkResultVOPage);
		PageResult<DailyCheckResultListVO> checkResultListVOPageResult = JsonUtils
				.parse(JsonUtils.serialize(checkResultVOPageResult), PageResult.class);
		return ResponseWrapper.success(checkResultListVOPageResult);
	}

	@Override
	public DailyCheckInspectionTimeAndResultIdVO getInspectionTime(String rwId, String bjdwId) {
		return dailyCheckResultDomain.getInspectionTime(rwId, bjdwId);
	}

	/**
	 * 调整流程-添加
	 */
	@Override
	public boolean insertProcessAdjustment(DailyCheckProcessAdjustmentAddVO record) {
		if (ObjectUtils.isEmpty(record)) {
			return false;
		}
		DailyCheckProcessAdjustmentDO entity = new DailyCheckProcessAdjustmentDO();
		LsBeanUtils.copyAllProperties(record, entity);
		entity.setLclx(UnitsTypeConstant.PROCESS_ADJUSTMENT);
		boolean result = dailyCheckResultDomain.insertProcessAdjustment(entity);
		if(result) {
			result = this.updateCheckResultStatus(record, null);
		}
		return result;
	}

	/**
	 * 调整流程-修改
	 */
	@Override
	public boolean updateProcessAdjustment(DailyCheckProcessAdjustmentAddVO record) {
		if (ObjectUtils.isEmpty(record)) {
			return false;
		}
		DailyCheckProcessAdjustmentDO entity = new DailyCheckProcessAdjustmentDO();
		LsBeanUtils.copyAllProperties(record, entity);
		boolean result = dailyCheckResultDomain.updateProcessAdjustment(entity);
		if(result) {
			result = this.updateCheckResultStatus(record, null);
		}
		return result;
	}

	/**
	 * 调整流程-审核
	 */
	@Override
	public boolean auditProcessAdjustment(DailyCheckProcessAdjustmentAuditVO record) {
		if (ObjectUtils.isEmpty(record)) {
			return false;
		}
		DailyCheckProcessAdjustmentDO entity = new DailyCheckProcessAdjustmentDO();
		LsBeanUtils.copyAllProperties(record, entity);
		boolean result = dailyCheckResultDomain.updateProcessAdjustment(entity);
		if(result) {
			result = this.updateCheckResultStatus(null, record);
		}
		return result;
	}

	/**
	 *
	 * @Description: 修改检查结果状态
	 * @author: 王帅
	 * @param: @param  addVO
	 * @param: @param  auditVO
	 * @param: @return 参数
	 * @return: boolean 返回类型
	 */
	public boolean updateCheckResultStatus(DailyCheckProcessAdjustmentAddVO addVO,
										   DailyCheckProcessAdjustmentAuditVO auditVO) {
		boolean result = false;
		DailyCheckResultDO checkResult = new DailyCheckResultDO();
		if (!ObjectUtils.isEmpty(addVO)) {
			checkResult.setJgId(addVO.getJgId());
			checkResult.setJgTbbh(addVO.getJgTbbh());
			checkResult.setJgTbmc(addVO.getJgTbmc());
		} else {
			checkResult.setJgId(auditVO.getJgId());
			checkResult.setJgTbbh(auditVO.getJgTbbh());
			checkResult.setJgTbmc(auditVO.getJgTbmc());
		}

		result = dailyCheckResultDomain.updateCheckResultStatus(checkResult);

		return result;
	}

	@Override
	public DailyCheckProcessAdjustmentShowVO viewProcessAdjustment(String checkResultId) {
		DailyCheckProcessAdjustmentShowVO showVO = null;
		DailyCheckProcessAdjustmentDO entity = dailyCheckResultDomain.viewProcessAdjustment(checkResultId, UnitsTypeConstant.PROCESS_ADJUSTMENT);
		if (!ObjectUtils.isEmpty(entity)) {
			showVO = new DailyCheckProcessAdjustmentShowVO();
			LsBeanUtils.copyAllProperties(entity, showVO);
		}

		return showVO;
	}

	/**
	 * 根据任务id查询特定状态结果数据
	 * @param performanceQueryVO
	 * @return
	 */
	@Override
	public List<DailyCheckResultPerformanceVO> getinspectionList(PerformanceQueryVO performanceQueryVO) {
		return dailyCheckResultDomain.getinspectionList(performanceQueryVO);
	}

	/**
	 * 根据结果id列表结果数据
	 * @param performanceQueryVO
	 * @return
	 */
	@Override
	public List<DailyCheckResultVO> getInspectionListByjgIdList(PerformanceQueryVO performanceQueryVO) {
		return dailyCheckResultDomain.getInspectionListByjgIdList(performanceQueryVO);
	}

	/**
	 * 根据任务时间查询特定状态结果数据
	 * @param developmentSituationQueryVO
	 * @return
	 */
	@Override
	public DevelopmentSituationVO developmentSituation(DevelopmentSituationQueryVO developmentSituationQueryVO) {
		return dailyCheckResultDomain.developmentSituation(developmentSituationQueryVO);
	}

	/**
	 * 根据任务时间查询任务列表
	 * @param developmentSituationQueryVO
	 * @return
	 */
	@Override
	public List<String> developmentSituationByRwIdList(DevelopmentSituationQueryVO developmentSituationQueryVO) {
		return dailyCheckResultDomain.developmentSituationByRwIdList(developmentSituationQueryVO);
	}

	/**
	 *
	 * @Description: 展示检查结果列表通过计划Id
	 * @author: 王帅
	 * @param: @param  planId
	 * @param: @return 参数
	 * @return: List<DailyCheckResultVO> 返回类型
	 */
	@Override
	public List<DailyCheckResultByPlanShowVO> getCheckResultListByPlanId(String planId) {
		return dailyCheckResultDomain.getCheckResultListByPlanId(planId);
	}

	/**
	 *
	 * @Description: 获取监管区域
	 * @author: 王帅
	 * @param: @param  orgId
	 * @param: @return 参数
	 * @return: List<DailyCheckTerritorialSupervisionVO> 返回类型
	 */
	@Override
	public List<DailyCheckTerritorialSupervisionVO> getTerritorialSupervisionByOrgId(String orgId){
		return dailyCheckResultDomain.getTerritorialSupervisionByOrgId(orgId);
	}

	@Override
	public PageInfo<DailyCheckResultVO> getInspectionResultPageByjgIdList(PerformanceQueryVO performanceQueryVO) {
		return dailyCheckResultDomain.getInspectionResultPageByjgIdList(performanceQueryVO);
	}

	@Override
	public ResponseWrapper dailyCheckResultList(String bjdwid) {
		List<DailyCheckResultVO> checkResultVOs = dailyCheckResultDomain.dailyCheckResultList(bjdwid);
		return ResponseWrapper.success(checkResultVOs);
	}

	@Override
	public ResponseWrapper resultList(int pageNum, int pageSize, ResultApplyQuery resultApplyQuery, String string) {
		Page<ResultApplyVO> resultApplyVOs;

		resultApplyVOs = dailyCheckResultDomain.selectDailyPageByEntity(pageNum, pageSize, resultApplyQuery, string);
		PageResult<ResultApplyVO> checkResultVOPageResult = new PageResult<ResultApplyVO>(resultApplyVOs);
		PageResult<ResultApplyVO> checkResultListVOPageResult = JsonUtils
				.parse(JsonUtils.serialize(checkResultVOPageResult), PageResult.class);
		return ResponseWrapper.success(checkResultListVOPageResult);
	}

	@Override
	public ResponseWrapper resultListDis(int pageNum, int pageSize, ResultApplyQuery resultApplyQuery, String string) {
		Page<ResultApplyVO> resultApplyVOs;
		resultApplyVOs = dailyCheckResultDomain.selectDailyDisPageByEntity(pageNum, pageSize, resultApplyQuery, string);
		PageResult<ResultApplyVO> checkResultVOPageResult = new PageResult<ResultApplyVO>(resultApplyVOs);
		PageResult<ResultApplyVO> checkResultListVOPageResult = JsonUtils
				.parse(JsonUtils.serialize(checkResultVOPageResult), PageResult.class);
		return ResponseWrapper.success(checkResultListVOPageResult);
	}

	@Override
	public List<BaseKcVO> selectKcxx(String tyshxydm) {
		return dailyCheckResultDomain.selectKc(tyshxydm);
	}

	@Override
	public List<BaseKcVO> selectChengPinKc(String tyshxydm) {
		return dailyCheckResultDomain.selectChengPinKc(tyshxydm);
	}

	public List<BaseKcVO> selectBatchWd(List<String> cfbhList){
		return dailyCheckResultDomain.selectBatchWd(cfbhList);
	}
}
