/*
 * FormDetailServiceImpl.java
 * 版权所有 © 2011-2017 北京神舟良实信息技术有限公司
 * Copyright © 2011-2017 All Rights Reserved    京ICP备13013562号
 * 2019-08-30 16:13:16 created by lipenghe with LAPTOP-IJQ2SDFV
 */
package com.unis.inspectionresult.server.service.impl;

import com.github.pagehelper.Page;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.utils.JsonUtils;
import com.unis.inspectionresult.common.vo.base.PageResult;
import com.unis.inspectionresult.common.vo.resultback.FormDetailListVO;
import com.unis.inspectionresult.common.vo.resultback.FormDetailShowVO;
import com.unis.inspectionresult.common.vo.resultback.FormDetailVO;
import com.unis.inspectionresult.server.domain.resultback.FormDetailDomain;
import com.unis.inspectionresult.server.entity.resultback.FormDetailDO;
import com.unis.inspectionresult.server.service.FormDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * T_BDJLMX-储备粮公司-表单记录明细表
 * @author lipenghe at 2019-08-30 16:13:16
 */
@Component
@Transactional
public class FormDetailServiceImpl implements FormDetailService {

    @Autowired
    FormDetailDomain formDetailDomain;

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 插入全部字段
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntityResult(FormDetailVO formDetailVO) {
        return formDetailDomain.insertEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 插入全部字段,可删除部分字段改为选择性插入
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper insertEntitySelectiveResult(FormDetailVO formDetailVO) {
        return formDetailDomain.insertEntitySelective(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 更改状态
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateStatusByEntityResult(FormDetailVO formDetailVO, String limit) {
        return formDetailDomain.updateStatusByEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体更新单条或者多条数据
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntityResult(FormDetailVO formDetailVO, String limit) {
        return formDetailDomain.updateByEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体选择性更新
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(FormDetailVO formDetailVO, String limit) {
        return formDetailDomain.updateByEntitySelective(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体选择性更新,更新单表专属
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper updateByEntitySelectiveResult(FormDetailDO entity, String limit) {
        int num= formDetailDomain.updateByEntitySelective(entity);
        return ResponseWrapper.choose(num);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体单条或者批量删除
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper deleteByEntityResult(FormDetailVO formDetailVO, String limit) {
        return formDetailDomain.deleteByEntity(formDetailVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体(唯一标示)查询一条数据
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(FormDetailDO entity) {
        FormDetailVO formDetailVO=formDetailDomain.selectById(entity);
        FormDetailShowVO formDetailShowVO= JsonUtils.parse(
            JsonUtils.serialize(formDetailVO), FormDetailShowVO.class);
        return ResponseWrapper.success(formDetailShowVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体(唯一标示)查询一条数据
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByIdResult(FormDetailVO formDetailVO) {
        FormDetailVO formDetailVODb=formDetailDomain.selectById(formDetailVO);
        FormDetailShowVO formDetailShowVO=JsonUtils.parse(
            JsonUtils.serialize(formDetailVODb), FormDetailShowVO.class);
        return ResponseWrapper.success(formDetailShowVO);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>根据实体查询分页列表
     * 带限制条件
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectPageByEntityResult(int pageNo, int pageSize
        , FormDetailVO formDetailVO, String order) {
        Page<FormDetailVO> formDetailVOPage=formDetailDomain.selectPageByEntity(pageNo,pageSize,formDetailVO,order);
        PageResult<FormDetailVO> formDetailVOPageResult=new PageResult<>(formDetailVOPage);
        PageResult<FormDetailListVO> formDetailListVOPageResult=JsonUtils.parse(
            JsonUtils.serialize(formDetailVOPageResult),PageResult.class);
        return ResponseWrapper.success(formDetailListVOPageResult);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体查询列表
     * @param entity    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByEntityResult(FormDetailDO entity) {
        List<FormDetailVO> formDetailVOList=formDetailDomain.selectByEntity(entity);
        List<FormDetailListVO> formDetailListVOList=JsonUtils.parseList(
            JsonUtils.serialize(formDetailVOList), FormDetailListVO.class);
        return ResponseWrapper.success(formDetailListVOList);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回结果对象,带限制条件
     * 根据实体查询列表
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectByEntityResult(FormDetailVO formDetailVO) {
        List<FormDetailVO> formDetailVOList=formDetailDomain.selectByEntity(formDetailVO);
        List<FormDetailListVO> formDetailListVOList=JsonUtils.parseList(
            JsonUtils.serialize(formDetailVOList), FormDetailListVO.class);
        return ResponseWrapper.success(formDetailListVOList);
    }

    /**
     * <T_BDJLMX-储备粮公司-表单记录明细表>返回初始化数据
     * 根据实体查询初始化数据
     * @param formDetailVO    <储备粮公司-表单记录明细表>对象
     * @author lipenghe with LAPTOP-IJQ2SDFV
     */
    @Override
    public ResponseWrapper selectInitDataResult(FormDetailVO formDetailVO) {
        return ResponseWrapper.success();
    }

}
