package com.unis.inspectionresult.server.service.impl;

import cn.hutool.core.util.StrUtil;
import com.github.pagehelper.PageHelper;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionresult.common.vo.*;
import com.unis.inspectionresult.server.dao.TrcjcfxwtMapper;
import com.unis.inspectionresult.server.dao.TrcjcshqkMapper;
import com.unis.inspectionresult.server.dao.TrcjczbMapper;
import com.unis.inspectionresult.server.dao.TrcjczgqkMapper;
import com.unis.inspectionresult.server.entity.TrcjcfxwtDO;
import com.unis.inspectionresult.server.entity.TrcjcshqkDO;
import com.unis.inspectionresult.server.entity.TrcjczbDO;
import com.unis.inspectionresult.server.entity.TrcjczgqkDO;
import com.unis.inspectionresult.server.service.TrcjczbService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @Classname TrcjczbServiceImpl
 * @Description 日常检查主表服务层实现类
 * @Date 2023/11/20 14:14
 * @Created by rising123sun
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class TrcjczbServiceImpl implements TrcjczbService {

    @Resource
    private TrcjczbMapper trcjczbMapper;

    @Resource
    private TrcjczgqkMapper trcjczgqkMapper;

    @Resource
    private TrcjcshqkMapper trcjcshqkMapper;

    @Resource
    private TrcjcfxwtMapper trcjcfxwtMapper;

    @Override
    public List<TrcjczbVO> queryPageList(Integer pageSize, Integer pageNum, TrcjczbVO trcjczbVO) {
        PageHelper.startPage(pageNum, pageSize);
        // 根据pageType判断是市级管理端，区级管理端，企业端
        String orgId = CurrentUtil.getOrgId();
        trcjczbVO.setOrgCode(orgId);
        List<TrcjczbVO> list = trcjczbMapper.queryPageList(trcjczbVO);
        // 针对管理端是否可撤回以及是否可驳回判断
        if (trcjczbVO.getPageType().equals("1") || trcjczbVO.getPageType().equals("2")) {
            if (list.size() > 0) {
                for (TrcjczbVO vo : list) {
                    // jcfxwttjsj的24小时内可以撤回
                    if (vo.getJcfxwttjsj() != null) {
                        // 获取当前时间
                        Date date = new Date();
                        // 获取当前时间的前24小时
                        Calendar calendar = Calendar.getInstance();
                        calendar.setTime(date);
                        calendar.add(Calendar.HOUR_OF_DAY, -24);
                        Date time = calendar.getTime();
                        // 判断当前时间是否在提交后24小时内
                        if (vo.getJcfxwttjsj().getTime() > time.getTime()) {
                            vo.setSfkch("1");
                        } else {
                            vo.setSfkch("0");
                        }
                    } else {
                        vo.setSfkch("0");
                    }
                    // wcsj的30天内可以驳回
                    if (vo.getWcsj() != null && (vo.getShzt().equals("已完成") || vo.getShzt().equals("超期完成"))) {
                        // 获取当前时间
                        Date date = new Date();
                        // 获取当前时间的前30天
                        Calendar calendar = Calendar.getInstance();
                        calendar.setTime(date);
                        calendar.add(Calendar.HOUR_OF_DAY, -30 * 24);
                        Date time = calendar.getTime();
                        // 判断当前时间是否在提交后30天内
                        if (vo.getWcsj().getTime() > time.getTime()) {
                            vo.setSfkbh("1");
                        } else {
                            vo.setSfkbh("0");
                        }
                    } else {
                        vo.setSfkbh("0");
                    }
                }
            }
        }
        return list;
    }

    @Override
    public void add(TrcjczbVO trcjczbVO) {
        // 保存日常检查主表
        TrcjczbDO trcjczbDO = new TrcjczbDO();
        BeanUtils.copyProperties(trcjczbVO, trcjczbDO);
        trcjczbDO.setId(UUID.randomUUID().toString().replace("-", ""));
        // 根据统一社会信用代码查询orgCode
        String orgCode = "";
        if (StringUtils.isNotBlank(trcjczbVO.getTyshxydm())) {
            orgCode = trcjczbMapper.selectOrgCodeByTyshxydm(trcjczbVO.getTyshxydm());
        }
        trcjczbDO.setTyshxydm(trcjczbVO.getTyshxydm());
        trcjczbDO.setOrgCode(orgCode);
        trcjczbDO.setBjdwbm(trcjczbVO.getBjdwbm() + "001");

        List<TrcjcfxwtVO> trcjcfxwtVOList = trcjczbVO.getTrcjcfxwtVOList();
        if (trcjcfxwtVOList != null && trcjcfxwtVOList.size() > 0) {
            // 取集合中元素的zglx，如果存在限期整改，trcjczbDO的zglx为限期整改
            List<String> zglxList = trcjcfxwtVOList.stream().map(TrcjcfxwtVO::getZglx).collect(Collectors.toList());
            if (zglxList.contains("限期整改")) {
                trcjczbDO.setZglx("限期整改");
            } else {
                if (zglxList.contains("现场整改")) {
                    trcjczbDO.setZglx("现场整改");
                } else {
                    trcjczbDO.setZglx("无需整改");
                }
            }
            // 取集合中是否需属地跟踪整改情况，如果存在1，trcjczbDO的sfxsdgzgqk为1
            List<String> sfxsdgzgqkList = trcjcfxwtVOList.stream().map(TrcjcfxwtVO::getSfxsdgzgqk).collect(Collectors.toList());
            if (sfxsdgzgqkList.contains("1")) {
                trcjczbDO.setSfxsdgzgqk("1");
            } else {
                trcjczbDO.setSfxsdgzgqk("0");
            }
            for (TrcjcfxwtVO trcjcfxwtVO : trcjcfxwtVOList) {
                TrcjcfxwtDO trcjcfxwtDO = new TrcjcfxwtDO();
                BeanUtils.copyProperties(trcjcfxwtVO, trcjcfxwtDO);
                trcjcfxwtDO.setId(UUID.randomUUID().toString().replace("-", ""));
                trcjcfxwtDO.setJcid(trcjczbDO.getId());
                trcjcfxwtMapper.insert(trcjcfxwtDO);
            }
        }
        trcjczbMapper.insert(trcjczbDO);
    }

    @Override
    public ResponseWrapper update(TrcjczbVO trcjczbVO) {
        // 针对已撤回，提交后24小时内的可以进行撤销，超过24小时的不可以撤销
        TrcjczbDO trcjczbDO = trcjczbMapper.selectByPrimaryKey(trcjczbVO.getId());
        if (trcjczbDO != null) {
            if (trcjczbVO.getShzt().equals("已撤回")) {
                // 获取当前时间
                Date date = new Date();
                // 获取当前时间的前24小时
                Calendar calendar = Calendar.getInstance();
                calendar.setTime(date);
                calendar.add(Calendar.HOUR_OF_DAY, -24);
                Date time = calendar.getTime();
                // 判断当前时间是否在提交后24小时内
                if (trcjczbDO.getJcfxwttjsj().getTime() < time.getTime()) {
                    // 不可以撤销
                    return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "已超过撤销时间,无法撤销", null);
                }
            }
            // 对于已完成或者超期完成的数据，在提交后30天内(转换成小时)可以驳回，状态为已驳回
            if (trcjczbVO.getShzt().equals("已驳回")) {
                // 获取当前时间
                Date date = new Date();
                // 获取当前时间的前30天
                Calendar calendar = Calendar.getInstance();
                calendar.setTime(date);
                calendar.add(Calendar.HOUR_OF_DAY, -30 * 24);
                Date time = calendar.getTime();
                // 判断当前时间是否在提交后30天内
                if (trcjczbDO.getWcsj() != null && trcjczbDO.getWcsj().getTime() < time.getTime()) {
                    // 不可以驳回
                    return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "已超过驳回时间,无法驳回", null);
                }
                // 已驳回，将TrcjcshqkDO的相关数据的sfzxjl设置为0，同时新增trcjczbVO中的TrcjcshqkDO数据，将sfzxjl设置为1
                // 将TrcjcshqkDO的相关数据的sfzxjl设置为0
                Example example = new Example(TrcjcshqkDO.class);
                Example.Criteria criteria = example.createCriteria();
                criteria.andEqualTo("jcid", trcjczbVO.getId());
                List<TrcjcshqkDO> trcjcshqkDOList = trcjcshqkMapper.selectByExample(example);
                if (trcjcshqkDOList != null && trcjcshqkDOList.size() > 0) {
                    for (TrcjcshqkDO trcjcshqkDO : trcjcshqkDOList) {
                        trcjcshqkDO.setSfzxjl("0");
                        trcjcshqkMapper.updateByPrimaryKeySelective(trcjcshqkDO);
                    }
                }
                // 新增trcjczbVO中的TrcjcshqkDO数据，将sfzxjl设置为1
                TrcjcshqkVO trcjcshqkVO = trcjczbVO.getTrcjcshqkVO();
                if (trcjcshqkVO != null) {
                    TrcjcshqkDO trcjcshqkDO = new TrcjcshqkDO();
                    BeanUtils.copyProperties(trcjcshqkVO, trcjcshqkDO);
                    trcjcshqkDO.setId(UUID.randomUUID().toString().replace("-", ""));
                    trcjcshqkDO.setJcid(trcjczbVO.getId());
                    trcjcshqkDO.setSfzxjl("1");
                    trcjcshqkMapper.insert(trcjcshqkDO);
                }
            }
            // 如果trcjczbDO的shzt是已驳回，并且trcjczbVO的shzt是已整改待盖章,将TrcjczgqkDO的相关数据的sfzxjl设置为0，同时新增trcjczbVO中的TrcjczgqkDO数据，将sfzxjl设置为1
            if (trcjczbDO.getShzt().equals("已驳回") && trcjczbVO.getShzt().equals("已整改待盖章")) {
                // 将TrcjczgqkDO的相关数据的sfzxjl设置为0
                Example example = new Example(TrcjczgqkDO.class);
                Example.Criteria criteria = example.createCriteria();
                criteria.andEqualTo("jcid", trcjczbVO.getId());
                List<TrcjczgqkDO> trcjczgqkDOList = trcjczgqkMapper.selectByExample(example);
                if (trcjczgqkDOList != null && trcjczgqkDOList.size() > 0) {
                    for (TrcjczgqkDO trcjczgqkDO : trcjczgqkDOList) {
                        trcjczgqkDO.setSfzxjl("0");
                        trcjczgqkMapper.updateByPrimaryKeySelective(trcjczgqkDO);
                    }
                }
                // 新增trcjczbVO中的TrcjczgqkDO数据，将sfzxjl设置为1
                TrcjczgqkVO trcjczgqkVO = trcjczbVO.getTrcjczgqkVO();
                if (trcjczgqkVO != null) {
                    TrcjczgqkDO trcjczgqkDO = new TrcjczgqkDO();
                    BeanUtils.copyProperties(trcjczgqkVO, trcjczgqkDO);
                    trcjczgqkDO.setId(UUID.randomUUID().toString().replace("-", ""));
                    trcjczgqkDO.setJcid(trcjczbVO.getId());
                    trcjczgqkDO.setSfzxjl("1");
                    trcjczgqkMapper.insert(trcjczgqkDO);
                }
            } else {
                // 删除原有的检查整改情况当中sfzxjl为1的数据，新增trcjczbVO中的TrcjczgqkDO数据，将sfzxjl设置为1
                Example example = new Example(TrcjczgqkDO.class);
                Example.Criteria criteria = example.createCriteria();
                criteria.andEqualTo("jcid", trcjczbVO.getId()).andEqualTo("sfzxjl", "1");
                trcjczgqkMapper.deleteByExample(example);
                // 新增trcjczbVO中的TrcjczgqkDO数据，将sfzxjl设置为1
                TrcjczgqkVO trcjczgqkVO = trcjczbVO.getTrcjczgqkVO();
                if (trcjczgqkVO != null) {
                    TrcjczgqkDO trcjczgqkDO = new TrcjczgqkDO();
                    BeanUtils.copyProperties(trcjczgqkVO, trcjczgqkDO);
                    trcjczgqkDO.setId(UUID.randomUUID().toString().replace("-", ""));
                    trcjczgqkDO.setJcid(trcjczbVO.getId());
                    trcjczgqkDO.setSfzxjl("1");
                    trcjczgqkMapper.insert(trcjczgqkDO);
                }
            }
            // 检查发现问题修改
            List<TrcjcfxwtVO> trcjcfxwtVOList = trcjczbVO.getTrcjcfxwtVOList();
            if (trcjcfxwtVOList != null && trcjcfxwtVOList.size() > 0) {
                // 取集合中元素的zglx，如果存在限期整改，trcjczbDO的zglx为限期整改
                List<String> zglxList = trcjcfxwtVOList.stream().map(TrcjcfxwtVO::getZglx).collect(Collectors.toList());
                if (zglxList.contains("限期整改")) {
                    trcjczbVO.setZglx("限期整改");
                } else {
                    if (zglxList.contains("现场整改")) {
                        trcjczbVO.setZglx("现场整改");
                    } else {
                        trcjczbVO.setZglx("无需整改");
                    }
                }
                // 取集合中是否需属地跟踪整改情况，如果存在1，trcjczbDO的sfxsdgzgqk为1
                List<String> sfxsdgzgqkList = trcjcfxwtVOList.stream().map(TrcjcfxwtVO::getSfxsdgzgqk).collect(Collectors.toList());
                if (sfxsdgzgqkList.contains("1")) {
                    trcjczbVO.setSfxsdgzgqk("1");
                } else {
                    trcjczbVO.setSfxsdgzgqk("0");
                }
                // 删除原有的检查发现问题
                Example example = new Example(TrcjcfxwtDO.class);
                Example.Criteria criteria = example.createCriteria();
                criteria.andEqualTo("jcid", trcjczbVO.getId());
                trcjcfxwtMapper.deleteByExample(example);
                // 重新添加检查发现问题
                for (TrcjcfxwtVO trcjcfxwtVO : trcjcfxwtVOList) {
                    TrcjcfxwtDO trcjcfxwtDO = new TrcjcfxwtDO();
                    BeanUtils.copyProperties(trcjcfxwtVO, trcjcfxwtDO);
                    trcjcfxwtDO.setId(UUID.randomUUID().toString().replace("-", ""));
                    trcjcfxwtDO.setJcid(trcjczbVO.getId());
                    trcjcfxwtMapper.insert(trcjcfxwtDO);
                }
            }
            // 修改
            TrcjczbDO trcjczbDO1 = new TrcjczbDO();
            BeanUtils.copyProperties(trcjczbVO, trcjczbDO1);
            // 根据统一社会信用代码查询orgCode
            if (StringUtils.isNotBlank(trcjczbVO.getTyshxydm())) {
                String orgCode = trcjczbMapper.selectOrgCodeByTyshxydm(trcjczbVO.getTyshxydm());
                trcjczbDO1.setTyshxydm(trcjczbVO.getTyshxydm());
                trcjczbDO1.setOrgCode(orgCode);
            }

            if (StringUtils.isNotBlank(trcjczbVO.getBjdwbm()) && !trcjczbVO.getBjdwbm().endsWith("001")) {
                trcjczbDO1.setBjdwbm(trcjczbVO.getBjdwbm() + "001");
            }

            trcjczbMapper.updateByPrimaryKeySelective(trcjczbDO1);

            // todo 代办已办
            return ResponseWrapper.success(HttpStatus.OK.value(), "修改成功", null);

        } else {
            return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "未查询到该条数据", null);
        }
    }

    @Override
    public void delete(String id) {
        // 先删除发现问题相关的数据
        Example trcjcfxwtExample = new Example(TrcjcfxwtDO.class);
        trcjcfxwtExample.createCriteria().andEqualTo("jcid", id);
        trcjcfxwtMapper.deleteByExample(trcjcfxwtExample);

        // 删除审核情况相关的数据
        Example trcjcshqkExample = new Example(TrcjcshqkDO.class);
        trcjcshqkExample.createCriteria().andEqualTo("jcid", id);
        trcjcshqkMapper.deleteByExample(trcjcshqkExample);

        // 删除整改情况相关的数据
        Example trcjczgqkExample = new Example(TrcjczgqkDO.class);
        trcjczgqkExample.createCriteria().andEqualTo("jcid", id);
        trcjczgqkMapper.deleteByExample(trcjczgqkExample);

        // 删除日常检查主表
        trcjczbMapper.deleteByPrimaryKey(id);
    }

    @Override
    public Map<String, List<Dcfxx>> selectCfxxByEntity(DCfxxsjyVO dCfxxsjyVO) {
        List<DCfxxsjyVO> dCfxxsjyVOList = trcjczbMapper.selectCfxxByEntity(dCfxxsjyVO);
        // 关联TrcjczbDO表中的cfbh（逗号隔开）的记录，分成未检仓房和已检仓房
        Map<String, List<Dcfxx>> map = new HashMap<>();
        Example example = new Example(TrcjczbDO.class);
        Example.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(dCfxxsjyVO.getKddm())) {
            criteria.andEqualTo("bjdwbm", dCfxxsjyVO.getKddm());
        }
        if (StringUtils.isNotBlank(dCfxxsjyVO.getJcnf())) {
            criteria.andEqualTo("jcnf", dCfxxsjyVO.getJcnf());
        }
        // 检查状态不等于已撤销
        criteria.andNotEqualTo("shzt", "已撤销");
        List<TrcjczbDO> trcjczbDOList = trcjczbMapper.selectByExample(example);
        // 已检仓房为dCfxxsjyVOList当中cfbh包含在cfbhList当中的数据,并且记录这个仓房的出现次数
        List<Dcfxx> yjcfList = new ArrayList<>();
        // 未检仓房为dCfxxsjyVOList当中cfbh不包含在cfbhList当中的数据
        List<Dcfxx> wjcfList = new ArrayList<>();
        if (dCfxxsjyVOList != null && dCfxxsjyVOList.size() > 0) {
            if (StringUtils.isNotBlank(dCfxxsjyVO.getYjcfbm())) {
                String[] jccfbmArr = dCfxxsjyVO.getYjcfbm().split(",");
                List<String> jccfbmList = Arrays.asList(jccfbmArr);
                for (DCfxxsjyVO cfxxsjyVO : dCfxxsjyVOList) {
                    String cfbh = cfxxsjyVO.getCfbh();
                    if (jccfbmList.contains(cfbh)) {
                        Dcfxx dcfxx = new Dcfxx();
                        BeanUtils.copyProperties(cfxxsjyVO, dcfxx);
                        // 记录出现次数
                        int count = Collections.frequency(jccfbmList, cfbh);
                        dcfxx.setBjccs(count);
                        yjcfList.add(dcfxx);
                    } else {
                        Dcfxx dcfxx = new Dcfxx();
                        BeanUtils.copyProperties(cfxxsjyVO, dcfxx);
                        wjcfList.add(dcfxx);
                    }
                }
            } else {
                List<String> cfbhList = new ArrayList<>();
                if (trcjczbDOList != null && trcjczbDOList.size() > 0) {
                    for (TrcjczbDO trcjczbDO1 : trcjczbDOList) {
                        String cfbh = trcjczbDO1.getJccfbm();
                        if (StringUtils.isNotBlank(cfbh)) {
                            String[] cfbhArr = cfbh.split(",");
                            List<String> cfbhList1 = Arrays.asList(cfbhArr);
                            cfbhList.addAll(cfbhList1);
                        }
                    }
                }
                for (DCfxxsjyVO dCfxxsjyVO1 : dCfxxsjyVOList) {
                    String cfbh = dCfxxsjyVO1.getCfbh();
                    if (cfbhList.contains(cfbh)) {
                        Dcfxx dcfxx = new Dcfxx();
                        BeanUtils.copyProperties(dCfxxsjyVO1, dcfxx);
                        // 记录出现次数
                        int count = Collections.frequency(cfbhList, cfbh);
                        dcfxx.setBjccs(count);
                        yjcfList.add(dcfxx);
                    } else {
                        Dcfxx dcfxx = new Dcfxx();
                        BeanUtils.copyProperties(dCfxxsjyVO1, dcfxx);
                        wjcfList.add(dcfxx);
                    }
                }
            }
        }

        map.put("yjcfList", yjcfList);
        map.put("wjcfList", wjcfList);
        return map;
    }

    @Override
    public List<Qyjsjctjb> qyjsjcQueryPageList(Integer pageSize, Integer pageNum, TrcjczbVO trcjczbVO) {
        PageHelper.startPage(pageNum, pageSize);
        List<Qyjsjctjb> list = trcjczbMapper.qyjsjcQueryPageList(trcjczbVO);
        extracted(list);
        return list;
    }

    @Override
    public List<Qyjsjctjb> qyjsjcQueryPageListForBbdc(TrcjczbVO trcjczbVO) {
        List<Qyjsjctjb> list = trcjczbMapper.qyjsjcQueryPageList(trcjczbVO);
        extracted(list);
        return list;
    }

    @Override
    public List<TrcjczbDO> queryJcsjByBjdwmcAndYearAndCfbm(TrcjczbVO trcjczbVO) {
        Example example = new Example(TrcjczbDO.class);
        Example.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(trcjczbVO.getBjdwmc())) {
            criteria.andEqualTo("bjdwmc", trcjczbVO.getBjdwmc());
        }
        if (StringUtils.isNotBlank(trcjczbVO.getJcnf())) {
            criteria.andEqualTo("jcnf", trcjczbVO.getJcnf());
        }
        if (StringUtils.isNotBlank(trcjczbVO.getJccfbm())) {
            criteria.andLike("jccfbm", "%" + trcjczbVO.getJccfbm() + "%");
        }
        // 根据jckssj倒叙排列
        example.orderBy("jckssj").desc();
        List<TrcjczbDO> trcjczbDOList = trcjczbMapper.selectByExample(example);
        return trcjczbDOList;
    }

    @Override
    public List<Jcdwtjb> jcdwjcQueryPageList(Integer pageSize, Integer pageNum, TrcjczbVO trcjczbVO) {
        PageHelper.startPage(pageNum, pageSize);
        List<Jcdwtjb> list = trcjczbMapper.jcdwjcQueryPageList(trcjczbVO);
        return list;
    }

    @Override
    public List<Jcdwtjb> jcdwjcQueryPageListForBbdc(TrcjczbVO trcjczbVO) {
        List<Jcdwtjb> list = trcjczbMapper.jcdwjcQueryPageList(trcjczbVO);
        return list;
    }

    @Override
    public TrcjczbVO queryDetail(String id) {
        TrcjczbDO trcjczbDO = trcjczbMapper.selectByPrimaryKey(id);
        // 查询检查发现问题
        Example example = new Example(TrcjcfxwtDO.class);
        Example.Criteria criteria = example.createCriteria();
        criteria.andEqualTo("jcid", id);
        List<TrcjcfxwtDO> trcjcfxwtDOList = trcjcfxwtMapper.selectByExample(example);
        // 查询检查审核情况
        Example example1 = new Example(TrcjcshqkDO.class);
        Example.Criteria criteria1 = example1.createCriteria();
        criteria1.andEqualTo("jcid", id);
        List<TrcjcshqkDO> trcjcshqkDOList = trcjcshqkMapper.selectByExample(example1);
        // 查询检查整改情况
        Example example2 = new Example(TrcjczgqkDO.class);
        Example.Criteria criteria2 = example2.createCriteria();
        criteria2.andEqualTo("jcid", id);
        List<TrcjczgqkDO> trcjczgqkDOList = trcjczgqkMapper.selectByExample(example2);

        TrcjczbVO trcjczbVO = new TrcjczbVO();
        BeanUtils.copyProperties(trcjczbDO, trcjczbVO);
        // 设置检查发现问题
        if (trcjcfxwtDOList != null && trcjcfxwtDOList.size() > 0) {
            List<TrcjcfxwtVO> trcjcfxwtVOList = new ArrayList<>();
            for (TrcjcfxwtDO trcjcfxwtDO : trcjcfxwtDOList) {
                TrcjcfxwtVO trcjcfxwtVO = new TrcjcfxwtVO();
                BeanUtils.copyProperties(trcjcfxwtDO, trcjcfxwtVO);
                trcjcfxwtVOList.add(trcjcfxwtVO);
            }
            trcjczbVO.setTrcjcfxwtVOList(trcjcfxwtVOList);
        }
        // 设置检查审核情况
        if (trcjcshqkDOList != null && trcjcshqkDOList.size() > 0) {
            TrcjcshqkDO trcjcshqkDO = trcjcshqkDOList.get(0);
            TrcjcshqkVO trcjcshqkVO = new TrcjcshqkVO();
            BeanUtils.copyProperties(trcjcshqkDO, trcjcshqkVO);
            trcjczbVO.setTrcjcshqkVO(trcjcshqkVO);
        }
        // 设置检查整改情况
        if (trcjczgqkDOList != null && trcjczgqkDOList.size() > 0) {
            TrcjczgqkDO trcjczgqkDO = trcjczgqkDOList.get(0);
            TrcjczgqkVO trcjczgqkVO = new TrcjczgqkVO();
            BeanUtils.copyProperties(trcjczgqkDO, trcjczgqkVO);
            trcjczbVO.setTrcjczgqkVO(trcjczgqkVO);
        }
        return trcjczbVO;
    }

    private void extracted(List<Qyjsjctjb> list) {
        if (list.size() > 0) {
            for (Qyjsjctjb qyjsjctjb : list) {
                // 设置未被检仓房数
                DCfxxsjyVO dCfxxsjyVO = new DCfxxsjyVO();
                dCfxxsjyVO.setKddm(qyjsjctjb.getBjdwbm());
                List<DCfxxsjyVO> cfzs = trcjczbMapper.selectCfxxByEntity(dCfxxsjyVO);
                // 设置被检仓房数
                String bjcfbm = qyjsjctjb.getBjcfbm();
                // bjcfbm转换成，分隔的字符串，并去重
                if (StringUtils.isNotBlank(bjcfbm)) {
                    String[] bjcfbmArr = bjcfbm.split(",");
                    List<String> bjcfbmList = Arrays.asList(bjcfbmArr);
                    List<String> bjcfbmList1 = bjcfbmList.stream().distinct().collect(Collectors.toList());
                    qyjsjctjb.setBjcf(bjcfbmList1.size());
                    qyjsjctjb.setBjcfbm(StrUtil.join(",", bjcfbmList1));
                    // 未被检仓房数为总数减去被检仓房数
                    qyjsjctjb.setWbjcf(cfzs.size() - qyjsjctjb.getBjcf());
                } else {
                    qyjsjctjb.setBjcf(0);
                    qyjsjctjb.setWbjcf(cfzs.size());
                }
            }
        }
    }
}
