package com.unis.inspectionresult.server.service.impl.backlog;

import java.util.Date;
import java.util.List;

import com.unis.inspectiontask.common.vo.backlog.BacklogDeleteVO;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.inspectionresult.server.service.backlog.BacklogMQService;
import com.unis.inspectiontask.common.constant.BacklogConstant;
import com.unis.inspectiontask.common.vo.backlog.BacklogAddVO;
import com.unis.inspectiontask.common.vo.backlog.BacklogUpdateVO;
import com.unis.inspectiontask.common.vo.backlog.ReceiverCollectionVO;

import lombok.extern.slf4j.Slf4j;

/**
 *
 * @Description：待办服务实现
 * @author：王帅
 * @date: 2020年2月27日
 */
@Service
@Slf4j
public class BacklogMQServiceImpl implements BacklogMQService {

	@Autowired
	private RabbitTemplate amqpTemplate;

	@Override
	public void sendMsg(Object obj, String type) {
		try {
			this.amqpTemplate.convertAndSend(BacklogConstant.BACKLOG_EXCHANGE, "backlog." + type, obj);
		} catch (Exception e) {
			log.error("{}待办消息发送异常,待办实体{}", type, obj, e);
		}
	}

	@Override
	public void addNeedToDeals(String id, String title, String status, String statusName,String isPad,String tyname, String itemUrl,
			String itemQuery, String itemHavQuery, String itemHavUrl,String receiveCompanyName, List<ReceiverCollectionVO> userList) {
		if(CollectionUtils.isEmpty(userList)) {
			System.out.println("****************待办用户集合为空*****************");
			return;
		}
		if(StringUtils.isEmpty(title)) {
			System.out.println("****************没有正确的title*****************");
			return;
		}
		System.out.println("*************进入新增待办---insert,用户数:"+userList.size()+"************");
		BacklogAddVO record = new BacklogAddVO();
		record.buildAddVO(record);
		record.setItemId(id);
		record.setItemName(title);
		record.setCompanyName(CurrentUtil.getOrgName());
		record.setItemQueryHaveDone(itemHavQuery);
		record.setItemUrlHaveDone(itemHavUrl);
		if(!StringUtils.isEmpty(status)) {
			record.setItemStatus(Integer.valueOf(status));
		}
		record.setItemStatusName(statusName);
		record.setItemUrl(itemUrl);
		record.setItemQuery(itemQuery);
		if(isPad!=null){
			record.setIspad(isPad);
		}
		if(tyname!=null){
			record.setTyname(tyname);
		}
		record.setReceiveCompanyName(receiveCompanyName);
		// 另起线程执行待办
		new Thread(new Runnable() {
			@Override
			public void run() {
				for (ReceiverCollectionVO userVO : userList) {
				//类型0代表是加待办,默认是0
					record.setReceiver(userVO.getUserName());
					record.setReceiverId(userVO.getUserId());
					String data=null;
					// 需要将对象序列化成JSONObject
					if(id.contains("5000110-1")) {//日常检查
						if(userVO.getRylx()==1) {
							record.setItemName(title.replace("）待盖章", "）待整改"));
							data=JsonUtils.serialize(record);
							sendMsg(JSON.parseObject(data), "insert");
						} else if(userVO.getRylx()==0)  {
							record.setItemName(title.replace("）待整改","）待盖章"));
							data=JsonUtils.serialize(record);
							sendMsg(JSON.parseObject(data), "insert");
						} else {
							data=JsonUtils.serialize(record);
							sendMsg(JSON.parseObject(data), "insert");
						}
					} else {
						data=JsonUtils.serialize(record);
						sendMsg(JSON.parseObject(data), "insert");
					}
					System.out.println("---新增待办---insert---Receiver&ReceiverId---"+userVO.getUserName() + "-------" +userVO.getUserId()+"---data-------" +data);
				}
				System.out.println("*************结束新增待办---insert************");
			}
		}).start();
	}



	@Override
	public void addDeals(String isPad,String tyname, String itemId, String itemName, String status, String statusName) {
		try {

			System.out.println("*************进入更新已办---update************");
			BacklogUpdateVO updateVO = new BacklogUpdateVO();
			updateVO.buildUpdateVO(updateVO);
			updateVO.setItemId(itemId);
			updateVO.setItemName(itemName);
			updateVO.setItemStatus(Integer.valueOf(status));
			updateVO.setItemStatusName(statusName);
			if(isPad!=null){
				updateVO.setIspad(isPad);
			}
			if(tyname!=null){
				updateVO.setTyname(tyname);
			}
			String data=JsonUtils.serialize(updateVO);
			System.out.println("************更新已办---update*************"+data);
			sendMsg(JSON.parseObject(data), "update");
		} catch (Exception e) {
			e.printStackTrace();
		}
		System.out.println("*************完成更新已办---update************");
	}

	@Override
	public void addDealsYwjc(String id, String title, String status, String statusName, String isPad, String tyname,
							 String itemUrl, String itemQuery, String itemQueryHaveDone, String itemUrlHaveDone, List<ReceiverCollectionVO> userList, String userId, String userName,String receiveCompanyName) {
		BacklogAddVO record = new BacklogAddVO();
		record.buildAddVO(record);
		record.setItemId(id);
		record.setItemName(title);
		record.setCompanyName(CurrentUtil.getOrgName());
		record.setItemQueryHaveDone(itemQueryHaveDone);
		record.setItemUrlHaveDone(itemUrlHaveDone);
		if(!StringUtils.isEmpty(status)) {
			record.setItemStatus(Integer.valueOf(status));
		}
		record.setHandlerId(userId);
		record.setHandler(userName);
		record.setHandlingTime(new Date());
		record.setItemStatusName(statusName);
		record.setItemUrl(itemUrl);
		record.setItemQuery(itemQuery);
		if(isPad!=null){
			record.setIspad(isPad);
		}
		if(tyname!=null){
			record.setTyname(tyname);
		}
		record.setReceiveCompanyName(receiveCompanyName);
		System.out.println("*************进入保存已办业务检查---save,用户数:"+userList.size()+"************");
		// 另起线程执行待办
		new Thread(new Runnable() {
			@Override
			public void run() {
				for (ReceiverCollectionVO userVO : userList) {
					//类型1代表是加已办,默认是0
					record.setReceiver(userVO.getUserName());
					record.setReceiverId(userVO.getUserId());
					String data=JsonUtils.serialize(record);
					System.out.println("---保存已办业务检查---Receiver&ReceiverId---" + userVO.getUserName() + "-------" + userVO.getUserId()+"-------"+data);
					// 需要将对象序列化成JSONObject
					sendMsg(JSON.parseObject(data), "save");
				}
				System.out.println("*************结束保存已办业务检查---save************");
			}
		}).start();
	}

	@Override
	public void deleteDeals(String isPad,String tyname, String itemId, String itemName, String status, String statusName) {
		try {

			System.out.println("*************进入删除待办---delete************");
			BacklogDeleteVO deleteVO = new BacklogDeleteVO();
			deleteVO.setItemId(itemId);
			deleteVO.setItemName(itemName);
			deleteVO.setItemStatus(Integer.valueOf(status));
			deleteVO.setItemStatusName(statusName);
			if(isPad!=null){
				deleteVO.setIspad(isPad);
			}
			if(tyname!=null){
				deleteVO.setTyname(tyname);
			}
			String data=JsonUtils.serialize(deleteVO);
			System.out.println("************删除待办---delete*************"+data);
			sendMsg(JSON.parseObject(data), "del");
		} catch (Exception e) {
			e.printStackTrace();
		}
		System.out.println("*************完成删除待办---delete************");
	}

}
